@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2009                                                *
+ *  Copyright (c) 2001-2010                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -13,6 +13,7 @@
 if (!defined("_ECRIRE_INC_VERSION")) return;
 
 include_spip('inc/presentation');
+include_spip('base/dump');
 
 // http://doc.spip.org/@exec_admin_tech_dist
 function exec_admin_tech_dist()
@@ -73,7 +74,11 @@ function exec_admin_tech_dist()
 	 _T('texte_admin_tech_01',
 	   array('dossier' => '<i>'.$dir_dump.'</i>', 'img'=>'<i>'.$dir_img.'</i>')) .
 	 '&nbsp;' .
-	 _T('texte_admin_tech_02') .
+	 _T('texte_admin_tech_02',
+		array('archive' => str_replace('/', ' / ', $archive),
+		      'spipnet' => $GLOBALS['home_server']
+		      . '/' .  $GLOBALS['spip_lang'] . '_article1489.html'
+		      )) .
 	"</p>";
 	
 	$chercher_rubrique = charger_fonction('chercher_rubrique', 'inc');
@@ -104,7 +109,8 @@ function exec_admin_tech_dist()
 	  $dir_dump .
 	  "</b>$nom<b>.xml</b></li></ul>\n"
 	  . "\n<input type='hidden' name='reinstall' value='non' />";
- 
+
+	$res .= options_avancees_dump();
 	echo 
  		generer_form_ecrire('export_all', $res, '', _T('texte_sauvegarde_base')),
  		fin_cadre_trait_couleur(true);
@@ -201,8 +207,9 @@ function admin_sauvegardes($dir_dump, $tri)
 		. '</table>';
 
 
+	$plie = _T('info_options_avancees');
 	// restauration partielle / fusion
-	$res .= debut_cadre_enfonce('',true) .
+	$opt = debut_cadre_enfonce('',true) .
 		"\n<div>" .
 		 "<input name='insertion' id='insertion' type='checkbox' />&nbsp; <label for='insertion'>". 
 		  _T('sauvegarde_fusionner') .
@@ -217,6 +224,8 @@ function admin_sauvegardes($dir_dump, $tri)
 		  '</div>' .
 		  fin_cadre_enfonce(true);
 
+	$res .= block_parfois_visible('import_tables', $plie, $opt, '', false);
+
 	return generer_form_ecrire('import_all', $res, '', _T('bouton_restaurer_base'));
 }
 
@@ -259,4 +268,47 @@ function nom_fichier_dump()
 	}
 	return $nom;
 }
-?>
+
+
+function options_avancees_dump(){
+	list($tables,) = base_liste_table_for_dump(lister_tables_noexport());
+	$plie = _T('info_options_avancees');
+	$res = controle_tables_en_base('export', $tables);
+	$res = "<h3>"._T('install_tables_base')."</h3>"
+	 . "\n<ol style='spip'><li>\n" .
+			join("</li>\n<li>", $res) .
+			"</li></ol>\n";
+
+	$res = block_parfois_visible('export_tables', $plie, $res, '', false);
+ 	return $res;
+}
+
+
+// Fabrique la liste a cocher des tables presentes
+function controle_tables_en_base($name, $check)
+{
+	$p = '/^' . $GLOBALS['table_prefix'] . '/';
+	$res = $check;
+	foreach(sql_alltable() as $t) {
+		$t = preg_replace($p, 'spip', $t);
+		if (!in_array($t, $check)) $res[]= $t;
+	}
+	sort($res);
+
+	foreach ($res as $k => $t) {
+
+		$c = "type='checkbox'"
+		. (in_array($t, $check) ? " checked='checked'" : '')
+		. " onclick='manuel=false'";
+
+		$res[$k] = "<input $c value='$t' id='$name_$t' name='$name"
+			. "[]' />\n"
+			. $t
+			. " ("
+			.  sql_countsel($t)
+	  		. ")";
+	}
+	return $res;
+}
+
+?>
\ No newline at end of file
