@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2009                                                *
+ *  Copyright (c) 2001-2010                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -133,7 +133,8 @@ function articles_affiche($id_article, $row, $cherche_auteur, $ids, $cherche_mot
 		. (_INTERFACE_ONGLETS?"":"<span $dir_lang class='arial1 spip_medium'><b>" . typo($soustitre) . "</b></span>\n");
 
 	$onglet_contenu =
-	  afficher_corps_articles($id_article,$virtuel,$row);
+	  afficher_corps_articles($id_article,$virtuel,$row)
+		.		"<div class='bandeau_actions'>$actions</div>";
 
 	$onglet_proprietes = ((!_INTERFACE_ONGLETS) ? "" :"")
 	  . $dater($id_article, $flag_editable, $statut_article, 'article', 'articles', $date, $date_redac)
@@ -141,6 +142,7 @@ function articles_affiche($id_article, $row, $cherche_auteur, $ids, $cherche_mot
 	  . (!$editer_mots ? '' : $editer_mots('article', $id_article, $cherche_mot, $select_groupe, $flag_editable, false, 'articles'))
 	  . (!$referencer_traduction ? '' : $referencer_traduction($id_article, $flag_editable, $id_rubrique, $id_trad, $trad_err))
 	  . pipeline('affiche_milieu',array('args'=>array('exec'=>'articles','id_article'=>$id_article),'data'=>''))
+		. bouton_proposer_article($id_article,$statut_article)
 	  ;
 
 	$documenter_objet = charger_fonction('documenter_objet','inc');
@@ -153,7 +155,8 @@ function articles_affiche($id_article, $row, $cherche_auteur, $ids, $cherche_mot
 	return
 	  $navigation
 	  . $extra
-	  . "<div class='fiche_objet'>"
+	  . pipeline('afficher_fiche_objet',array('args'=>array('type'=>'article','id'=>$id_article),'data'=>
+	   "<div class='fiche_objet'>"
 	  . $haut
 	  . afficher_onglets_pages(
 	  	array(
@@ -170,7 +173,7 @@ function articles_affiche($id_article, $row, $cherche_auteur, $ids, $cherche_mot
 	    'discuter'=>_INTERFACE_ONGLETS?$onglet_discuter:""))
 	  . "</div>"
 	  . (_INTERFACE_ONGLETS?"":$onglet_discuter)
-;
+			));
 }
 
 //
@@ -189,6 +192,7 @@ function boites_de_config_articles($id_article)
 	$petition = $petitionner($id_article,"articles","id_article=$id_article");
 
 	$masque = $regler . $petition;
+  $masque = pipeline('afficher_config_objet',array('args'=>array('type'=>'article','id'=>$id_article),'data'=>$masque));
 
 	if (!$masque) return '';
 
@@ -281,4 +285,25 @@ function afficher_corps_articles($id_article, $virtuel, $row)
 	return $res;
 }
 
+function bouton_proposer_article($id_article,$statut_article){
+	$ret = "";
+
+	if ($statut_article=='prepa'
+		AND $id_auteur = $GLOBALS["visiteur_session"]["id_auteur"]
+		AND $GLOBALS["visiteur_session"]["statut"] == "1comite"
+		AND autoriser('modifier', 'article', $id_article)
+		AND sql_fetsel("id_article", "spip_auteurs_articles", "id_article=".intval($id_article)." AND id_auteur=".intval($id_auteur))) {
+			$ret .= debut_cadre_relief("", true);
+			$ret .= "<div class='verdana3' style='text-align: center;'>";
+			$ret .= "<div>"._T("texte_proposer_publication")."</div>";
+
+			$ret .= bouton_action(_T("bouton_demande_publication"),
+							generer_action_auteur('instituer_article', "$id_article-prop", self()), '', _T('confirm_changer_statut'));
+
+			$ret .= "</div>";
+			$ret .= fin_cadre_relief(true);
+
+	}
+	return $ret;
+}
 ?>
