@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2009                                                *
+ *  Copyright (c) 2001-2010                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -11,11 +11,17 @@
 \***************************************************************************/
 
 if (!defined("_ECRIRE_INC_VERSION")) return;
+
+@define('_INC_DISTANT_VERSION_HTTP', "HTTP/1.0");
+@define('_INC_DISTANT_CONTENT_ENCODING', "gzip");
+@define('_INC_DISTANT_USER_AGENT', 'SPIP-'. $GLOBALS['spip_version_affichee']." (" . $GLOBALS['home_server'] . ")");
+
 //@define('_COPIE_LOCALE_MAX_SIZE',2097152); // poids (inc/utils l'a fait)
 //
 // Cree au besoin la copie locale d'un fichier distant
 // mode = 'test' - ne faire que tester
 // mode = 'auto' - charger au besoin
+// mode = 'modif' - Si deja present, ne charger que si If-Modified-Since
 // mode = 'force' - charger toujours (mettre a jour)
 //
 // Prend en argument un chemin relatif au rep racine, ou une URL
@@ -31,27 +37,28 @@ function copie_locale($source, $mode='auto') {
 	if (preg_match($reg, $source, $local)) return substr(_DIR_IMG,strlen(_DIR_RACINE)) . urldecode($local[1]);
 
 	$local = fichier_copie_locale($source);
+	$localrac = _DIR_RACINE.$local;
+	$t = ($mode=='force') ? false  : @file_exists($localrac);
 
 	// test d'existence du fichier
-	if ($mode == 'test')
-		return @file_exists(_DIR_RACINE.$local) ? $local : '';
+	if ($mode == 'test') return $t ? $local : '';
 
 	// si $local = '' c'est un fichier refuse par fichier_copie_locale(),
 	// par exemple un fichier qui ne figure pas dans nos documents ;
 	// dans ce cas on n'essaie pas de le telecharger pour ensuite echouer
 	if (!$local) return false;
 
-	// sinon voir si on doit le telecharger
-	if ($local != $source
-	AND preg_match(',^\w+://,', $source)) {
-		if (($mode=='auto' AND !@file_exists(_DIR_RACINE.$local))
-		OR $mode=='force') {
-			$res = recuperer_page($source,_DIR_RACINE.$local,false,_COPIE_LOCALE_MAX_SIZE);
-			if (!$res) return false;
-			spip_log ('ecrire copie locale '._DIR_RACINE.$local." taille $res");
+	// sinon voir si on doit/peut le telecharger
+	if ($local == $source OR !preg_match(',^\w+://,', $source)) 
+		return $local;
+
+	if ($mode=='modif' OR !$t) {
+		$res = recuperer_page($source, $localrac,false,_COPIE_LOCALE_MAX_SIZE, '','',false, $t ? filemtime($localrac) : '');
+		if (!$res) return $t ? $local : false;
+#		spip_log ('ecrire copie locale '.$localrac." taille $res");
 			
-			// pour une eventuelle indexation
-			pipeline('post_edition',
+		// pour une eventuelle indexation
+		pipeline('post_edition',
 				array(
 					'args' => array(
 						'operation' => 'copie_locale',
@@ -61,7 +68,6 @@ function copie_locale($source, $mode='auto') {
 					'data' => null
 				)
 			);
-		}
 	}
 
 	return $local;
@@ -90,7 +96,7 @@ function prepare_donnees_post($donnees, $boundary = '') {
   else {
 	  /* boundary automatique */
 	  // Si on a plus de 500 octects de donnees, on "boundarise"
-	  if($boundary == '') {
+	  if($boundary === '') {
 	    $taille = 0;
 	    foreach ($donnees as $cle => $valeur) {
 	  		if (is_array($valeur)) {
@@ -107,7 +113,7 @@ function prepare_donnees_post($donnees, $boundary = '') {
 	    }
 	  }
 
-		if($boundary) {
+		if(is_string($boundary) and strlen($boundary)) {
 			// fabrique une chaine HTTP pour un POST avec boundary
 			$entete = "Content-Type: multipart/form-data; boundary=$boundary\r\n";
 			$chaine = '';
@@ -182,13 +188,13 @@ function recuperer_page($url, $trans=false, $get_headers=false,
 
 	if (!empty($datas)) {
 		$get = 'POST';
-		list($type, $postdata) = prepare_donnees_post($datas);
+		list($type, $postdata) = prepare_donnees_post($datas, $boundary);
 		$datas = $type . 'Content-Length: '.strlen($postdata)."\r\n\r\n".$postdata;
 	}
 
 	// dix tentatives maximum en cas d'entetes 301...
 	for ($i=0;$i<10;$i++) {
-		$url = recuperer_lapage($url, $trans, $get, $taille_max, $datas, $boundary, $refuser_gz, $date_verif, $uri_referer);
+		$url = recuperer_lapage($url, $trans, $get, $taille_max, $datas, $refuser_gz, $date_verif, $uri_referer);
 		if (!$url) return false;
 		if (is_array($url)) {
 			list($headers, $result) = $url;
@@ -202,7 +208,7 @@ function recuperer_page($url, $trans=false, $get_headers=false,
 // si $trans est null -> on ne veut que les headers
 // si $trans est une chaine, c'est un nom de fichier pour ecrire directement dedans
 // http://doc.spip.org/@recuperer_lapage
-function recuperer_lapage($url, $trans=false, $get='GET', $taille_max = 1048576, $datas='', $boundary='', $refuser_gz = false, $date_verif = '', $uri_referer = '')
+function recuperer_lapage($url, $trans=false, $get='GET', $taille_max = 1048576, $datas='', $refuser_gz = false, $date_verif = '', $uri_referer = '')
 {
 	// $copy = copier le fichier ?
 	$copy = (is_string($trans) AND strlen($trans) > 5); // eviter "false" :-)
@@ -213,7 +219,7 @@ function recuperer_lapage($url, $trans=false, $get='GET', $taille_max = 1048576,
 		$refuser_gz = true;
 
 	// ouvrir la connexion et envoyer la requete et ses en-tetes
-	list($f, $fopen) = init_http($get, $url, $refuser_gz, $uri_referer, $datas);
+	list($f, $fopen) = init_http($get, $url, $refuser_gz, $uri_referer, $datas, _INC_DISTANT_VERSION_HTTP, $date_verif);
 	if (!$f) {
 		spip_log("ECHEC init_http $url");
 		return false;
@@ -226,9 +232,15 @@ function recuperer_lapage($url, $trans=false, $get='GET', $taille_max = 1048576,
 	else {
 		$headers = recuperer_entetes($f, $date_verif);
 		if (is_numeric($headers)) {
-			spip_log("HTTP status $headers pour $url");
 			fclose($f);
-			return false;
+			// Chinoisierie inexplicable pour contrer 
+			// les actions liberticides de l'empire du milieu
+			if ($headers) {
+				spip_log("HTTP status $headers pour $url");
+				return false;
+			} elseif ($result = @file_get_contents($url))
+			    return array('', $result);
+			else return false;
 		}
 		if (!is_array($headers)) { // cas Location
 			fclose($f);
@@ -238,15 +250,23 @@ function recuperer_lapage($url, $trans=false, $get='GET', $taille_max = 1048576,
 		$headers = join('', $headers);
 	}
 
-#	spip_log("recup  $headers" );
 	if ($trans === NULL) return array($headers, '');
-	$result = recuperer_body($f, $taille_max, $copy ? $trans : '');
+
+	// s'il faut deballer, le faire via un fichier temporaire
+	// sinon la memoire explose pour les gros flux
+
+	$gz = preg_match(",\bContent-Encoding: .*gzip,is", $headers) ?
+		(_DIR_TMP.md5(uniqid(mt_rand())).'.tmp.gz') : '';
+	  
+#	spip_log("entete ($trans $copy $gz)\n$headers"); 
+	$result = recuperer_body($f, $taille_max, $gz ? $gz : ($copy ? $trans : ''));
 	fclose($f);
 	if (!$result) return array($headers, $result);
 
 	// Decompresser au besoin
-	if (preg_match(",\bContent-Encoding: .*gzip,i", $headers)) {
-		$result = spip_gzinflate_body($result);
+	if ($gz) {
+		$result = join('', gzfile($gz));
+		supprimer_fichier($gz);
 	}
 	// Faut-il l'importer dans notre charset local ?
 	if ($trans === true) {
@@ -257,19 +277,6 @@ function recuperer_lapage($url, $trans=false, $get='GET', $taille_max = 1048576,
 	return array($headers, $result);
 }
 
-// http://doc.spip.org/@spip_gzinflate_body
-function spip_gzinflate_body($gzData){
-	// on dezippe via un fichier temporaire
-	// sinon la memoire explose pour les gros flux
-	$tmp = _DIR_TMP.md5(uniqid()).'.tmp';
-	ecrire_fichier($tmp, $gzData);
-	rename($tmp,$tmp.'.gz');
-	lire_fichier($tmp.'.gz', $gzData);
-	supprimer_fichier($tmp.'.gz');
-	return $gzData;
-}
-
-
 // http://doc.spip.org/@recuperer_body
 function recuperer_body($f, $taille_max=1048576, $fichier='')
 {
@@ -310,7 +317,7 @@ function recuperer_entetes($f, $date_verif='')
 	}
 	$status = intval($r[1]);
 	$headers = array();
-	$not_modif = false;
+	$not_modif = $location = false;
 	while ($s = trim(fgets($f, 16384))) {
 		$headers[]= $s."\n";
 		preg_match(',^([^:]*): *(.*)$,i', $s, $r);
@@ -526,8 +533,8 @@ function recuperer_infos_distantes($source, $max=0, $charger_si_petite_image = t
 // http://doc.spip.org/@need_proxy
 function need_proxy($host)
 {
-	$http_proxy = $GLOBALS['meta']["http_proxy"];
-	$http_noproxy = $GLOBALS['meta']["http_noproxy"];
+	$http_proxy = @$GLOBALS['meta']["http_proxy"];
+	$http_noproxy = @$GLOBALS['meta']["http_noproxy"];
 
 	$domain = substr($host,strpos($host,'.'));
 
@@ -542,8 +549,9 @@ function need_proxy($host)
 // retourne le descripteur sur lequel lire la reponse
 //
 // http://doc.spip.org/@init_http
-function init_http($method, $url, $refuse_gz=false, $referer = '', $datas="", $vers="HTTP/1.0") {
-	$via_proxy = ''; $proxy_user = ''; $fopen = false;
+function init_http($method, $url, $refuse_gz=false, $referer = '', $datas="", $vers="HTTP/1.0", $date='') {
+	$user = $via_proxy = $proxy_user = ''; 
+	$fopen = false;
 
 	$t = @parse_url($url);
 	$host = $t['host'];
@@ -561,12 +569,12 @@ function init_http($method, $url, $refuse_gz=false, $referer = '', $datas="", $v
 
 	if (!isset($t['port']) || !($port = $t['port'])) $port = 80;
 	if (!isset($t['path']) || !($path = $t['path'])) $path = "/";
-	if ($t['query']) $path .= "?" .$t['query'];
+	if (@$t['query']) $path .= "?" .$t['query'];
 
-	$f = lance_requete($method, $scheme, $user, $host, $path, $port, $noproxy, $refuse_gz, $referer, $datas, $vers);
+	$f = lance_requete($method, $scheme, $user, $host, $path, $port, $noproxy, $refuse_gz, $referer, $datas, $vers, $date);
 	if (!$f) {
 	  // fallback : fopen
-		if (!$GLOBALS['tester_proxy']) {
+		if (!_request('tester_proxy')) {
 			$f = @fopen($url, "rb");
 			spip_log("connexion vers $url par simple fopen");
 			$fopen = true;
@@ -577,20 +585,21 @@ function init_http($method, $url, $refuse_gz=false, $referer = '', $datas="", $v
 }
 
 // http://doc.spip.org/@lance_requete
-function lance_requete($method, $scheme, $user, $host, $path, $port, $noproxy, $refuse_gz=false, $referer = '', $datas="", $vers="HTTP/1.0") {
+function lance_requete($method, $scheme, $user, $host, $path, $port, $noproxy, $refuse_gz=false, $referer = '', $datas="", $vers="HTTP/1.0", $date='') {
 
+	$proxy_user = '';
 	$http_proxy = need_proxy($host);
+	if ($user) $user = urlencode($user[0]).":".urlencode($user[1]);
 
 	if ($http_proxy) {
 		$path = "$scheme://"
-			. (!$user ? '' : urlencode($user[0]).":".urlencode($user[1])."@")
+			. (!$user ? '' : "$user@")
 			. "$host" . (($port != 80) ? ":$port" : "") . $path;
 		$t2 = @parse_url($http_proxy);
-		$proxy_user = $t2['user'];
-		$proxy_pass = $t2['pass'];
 		$first_host = $t2['host'];
 		if (!($port = $t2['port'])) $port = 80;
-
+		if ($t2['user'])
+			$proxy_user = base64_encode($t2['user'] . ":" . $t2['pass']);
 	} else $first_host = $noproxy.$host;
 
 	$f = @fsockopen($first_host, $port);
@@ -601,14 +610,13 @@ function lance_requete($method, $scheme, $user, $host, $path, $port, $noproxy, $
 
 	$req = "$method $path $vers\r\n"
 	. "Host: $host\r\n"
-	. "User-Agent: SPIP-".$GLOBALS['spip_version_affichee']." (http://www.spip.net/)\r\n"
-	. ($refuse_gz ? '' : "Accept-Encoding: gzip\r\n")
+	. "User-Agent: " . _INC_DISTANT_USER_AGENT . "\r\n"
+	. ($refuse_gz ? '' : ("Accept-Encoding: " . _INC_DISTANT_CONTENT_ENCODING . "\r\n"))
 	. (!$site ? '' : "Referer: $site/$referer\r\n")
-	. (!$user ? '' : "Authorization: Basic "
-	     . base64_encode(urlencode($user[0]).":".urlencode($user[1])) ."\r\n")
-	. (!$proxy_user ? '' :
-	    ("Proxy-Authorization: Basic "
-	     . base64_encode($proxy_user . ":" . $proxy_pass) . "\r\n"));
+	. (!$date ? '' : "If-Modified-Since: " . (gmdate("D, d M Y H:i:s", $date)  ." GMT\r\n"))
+	. (!$user ? '' : ("Authorization: Basic " . base64_encode($user) ."\r\n"))
+	. (!$proxy_user ? '' : "Proxy-Authorization: Basic $proxy_user\r\n")
+	. (!strpos($vers, '1.1') ? '' : "Keep-Alive: 300\r\nConnection: keep-alive\r\n");
 
 #	spip_log("Requete\n$req");
 	fputs($f, $req);
