@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2009                                                *
+ *  Copyright (c) 2001-2010                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -96,8 +96,9 @@ function generer_url_document_dist($id_document, $args='', $ancre='') {
 
 	// Si droit de voir tous les docs, pas seulement celui-ci
 	// il est inutilement couteux de rajouter une protection
-
-	$r = autoriser('voir', 'document');
+	// idem si ce doc est visible par tous
+	$r = (autoriser('voir', 'document')
+		OR autoriser('voir', 'document', $id_document, array()));
 
 	if ($r AND $r !== 'htaccess') return get_spip_doc($f);
 
@@ -123,7 +124,6 @@ function vignette_par_defaut($ext, $size=true, $loop = true) {
 	if (!$ext)
 		$ext = 'txt';
 
-
 	// Chercher la vignette correspondant a ce type de document
 	// dans les vignettes persos, ou dans les vignettes standard
 	if (
@@ -153,6 +153,31 @@ function vignette_par_defaut($ext, $size=true, $loop = true) {
 	return array($v, $largeur, $hauteur);
 }
 
+// http://doc.spip.org/@document_et_vignette
+function document_et_vignette($document, $url, $portfolio=false) {
+	$image = $document['id_vignette'];
+
+	if ($image) 
+		$image = sql_fetsel("*", "spip_documents", "id_document = ".$image);
+	if ($image) {
+		if (!$portfolio OR !($GLOBALS['meta']['creer_preview'] == 'oui')) {
+			$x = $image['largeur'];
+			$y = $image['hauteur'];
+		} else {
+			$x = 120;
+			$y = 110;
+		}
+		$image = get_spip_doc($image['fichier']);
+	} else {
+		if ($portfolio) {
+			$x = 110;
+			$y = 120;
+		} else 	$x = $y =-1; 
+	}
+	if (!$url) $url = generer_url_document_dist($document['id_document'], 'document');
+	return vignette_automatique($image, $document, $url, $x, $y, '', "miniature_document");
+}
+
 //
 // Affiche le document avec sa vignette par defaut
 //
@@ -162,68 +187,74 @@ function vignette_par_defaut($ext, $size=true, $loop = true) {
 //
 // A noter : dans le portfolio prive on pousse le vice jusqu'a reduire la taille
 // de la vignette -> c'est a ca que sert la variable $portfolio
-// http://doc.spip.org/@image_pattern
-function image_pattern($vignette) {
-	return "<img src='"
-			. get_spip_doc($vignette['fichier'])."'
-			alt=' '
-			width='".$vignette['largeur']."'
-			height='".$vignette['hauteur']."' />";
+// http://doc.spip.org/@vignette_automatique
+function vignette_automatique($img, $doc, $lien, $x=0, $y=0, $align='', $class='spip_logos')
+{
+	include_spip('inc/distant');
+	include_spip('inc/filtres');
+	include_spip('inc/filtres_images_mini');
+	$e = $doc['extension'];
+	if (!$img) {
+		if ($img = image_du_document($doc)) {
+			if (!$x AND !$y) // eviter une double reduction
+				$img = image_reduire($img);
+		}
+		else{
+			$img = vignette_par_defaut($e, false);
+			$size = @getimagesize($img);
+			$img = "<img src='$img' ".$size[3]." />";
+		}
+	}
+	else{
+		$size = @getimagesize($img);
+		$img = "<img src='$img' ".$size[3]." />";
+	}
+	// on appelle image_reduire independamment de la presence ou non
+	// des librairies graphiques
+	// la fonction sait se debrouiller et faire de son mieux dans tous les cas
+	if ($x OR $y) {
+		$img = image_reduire($img, $x, $y);
+	}
+	$img = inserer_attribut($img, 'alt', '');
+	$img = inserer_attribut($img, 'class', $class);
+	if ($align) $img = inserer_attribut($img, 'align', $align);
+
+	if (!$lien) return $img;
+
+	$titre = supprimer_tags(typo($doc['titre']));
+	$titre = " - " .taille_en_octets($doc['taille'])
+	  . ($titre ? " - $titre" : "");
+
+	$type = sql_fetsel('titre, mime_type','spip_types_documents', "extension = " . sql_quote($e));
+
+	$mime = $type['mime_type'];
+	$titre = attribut_html(couper($type['titre'] . $titre, 80));
+
+	return "<a href='$lien' type='$mime' title='$titre'>$img</a>";
 }
 
-// http://doc.spip.org/@document_et_vignette
-function document_et_vignette($document, $url, $portfolio=false) {
-	$extension = $document['extension'];
-	$vignette = $document['id_vignette'];
+// Trouve une image caracteristique d'un document.
+// Si celui-ci est une image et que les outils graphiques sont dispos, 
+// retourner le document (en exploitant sa copie locale s'il est distant).
+// Autrement retourner la vignette fournie par SPIP pour ce type MIME 
+// Resultat: un fichier local existant
 
-	if ($vignette) 
-		$vignette = sql_fetsel("*", "spip_documents", "id_document = ".$vignette);
-	if ($vignette) {
-		include_spip('inc/filtres');
-		$loc = get_spip_doc($vignette['fichier']);
-		$image = filtrer('image_reduire', $loc, 120, 110, false, true);
-		if ($loc == $image)
-			$image = image_pattern($vignette);
-	}
-	else if (in_array($extension,
-		explode(',', $GLOBALS['meta']['formats_graphiques']))
-	AND $GLOBALS['meta']['creer_preview'] == 'oui') {
-		include_spip('inc/distant');
-		include_spip('inc/filtres');
-
-		// Si le document distant a une copie locale, on peut l'exploiter
+function image_du_document($document)
+{
+	$e = $document['extension'];
+	if ((strpos($GLOBALS['meta']['formats_graphiques'], $e) !== false)
+	  AND (!test_espace_prive() OR $GLOBALS['meta']['creer_preview']=='oui')
+	  AND $document['fichier']) {
 		if ($document['distant'] == 'oui') {
-			$image = _DIR_RACINE.copie_locale($document['fichier'], 'test');
-		} else {
+			$image = _DIR_RACINE.copie_locale($document['fichier']);
+		} 
+		else
 			$image = get_spip_doc($document['fichier']);
-		}
-
-		if ($image) {
-			if ($portfolio) {
-				$image = filtrer('image_reduire',	$image,	110, 120, false, true);
-			} else {
-				$image = filtrer('image_reduire',	$image,	-1,-1,false, true);
-			}
-			$image = inserer_attribut($image, "class", "miniature_document");
-		}
-	} else {
-		$image = '';
-	}
-
-	if (!$image) {
-		list($fichier, $largeur, $hauteur) = vignette_par_defaut($extension);
-		$image = "<img src='$fichier'\n\theight='$hauteur' style='' width='$largeur' alt=' ' />";
-	} else $image = inserer_attribut($image, 'alt', ' ');
-
-	if (!$url)
-		return $image;
-	else {
-		$t = sql_fetsel("mime_type", "spip_types_documents", "extension=".sql_quote($document['extension']));
-		return "<a href='$url'\n\ttype='".$t['mime_type']."'>$image</a>";
+		if (@file_exists($image)) return $image;
 	}
+	return '';
 }
 
-
 //
 // Afficher un document dans la colonne de gauche
 //
@@ -344,7 +375,7 @@ function affiche_raccourci_doc($doc, $id, $align) {
 		$pipe = "|$align";
 
 		if ($GLOBALS['browser_barre'])
-			$onclick = "\nondblclick=\"barre_inserer('\\x3C$doc$id$pipe&gt;', $('.barre_inserer')[0]);\"\ntitle=\"". str_replace('&amp;', '&', entites_html(_T('double_clic_inserer_doc')))."\"";
+			$onclick = "\nondblclick=\"barre_inserer('\\x3C$doc$id$pipe&gt;', $('textarea[name=texte]')[0]);\"\ntitle=\"". str_replace('&amp;', '&', entites_html(_T('double_clic_inserer_doc')))."\"";
 	} else {
 		$align='center';
 	}
@@ -363,90 +394,62 @@ function est_inclus($id_document) {
 }
 
 //
-// Afficher un document sous forme de ligne depliable (pages xxx_edit)
-//
-// TODO: il y a du code a factoriser avec inc/documenter
+// Afficher un document sous forme de bloc depliable 
+// en donnant un apercu
+// et en indiquer le raccourci permettant l'incrustation
+// Pour les distant, donner un bouton pour rappatriement (trombone)
+// Pour les images, donnner les boutons de rotations
+
 
 // http://doc.spip.org/@afficher_case_document
 function afficher_case_document($id_document, $id, $script, $type, $deplier=false) {
 	global $spip_lang_right;
 	
-	$document = sql_fetsel("docs.id_document, docs.id_vignette,docs.extension,docs.titre,docs.descriptif,docs.fichier,docs.largeur,docs.hauteur,docs.taille,docs.mode,docs.distant, docs.date, L.vu", "spip_documents AS docs INNER JOIN spip_documents_liens AS L ON L.id_document=docs.id_document", "L.id_objet=".intval($id)." AND objet=".sql_quote($type)." AND L.id_document=".sql_quote($id_document));
+	$document = sql_fetsel("D.id_document, D.id_vignette,D.extension,D.titre,D.descriptif,D.fichier,D.largeur,D.hauteur,D.taille,D.mode,D.distant, D.date, L.vu", "spip_documents AS D INNER JOIN spip_documents_liens AS L ON L.id_document=D.id_document", "L.id_objet=".intval($id)." AND objet=".sql_quote($type)." AND L.id_document=".intval($id_document));
 
 	if (!$document) return "";
 
 	$id_vignette = $document['id_vignette'];
 	$extension = $document['extension'];
-	$titre = $document['titre'];
 	$descriptif = $document['descriptif'];
-	$url = generer_url_entite($id_document, 'document');
 	$fichier = $document['fichier'];
 	$largeur = $document['largeur'];
 	$hauteur = $document['hauteur'];
-	$taille = $document['taille'];
 	$mode = $document['mode'];
 	$distant = $document['distant'];
+	$titre = $document['titre'];
+	$legender = charger_fonction('legender', 'inc');
+	$dist = '';
 
-	// le doc est-il appele dans le texte ?
-	$doublon = est_inclus($id_document);
-
-	$cadre = strlen($titre) ? $titre : basename($fichier);
-
-	$letype = sql_fetsel("titre,inclus", "spip_types_documents", "extension=".sql_quote($extension));
-	if ($letype) {
-		$type_inclus = $letype['inclus'];
-		$type_titre = $letype['titre'];
+	$r = sql_fetsel("titre,inclus", "spip_types_documents", "extension=".sql_quote($extension));
+	if ($r) {
+		$type_inclus = $r['inclus'];
+		$type_titre = $r['titre'];
 	}
-	//
-	// Afficher un document
-	//
-	$ret = "";
+
 	if ($mode == 'document') {
 
-		$ret .= debut_cadre_enfonce("doc-24.gif", true, "", lignes_longues(typo($cadre),20), "document$id_document");
-		$ret .= "<a name='document$id_document'></a>\n";
-
 		if ($distant == 'oui') {
-			$dist = "\n<div class='verdana1' style='float: $spip_lang_right; text-align: $spip_lang_right;'>";
-
-			// Signaler les documents distants par une icone de trombone
-			$dist .= "\n<img src='" . chemin_image('attachment.gif') . "'\n\talt=\"$fichier\"\n\ttitle=\"$fichier\" />\n";
-			// Bouton permettant de copier en local le fichier
 			include_spip('inc/tourner');
-			$dist .= bouton_copier_local($document, $type, $id, $id_document, $script);
-			
-			$dist .="</div>\n";
-		} else {
-			$dist = '';
+			$dist = "\n<div class='verdana1' style='float: $spip_lang_right; text-align: $spip_lang_right;'>"
+			. "\n<img src='" . chemin_image('attachment.gif') . "'\n\talt=\"$fichier\"\n\ttitle=\"$fichier\" />\n"
+			. bouton_copier_local($document, $type, $id, $id_document, $script)
+			. "</div>\n";
 		}
 
-		//
-		// Affichage de la vignette
-		//
-		$ret .= "\n<div style='text-align: center'>"
-		. $dist
-		. document_et_vignette($document, $url, true)
-		. '</div>'
-		. "\n<div class='verdana1' style='text-align: center; color: black;'>\n"
-		. ($type_titre ? $type_titre : 
-		      ( _T('info_document').' '.majuscules($extension)))
-		. "</div>";
-
-		// Affichage du raccourci <doc...> correspondant
-		$raccourci = '';
-		if ($doublon)
-			$raccourci .= affiche_raccourci_doc('doc', $id_document, '');
+		if (est_inclus($id_document))
+			$raccourci = affiche_raccourci_doc('doc', $id_document, '');
 		else {
-			if (($type_inclus == "embed" OR $type_inclus == "image") AND $largeur > 0 AND $hauteur > 0) {
-				$raccourci .= "<b>"._T('info_inclusion_vignette')."</b><br />";
-			}
+			$vign= (($type_inclus == "embed" OR $type_inclus == "image") AND $largeur > 0 AND $hauteur > 0);
+			$raccourci = $vign ? ("<b>"._T('info_inclusion_vignette')."</b><br />") : '';
+
 			$raccourci .= "<div style='color: 333333'>"
 			. affiche_raccourci_doc('doc', $id_document, 'left')
 			. affiche_raccourci_doc('doc', $id_document, 'center')
 			. affiche_raccourci_doc('doc', $id_document, 'right')
 			. "</div>\n";
 	
-			if (($type_inclus == "embed" OR $type_inclus == "image") AND $largeur > 0 AND $hauteur > 0) {
+			if ($vign) {
 				$raccourci .= "<div style='padding:2px; ' class='arial1 spip_xx-small'>";
 				$raccourci .= "<b>"._T('info_inclusion_directe')."</b><br />";
 				$raccourci .= "<div style='color: 333333'>"
@@ -457,60 +460,47 @@ function afficher_case_document($id_document, $id, $script, $type, $deplier=fals
 				$raccourci .= "</div>";
 			}
 		}
-
-		$ret .= "\n<div style='padding:2px; ' class='arial1 spip_xx-small'>"
-			. $raccourci."</div>\n";
-
-		$legender = charger_fonction('legender', 'inc');
-		$ret .= $legender($id_document, $document, $script, $type, $id, "document$id_document", $deplier);
-
-		$ret .= fin_cadre_enfonce(true);
+		$ninclus = false;
+		$icone = 'doc-24.gif';
+		$style = 'e';
 
 	} else if ($mode == 'image') {
 
-	//
-	// Afficher une image inserable dans l'article
-	//
-	
-	  $ret .= debut_cadre_relief("image-24.gif", true, "", lignes_longues(typo($cadre),20), "document$id_document");
+		$icone = 'image-24.gif';
+		$style = 'r';
+		$ninclus = ($type_inclus !== 'image');
+		$doc = ($descriptif OR $titre) ? 'doc' : 'img';
 
-		//
-		// Afficher un apercu (pour les images)
-		//
-		if ($type_inclus == 'image') {
-			$ret .= "<div style='text-align: center; padding: 2px;'>\n";
-			$ret .= document_et_vignette($document, $url, true);
-			$ret .= "</div>\n";
-		}
-
-		//
-		// Preparer le raccourci a afficher sous la vignette ou sous l'apercu
-		//
-		$raccourci = "";
-		if (strlen($descriptif) > 0 OR strlen($titre) > 0)
-			$doc = 'doc';
-		else
-			$doc = 'img';
-
-		if ($doublon)
-			$raccourci .= affiche_raccourci_doc($doc, $id_document, '');
+		if (est_inclus($id_document))
+			$raccourci = affiche_raccourci_doc($doc, $id_document, '');
 		else {
-			$raccourci .=
+			$raccourci =
 				affiche_raccourci_doc($doc, $id_document, 'left')
 				. affiche_raccourci_doc($doc, $id_document, 'center')
 				. affiche_raccourci_doc($doc, $id_document, 'right');
 		}
 
-		$ret .= "\n<div style='padding:2px; ' class='arial1 spip_xx-small'>"
-			. $raccourci."</div>\n";
-
-
-		$legender = charger_fonction('legender', 'inc');
-		$ret .= $legender($id_document, $document, $script, $type, $id, "document$id_document", $deplier);
-		
-		$ret .= fin_cadre_relief(true);
 	}
-	return "<div>$ret</div>"; // on encapsule chaque document dans un container pour permettre son remplacement en ajax
+	$cadre = lignes_longues(typo($titre ? $titre : basename($fichier)), 20);
+	// encapsuler chaque document dans un container pour permettre son remplacement en ajax
+	return  '<div>'
+		. debut_cadre($style, $icone, '', $cadre, "document$id_document")
+		. ($ninclus ? '' :
+		   ("\n<div style='text-align: center'>"
+		    . $dist
+		    . document_et_vignette($document, '', true)
+		    . '</div>'
+		    . "\n<div class='verdana1' style='text-align: center; color: black;'>\n"
+		    . ($type_titre ? $type_titre : 
+		       ( _T('info_document').' '.majuscules($extension)))
+		    . "</div>"))
+		. $apercu
+		. "\n<div style='padding:2px; ' class='arial1 spip_xx-small'>"
+		. $raccourci
+		. "</div>\n"
+		. $legender($id_document, $document, $script, $type, $id, "document$id_document", $deplier)
+		. fin_cadre($style)
+		. '</div>'; 
 }
 
 // Etablit la liste des documents orphelins, c'est-a-dire qui ne sont lies
@@ -520,9 +510,7 @@ function afficher_case_document($id_document, $id, $script, $type, $deplier=fals
 // sinon eventuellement appeler avant une fonction nettoyer_liens_documents
 // http://doc.spip.org/@lister_les_documents_orphelins
 function lister_les_documents_orphelins() {
-	$s = sql_select("d.id_document, d.id_vignette",
-	"spip_documents AS d LEFT JOIN spip_documents_liens AS l ON d.id_document=l.id_document",
-	"(l.id_objet IS NULL)");
+	$s = sql_select("D.id_document, D.id_vignette", "spip_documents AS D LEFT JOIN spip_documents_liens AS L ON D.id_document=L.id_document", "(L.id_objet IS NULL)");
 
 	$orphelins = array();
 	while ($t = sql_fetch($s)) {
@@ -534,9 +522,7 @@ function lister_les_documents_orphelins() {
 	}
 
 	// les vignettes qui n'appartiennent a aucun document sont aussi orphelines
-	$s = sql_select("v.id_document",
-	"spip_documents AS v LEFT JOIN spip_documents AS d ON v.id_document=d.id_vignette",
-	"v.mode='vignette' AND d.id_document IS NULL");
+	$s = sql_select("V.id_document", "spip_documents AS V LEFT JOIN spip_documents AS D ON V.id_document=D.id_vignette", "V.mode='vignette' AND D.id_document IS NULL");
 	while ($t = sql_fetch($s))
 		$orphelins[$t['id_document']] = true;
 
