@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2009                                                *
+ *  Copyright (c) 2001-2010                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -18,7 +18,7 @@ function formulaires_editer_objet_traiter($type, $id='new', $id_parent=0, $lier_
 
 	$res = array();
 	$action_editer = charger_fonction("editer_$type",'action');
-	list($id,$err) = $action_editer();
+	list($id,$err) = $action_editer($id);
 	$id_table_objet = id_table_objet($type);
 	$res[$id_table_objet] = $id;
 	if ($err){
@@ -55,36 +55,23 @@ function formulaires_editer_objet_charger($type, $id='new', $id_parent=0, $lier_
 	$table_objet = table_objet($type);
 	$table_objet_sql = table_objet_sql($type);
 	$id_table_objet = id_table_objet($type);
-	$new = $id;
-
-	// nouveau ou pas ?
-	if (is_numeric($id))
-		$new = '';
-	else
-		$new = $id;
+	$new = !is_numeric($id);
 
 	// Appel direct dans un squelette
 	if (!$row) {
-		if ($select = charger_fonction($type."_select",'inc',true)){
-			$row = $select($id, $id_parent, $lier_trad);
+		if  (!$new OR $lier_trad) {
+		  	if ($select = charger_fonction($type."_select",'inc',true))
+				$row = $select($id, $id_parent, $lier_trad);
+			else $row = sql_fetsel('*',$table_objet_sql,$id_table_objet."=".intval($id));
+			if (!$new)
+				$md5 = controles_md5($row);
 		}
-		else {
-			$row = sql_fetsel('*',$table_objet_sql,$id_table_objet."=".intval($id));
-		}
-		if ($new OR !$row) {
+		if (!$row) {
 			$trouver_table = charger_fonction('trouver_table','base');
 			if ($desc = $trouver_table($table_objet))
-				foreach($desc['field'] as $k=>$v)
-					if (!isset($row[$k]))
-						$row[$k]='';
+				foreach($desc['field'] as $k=>$v) $row[$k]='';
 		}
-
-		// Ajouter les controles md5 si l'article existe
-		// et n'a pas ete passe en valeur
-		if (!$new)
-			$md5 = controles_md5($row);
 	}
-
 	// Gaffe: sans ceci, on ecrase systematiquement l'article d'origine
 	// (et donc: pas de lien de traduction)
 	$id = ($new OR $lier_trad)
@@ -95,10 +82,10 @@ function formulaires_editer_objet_charger($type, $id='new', $id_parent=0, $lier_
 	$contexte = $row;
 	if ($id_parent && (!isset($contexte['id_parent']) OR $new))
 		$contexte['id_parent']=$id_parent;
+
 	if ($config_fonc)
-		$contexte['config'] = $config = $config_fonc($row);
-	$att_text = " class='formo' "
-	. $GLOBALS['browser_caret']
+		$contexte['config'] = $config = $config_fonc($contexte);
+	$att_text = " class='textarea' "
 	. " rows='"
 	. ($config['lignes'] +15)
 	. "' cols='40'";
@@ -112,8 +99,6 @@ function formulaires_editer_objet_charger($type, $id='new', $id_parent=0, $lier_
 		unset($contexte['lang']);
 	}
 
-	$contexte['_browser_caret']=$GLOBALS['browser_caret'];
-
 	$contexte['_hidden'] = "<input type='hidden' name='editer_$type' value='oui' />\n" .
 		 (!$lier_trad ? '' :
 		 ("\n<input type='hidden' name='lier_trad' value='" .
@@ -130,7 +115,10 @@ function formulaires_editer_objet_charger($type, $id='new', $id_parent=0, $lier_
 		$contexte['extra'] = unserialize($contexte['extra']);
 	// preciser que le formulaire doit passer dans un pipeline
 	$contexte['_pipeline'] = array('editer_contenu_objet',array('type'=>$type,'id'=>$id));
+
 	// preciser que le formulaire doit etre securise auteur/action
+	// n'est plus utile lorsque l'action accepte l'id en argument direct
+	// on le garde pour compat 
 	$contexte['_action'] = array("editer_$type",$id);
 
 	return $contexte;
@@ -180,14 +168,12 @@ function editer_texte_recolle($texte, $att_text)
 	while (strlen($texte)>29*1024) {
 		$nombre ++;
 		list($texte1,$texte) = coupe_trop_long($texte);
-		$id = "document.getElementById('texte$nombre')";
-		$textes_supplement .= "<br />" . afficher_barre($id) .
+		$textes_supplement .= "<br />" .
 			"<textarea id='texte$nombre' name='texte_plus[$nombre]'$att_text>$texte1</textarea>\n";
 		}
 	return array($texte,$textes_supplement);
 }
 
-
 // Produit la liste des md5 d'un tableau de donnees, sous forme
 // de inputs html
 // http://doc.spip.org/@controles_md5
