@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2009                                                *
+ *  Copyright (c) 2001-2010                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -247,7 +247,7 @@ function forum_insert_noprevisu()
 
 	// antispam : si le champ au nom aleatoire verif_$hash n'est pas 'ok'
 	// on meurt
-	if (_request('verif_'._request('hash')) != 'ok') {
+	if (_request('verif_'.substr(_request('hash'),0,32)) != 'ok') {
 			tracer_erreur_forum('champ verif manquant');
 			return true;
 	}
