@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2009                                                *
+ *  Copyright (c) 2001-2010                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -31,10 +31,17 @@ function install_fichier_connexion($nom, $texte)
 // http://doc.spip.org/@install_connexion
 function install_connexion($adr, $port, $login, $pass, $base, $type, $pref, $ldap='')
 {
+	$adr = addslashes($adr);
+	$port = addslashes($port);
+	$login = addslashes($login);
+	$pass = addslashes($pass);
+	$base = addslashes($base);
+	$type = addslashes($type);
+	$pref = addslashes($pref);
+	$ldap = addslashes($ldap);
 	return "\$GLOBALS['spip_connect_version'] = 0.7;\n"
 	. "spip_connect_db("
-	. "'$adr','$port','$login','"
-	. addcslashes($pass, "'\\") . "','$base'"
+	. "'$adr','$port','$login','$pass','$base'"
 	. ",'$type', '$pref','$ldap');\n";
 
 }
@@ -156,7 +163,7 @@ function bouton_suivant($code = '') {
 	static $suivant = 0;
 	$id = 'suivant'.(($suivant>0)?strval($suivant):'');
 	$suivant +=1;
-	return "\n<span class='suivant'><input id='".$id."' type='submit' class='fondl'\nvalue=\"" .
+	return "\n<span class='suivant'><input id='".$id."' type='submit'\nvalue=\"" .
 		$code .
 		" >>\" /></span>\n";
 }
@@ -201,15 +208,24 @@ function info_progression_etape($en_cours,$phase,$dir, $erreur = false){
 		$debut++;
 	}
 	$aff_etapes .= "</ul>";
-	$aff_etapes .= "<br class='nettoyeur' /\n";
+	$aff_etapes .= "<br class='nettoyeur' />\n";
 	return $aff_etapes;
 }
 
 
 // http://doc.spip.org/@fieldset
-function fieldset($legend, $champs = array(), $horchamps='') {
-	$fieldset = "<fieldset>\n" .
-	($legend ? "<legend>".$legend."</legend>\n" : '');
+function fieldset($legend,  $champs = array(), $apres='', $avant='') {
+	return "<fieldset>\n" .
+	  $avant .
+	  ($legend ? "<legend>".$legend."</legend>\n" : '') .
+	  fieldset_champs($champs) .
+	  $apres .
+	  "</fieldset>\n";
+}
+
+function fieldset_champs($champs = array())
+  {
+	$fieldset = '';
 	foreach ($champs as $nom => $contenu) {
 		$type = isset($contenu['hidden']) ? 'hidden' : (preg_match(',^pass,', $nom) ? 'password' : 'text');
 		$class = isset($contenu['hidden']) ? '' : "class='formo' size='40' ";
@@ -230,45 +246,36 @@ function fieldset($legend, $champs = array(), $horchamps='') {
 							  .(preg_match(',^(pass|login),', $nom)?" autocomplete='off'":'') .	" />\n";
 		}
 	}
-	$fieldset .= "$horchamps</fieldset>\n";
 	return $fieldset;
 }
 
+function install_select_serveur()
+{
+	$options = array();
+	$dir = _DIR_RESTREINT . 'req/';
+	$d = @opendir($dir);
+	if (!$d) return array();
+	while ($f = readdir($d)) {
+		if ((preg_match('/^(.*)[.]php$/', $f, $s))
+		AND is_readable($f = $dir . $f)) {
+			require_once($f);
+			$s = $s[1];
+			$v = 'spip_versions_' . $s;
+			if (function_exists($v) AND $v()) {
+			  $titre = _T("install_select_type_$s");
+			  $options[$s] =  "<option value='$s'>"
+			    . ($titre ? $titre : $s)
+			    ."</option>";
+			} else spip_log("$s: portage indisponible");
+		}
+	}
+	sort($options);
+	return $options;
+}
+
 // http://doc.spip.org/@install_connexion_form
 function install_connexion_form($db, $login, $pass, $predef, $hidden, $etape)
 {
-
-	// demander les version dispo de postgres
-	if (include_spip('req/pg')) {
-		$versions = spip_versions_pg();
-		$pg = !!$versions;
-	}
-
-	// demander les version dispo de mysql
-	if (include_spip('req/mysql')) {
-		$versions = spip_versions_mysql();
-		$mysql = !!$versions;
-	}
-
-	// demander les version dispo de sqlite
-	if (include_spip('req/sqlite_generique')) {
-		$versions = spip_versions_sqlite();
-		$sqlite2 = in_array(2, $versions);
-		$sqlite3 = in_array(3, $versions);
-	}
-
-	// ne pas cacher le formulaire s'il n'a qu'un serveur :
-	// ca permet de se rendre compte de ce qu'on fait !
-/*
-	if (($pg + $mysql + $sqlite2 + $sqlite3) == 1){
-		if ($mysql) 	$server_db = 'mysql';
-		if ($pg) 		$server_db = 'pg';
-		if ($sqlite2) 	$server_db = 'sqlite2';
-		if ($sqlite3) 	$server_db = 'sqlite3';
-	} else
-*/
-
-	// le cacher si l'installation est predefinie avec un serveur particulier
 	if (is_string($predef[0])) {
 		$server_db = $predef[0];
 	}
@@ -317,20 +324,9 @@ function install_connexion_form($db, $login, $pass, $predef, $hidden, $etape)
 			// Passer l'avertissement SQLIte en  commentaire, on pourra facilement le supprimer par la suite sans changer les traductions.
 			. "<br /><small>(". _T('install_types_db_connus_avertissement') .')</small>'
 			.'</label>'		
-		. "\n<div style='text-align: center;'><select name='server_db' id='sql_serveur_db' >"
-		. ($mysql
-			? "\n<option value='mysql'>"._T('install_select_type_mysql')."</option>"
-			: '')
-		. ($pg
-			? "\n<option value='pg'>"._T('install_select_type_pgsql')."</option>"
-			: '')
-		. (($sqlite2)
-			? "\n<option value='sqlite2'>"._T('install_select_type_sqlite2')."</option>"
-			: '')
-		. (($sqlite3)
-			? "\n<option value='sqlite3'>"._T('install_select_type_sqlite3')."</option>"
-			: '')
-		   . "\n</select></div></fieldset>")
+		. "\n<div style='text-align: center;'><select name='server_db' id='sql_serveur_db' >\n"
+		.   join("\n", install_select_serveur())
+		. "\n</select></div></fieldset>")
 	)
 	. '<div id="install_adresse_base_hebergeur">'
 	. ($predef[1]
@@ -448,4 +444,14 @@ function install_etape_liste_bases($server_db, $disabled=array())
 
 	return array($checked, $bases);
 }
+
+function install_propager($hidden)
+{
+	$res = '';
+	foreach($hidden as $k) {
+		$v = htmlentities(_request($k));
+		$res .= "<input type='hidden' name='$k' value='$v' />";
+	}
+	return $res;
+}
 ?>
