@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2009                                                *
+ *  Copyright (c) 2001-2010                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -61,9 +61,31 @@ function taille_du_cache() {
 // ici on se contente de noter la date de mise a jour dans les metas
 // http://doc.spip.org/@suivre_invalideur
 function suivre_invalideur($cond, $modif=true) {
-	if ($modif) {
-		ecrire_meta('derniere_modif', time());
+	if (!$modif)
+		return;
+
+	// determiner l'objet modifie : forum, article, etc
+	if (preg_match(',id_([a-z]+),', $cond, $r))
+		$objet = $r[1];
+	// cas particulier des signatures
+	else if (strpos($cond, 'varia/pet'))
+		$objet = 'signature';
+
+	// stocker la date_modif_$objet (ne sert a rien pour le moment)
+	if (isset($objet))
+		ecrire_meta('derniere_modif_'.$objet, time());
+
+	// si $derniere_modif_invalide est un array('forum', 'signature')
+	// n'affecter la meta que si un de ces objets est modifie
+	if (is_array($GLOBALS['derniere_modif_invalide'])) {
+		if (in_array($objet, $GLOBALS['derniere_modif_invalide']))
+			ecrire_meta('derniere_modif', time());
 	}
+	// sinon, cas standard, toujours affecter la meta
+	else
+		ecrire_meta('derniere_modif', time());
+
+
 }
 
 
@@ -136,7 +158,8 @@ function appliquer_quota_cache() {
 			$n = purger_repertoire($dir,
 				array(
 					'atime' => time() - _AGE_CACHE_ATIME,
-					'limit' => $trop
+					'limit' => $trop,
+					'subdir' => true // supprimer les sous repertoire de session aussi
 				)
 			);
 			spip_log("$dir : $n/$trop caches supprimes [taille moyenne $taille]","invalideur");
