@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2009                                                *
+ *  Copyright (c) 2001-2010                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -29,6 +29,7 @@ function inc_lien_dist($lien, $texte='', $class='', $title='', $hlang='', $rel='
 		$texte = $lien['titre'];
 		if (!$class AND isset($lien['class'])) $class = $lien['class'];
 		$lang = isset($lien['lang']) ?$lien['lang'] : '';
+		$mime = isset($lien['mime']) ? " type='".$lien['mime']."'" : "";
 		$lien = $lien['url'];
 	}
 	if (substr($lien,0,1) == '#')  # ancres pures (internes a la page)
@@ -46,8 +47,14 @@ function inc_lien_dist($lien, $texte='', $class='', $title='', $hlang='', $rel='
 	$lang = ($hlang ? " hreflang='$hlang'" : '');
 
 	if ($title) $title = ' title="'.texte_backend($title).'"';
+
+	// rel=external pour les liens externes
+	if (preg_match(',^https?://,S', $lien)
+	AND false === strpos("$lien/", url_de_base()))
+		$rel = trim("$rel external");
 	if ($rel) $rel = " rel='$rel'";
-	$lien = "<a href='$lien' class='$class'$lang$title$rel>$texte</a>";
+
+	$lien = "<a href='$lien' class='$class'$lang$title$rel$mime>$texte</a>";
 
 	# ceci s'execute heureusement avant les tableaux et leur "|".
 	# Attention, le texte initial est deja echappe mais pas forcement
@@ -56,7 +63,7 @@ function inc_lien_dist($lien, $texte='', $class='', $title='', $hlang='', $rel='
 	return typo($lien, true, $connect);
 }
 
-// Regexp des raccouris, aussi utilisee pour la fusion de sauvegarde Spip
+// Regexp des raccourcis, aussi utilisee pour la fusion de sauvegarde Spip
 // Laisser passer des paires de crochets pour la balise multi
 // mais refuser plus d'imbrications ou de mauvaises imbrications
 // sinon les crochets ne peuvent plus servir qu'a ce type de raccourci
@@ -66,21 +73,34 @@ define('_RACCOURCI_LIEN', "/\[([^][]*?([[]\w*[]][^][]*)*)->(>?)([^]]*)\]/msS");
 function expanser_liens($texte, $connect='')
 {
 	$texte = pipeline('pre_liens', $texte);
-	$inserts = $regs = array();
+	$sources = $inserts = $regs = array();
 	if (preg_match_all(_RACCOURCI_LIEN, $texte, $regs, PREG_SET_ORDER)) {
 		$lien = charger_fonction('lien', 'inc');
 		foreach ($regs as $k => $reg) {
 
 			$inserts[$k] = '@@SPIP_ECHAPPE_LIEN_' . $k . '@@';
-			$texte = str_replace($reg[0], $inserts[$k], $texte);
+			$sources[$k] = $reg[0];
+			$texte = str_replace($sources[$k], $inserts[$k], $texte);
 
 			list($titre, $bulle, $hlang) = traiter_raccourci_lien_atts($reg[1]);
 			$r = $reg[count($reg)-1];
+			// la mise en lien automatique est passee par la a tort !
+			// corrigeons pour eviter d'avoir un <a...> dans un href...
+			if (strncmp($r,'<a',2)==0){
+				$href = extraire_attribut($r, 'href');
+				// remplacons dans la source qui peut etre reinjectee dans les arguments
+				// d'un modele
+				$sources[$k] = str_replace($r,$href,$sources[$k]);
+				// et prenons le href comme la vraie url a linker
+				$r = $href;
+			}
 			$regs[$k] = $lien($r, $titre, '', $bulle, $hlang, '', $connect);
 		}
 	}
 
-	$texte = traiter_modeles($texte, false, false, $connect);
+	// on passe a traiter_modeles la liste des liens reperes pour lui permettre
+	// de remettre le texte d'origine dans les parametres du modele
+	$texte = traiter_modeles($texte, false, false, $connect, array($inserts, $sources));
  	$texte = corriger_typo($texte);
 	$texte = str_replace($inserts, $regs, $texte);
 	return $texte;
@@ -99,7 +119,7 @@ function nettoyer_raccourcis_typo($texte, $connect='')
 			if (!$titre) {
 				$match = typer_raccourci($reg[count($reg)-1]);
 				@list($type,,$id,,,,) = $match;
-				$titre = traiter_raccourci_titre($id, $type, $connect);
+				if ($type) $titre = traiter_raccourci_titre($id, $type, $connect);
 				$titre = $titre ? $titre['titre'] : $match[0];
 			}
 			$titre = corriger_typo(supprimer_tags($titre));
@@ -250,6 +270,19 @@ function traiter_lien_explicite ($ref, $texte='', $pour='url', $connect='')
 
 	$lien = entites_html(trim($ref));
 
+	// Liens explicites
+	if (!$texte) {
+		$texte = str_replace('"', '', $lien);
+		// evite l'affichage de trops longues urls.
+		// personnalisation possible dans mes_options
+		$long_url = defined('_MAX_LONG_URL') ? _MAX_LONG_URL : 40;
+		$coupe_url = defined('_MAX_COUPE_URL') ? _MAX_COUPE_URL : 35;
+		if (strlen($texte)>$long_url) {
+			$texte = substr($texte,0,$coupe_url).'...';
+		}
+		$texte = "<html>".quote_amp($texte)."</html>";
+	}
+
 	// petites corrections d'URL
 	if (preg_match('/^www\.[^@]+$/S',$lien))
 		$lien = "http://".$lien;
@@ -260,13 +293,6 @@ function traiter_lien_explicite ($ref, $texte='', $pour='url', $connect='')
 	
 	if ($pour == 'url') return $lien;
 
-	// Liens explicites
-	if (!$texte) {
-		$texte = str_replace('"', '', $lien);
-		if (strlen($texte)>40) $texte = substr($texte,0,35).'...';
-		$texte = "<html>".quote_amp($texte)."</html>";
-	}
-
 	if ($pour == 'titre') return $texte;
 
 	return array('url' => $lien, 'titre' => $texte);
@@ -293,11 +319,20 @@ function traiter_lien_implicite ($ref, $texte='', $pour='url', $connect='')
 	}
 	if ($pour === 'url') return $url;
 	$r = traiter_raccourci_titre($id, $type, $connect);
-	if ($r) $r['class'] =  'spip_in';
+	if ($r) $r['class'] =  ($type == 'site')?'spip_out':'spip_in';
 	if ($texte = trim($texte)) $r['titre'] = $texte;
 	if (!@$r['titre']) $r['titre'] =  _T($type) . " $id";
 	if ($pour=='titre') return $r['titre'];
 	$r['url'] = $url;
+
+	// dans le cas d'un lien vers un doc, ajouter le type='mime/type'
+	if ($type == 'document'
+	AND $mime = sql_getfetsel('mime_type', 'spip_types_documents',
+			"extension IN (SELECT extension FROM spip_documents where id_document =".sql_quote($id).")",
+			'','','','',$connect)
+	)
+		$r['mime'] = $mime;
+
 	return $r;
 }
 
@@ -357,7 +392,7 @@ define('_RACCOURCI_MODELE',
 define('_RACCOURCI_MODELE_DEBUT', '@^' . _RACCOURCI_MODELE .'@is');
 
 // http://doc.spip.org/@traiter_modeles
-function traiter_modeles($texte, $doublons=false, $echap='', $connect='') {
+function traiter_modeles($texte, $doublons=false, $echap='', $connect='', $liens = null) {
 	// preserver la compatibilite : true = recherche des documents
 	if ($doublons===true)
 		$doublons = array('documents'=>array('doc','emb','img'));
@@ -394,7 +429,11 @@ function traiter_modeles($texte, $doublons=false, $echap='', $connect='') {
 				$texte .= preg_replace(',[|][^|=]*,s',' ',$params);
 			# version normale
 			else {
-				$modele = inclure_modele($type, $id, $params, $lien);
+				// si un tableau de liens a ete passe, reinjecter le contenu d'origine
+				// dans les parametres, plutot que les liens echappes
+				if (!is_null($liens))
+					$params = str_replace($liens[0], $liens[1], $params);
+			  $modele = inclure_modele($type, $id, $params, $lien, $connect);
 				// en cas d'echec, 
 				// si l'objet demande a une url, 
 				// creer un petit encadre vers elle
@@ -408,8 +447,15 @@ function traiter_modeles($texte, $doublons=false, $echap='', $connect='') {
 						  . '">'
 						  .sinon($lien['titre'], _T('ecrire:info_sans_titre'))
 						  ."</a>";
+					else {
+						$modele = "";
+						if (test_espace_prive()) {
+							$modele = entites_html(substr($texte,$a,$cherche));
+							if (!is_null($liens))
+								$modele = "<pre>".str_replace($liens[0], $liens[1], $modele)."</pre>";
+						}
+					}
 				}
-
 				// le remplacer dans le texte
 				if ($modele !== false) {
 					$modele = protege_js_modeles($modele);
@@ -454,7 +500,7 @@ function traiter_raccourci_ancre($letexte)
 // cf. http://fr.wikipedia.org/wiki/Wikip%C3%A9dia:Conventions_sur_les_titres
 
 define('_RACCOURCI_GLOSSAIRE', "/\[\?+\s*([^][<>]+)\]/S");
-define('_RACCOURCI_GLOSES', '/^([^|#{]*\w[^|#{]*)([^#]*)(#([^|{}]*))?(.*)$/');
+define('_RACCOURCI_GLOSES', '/^([^|#{]*\w[^|#{]*)([^#]*)(#([^|{}]*))?(.*)$/S');
 
 // http://doc.spip.org/@traiter_raccourci_glossaire
 function traiter_raccourci_glossaire($texte)
