@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2009                                                *
+ *  Copyright (c) 2001-2010                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -44,7 +44,7 @@ function modifier_contenu($type, $id, $options, $c=false, $serveur='') {
 	}
 
 	// Securite : certaines variables ne sont jamais acceptees ici
-	// car elles ne relevent pas de autoriser(article, modifier) ;
+	// car elles ne relevent pas de autoriser(xxx, modifier) ;
 	// il faut passer par instituer_XX()
 	// TODO: faut-il passer ces variables interdites
 	// dans un fichier de description separe ?
@@ -142,6 +142,7 @@ function modifier_contenu($type, $id, $options, $c=false, $serveur='') {
 					'id_objet' => $id,
 					'champs' => $options['champs'],
 					'serveur' => $serveur,
+					'action' => 'modifier'
 				),
 				'data' => $champs
 			)
@@ -191,8 +192,9 @@ function marquer_doublons_documents($champs,$id,$type,$id_table_objet,$table_obj
 		$res = sql_select("id_document", "spip_documents", $in_liste);
 		while ($row = sql_fetch($res)) {
 			// Creer le lien s'il n'existe pas deja
-			sql_insertq("spip_documents_liens", array('id_objet'=>$id, 'objet'=>$type, 'id_document' => $row['id_document'], 'vu' => 'oui'));
-			sql_updateq("spip_documents_liens", array("vu" => 'oui'), "id_objet=$id AND objet=".sql_quote($type)." AND id_document=" . $row['id_document']);
+			if (!sql_updateq("spip_documents_liens", array("vu" => 'oui'), "id_objet=$id AND objet=".sql_quote($type)." AND id_document=" . $row['id_document'])) {
+				sql_insertq("spip_documents_liens", array('id_objet'=>$id, 'objet'=>$type, 'id_document' => $row['id_document'], 'vu' => 'oui'));
+			}
 		}
 	}
 }
@@ -342,7 +344,7 @@ function revision_forum($id_forum, $c=false) {
 		),
 		$c);
 
-	$t = $t["id_thread"];
+	$id_thread = $t["id_thread"];
 	$cles = array();
 	foreach (array('id_article', 'id_rubrique', 'id_syndic', 'id_breve')
 		 as $k) {
@@ -353,13 +355,15 @@ function revision_forum($id_forum, $c=false) {
 	// (non autorise en standard mais utile pour des crayons)
 	// on deplace tout le thread {sauf les originaux}.
 	if ($cles) {
-		sql_updateq("spip_forum", $cles, "id_thread=$t AND statut!='original'");
+		sql_updateq("spip_forum", $cles, "id_thread=$id_thread AND statut!='original'");
 		// on n'affecte pas $r, car un deplacement ne change pas l'auteur
 	}
 
 	// s'il y a vraiment eu une modif, on
-	// enregistre le nouveau date_thread
-	if ($r) {
+	// enregistre le nouveau date_thread,
+	// si le message est bien publie ou si c'est un thread non public
+	if ($r AND 
+		($t['statut'] == 'publie' OR !sql_countsel("spip_forum", "statut='publie' AND id_thread=".intval($id_thread)))) {
 		// on ne stocke ni le numero IP courant ni le nouvel id_auteur
 		// dans le message modifie (trop penible a l'usage) ; mais du
 		// coup attention a la responsabilite editoriale
@@ -368,7 +372,7 @@ function revision_forum($id_forum, $c=false) {
 		*/
 
 		// & meme ca ca pourrait etre optionnel
-		sql_updateq("spip_forum", array("date_thread" => date('Y-m-d H:i:s')), "id_thread=".$t);
+		sql_updateq("spip_forum", array("date_thread" => date('Y-m-d H:i:s')), "id_thread=".intval($id_thread));
 	}
 }
 
