@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2009                                                *
+ *  Copyright (c) 2001-2010                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -56,7 +56,7 @@ function afficher_onglets_pages($ordre,$onglets){
 	}
 	$res = "<ul class='tabs-nav'>$res</ul>";
 	foreach((_INTERFACE_ONGLETS ? array_keys($ordre):array_keys($onglets)) as $id){
-		$res .= "<div id='$id' class='tabs-container'>" . $onglets[$id] . "<br class='nettoyeur' /></div>";
+		$res .= "<div id='$id' class='tabs-container'>" . $onglets[$id] . "<div class='nettoyeur'></div></div>";
 	}
 	$onglet_compteur++;
 	return "<div class='boite_onglets' id='boite_onglet_$onglet_compteur'>$res</div>"
@@ -86,7 +86,7 @@ function debut_cadre($style, $icone = "", $fonction = "", $titre = "", $id="", $
 	$style_cadre = " style='";
 	if ($spip_display != 1 AND $spip_display != 4 AND strlen($icone) > 1) {
 		$style_gauche = "padding-$spip_lang_left: 38px;";
-		$style_cadre .= "margin-top: 20px;'";
+		$style_cadre .= "'";
 	} else {
 		$style_cadre .= "'";
 		$style_gauche = '';
@@ -296,7 +296,7 @@ function fin_boite_info($return=false) {
 function bloc_des_raccourcis($bloc) {
 	global $spip_display;
 
-	return "\n<div>&nbsp;</div>"
+	return "\n"
 	. creer_colonne_droite('',true)
 	. debut_cadre_enfonce('',true)
 	. (($spip_display != 4)
@@ -822,7 +822,7 @@ function debut_gauche($rubrique = "accueil", $return=false) {
 // http://doc.spip.org/@fin_gauche
 function fin_gauche()
 {
-	return "</div></div><br class='nettoyeur' />";
+	return "</div></div><div class='nettoyeur'></div>";
 }
 
 //
@@ -861,7 +861,7 @@ function debut_droite($rubrique="", $return= false) {
 	$res .= creer_colonne_droite($rubrique, true)
 	. "</div>";
 
-	$res .= "\n<div id='contenu' class='serif'>";
+	$res .= "\n<div id='contenu'>";
 
 	// touche d'acces rapide au debut du contenu : z
 	// Attention avant c'etait 's' mais c'est incompatible avec
@@ -925,16 +925,6 @@ function fin_page()
 		$chrono = chrono_requete($GLOBALS['tableau_des_temps']);
 	} else $chrono = '';
 
-	// cf. public/assembler, fonction f_msie()
-	// test si MSIE et sinon quitte
-	if (
-		strpos(strtolower($_SERVER['HTTP_USER_AGENT']), 'msie')
-		AND preg_match('/MSIE /i', $_SERVER['HTTP_USER_AGENT'])
-		AND $msiefix = charger_fonction('msiefix', 'inc')
-	)
-		$fix_png = presentation_msiefix();
-	else
-		$fix_png = '';
 
 	return debut_grand_cadre(true)
 	. (($spip_display == 4)
@@ -944,14 +934,16 @@ function fin_page()
 			.  _T("access_interface_graphique")
 			. "</a></div>")
 		: ("<div style='text-align: right; ' class='verdana1 spip_xx-small'>"
+			. info_maj_spip()
 			. info_copyright()
 			. "<br />"
-			. _T('info_copyright_doc')
+			. _T('info_copyright_doc',
+				array('spipnet' => $GLOBALS['home_server']
+					. '/' .    $GLOBALS['spip_lang']))
 			. '</div>'))
 
 	. fin_grand_cadre(true)
 	. "</div>\n" // cf. div centered ouverte dans conmmencer_page()
-	. $fix_png
 	. $GLOBALS['rejoue_session']
 	. '<div style="background-image: url(\''
 	. generer_url_action('cron')
@@ -961,6 +953,26 @@ function fin_page()
 	. "</body></html>\n";
 }
 
+function info_maj_spip(){
+
+	$maj = $GLOBALS['meta']['info_maj_spip'];
+	if (!$maj)
+		return "";
+
+	$maj = explode('|',$maj);
+	// c'est une ancienne notif, on a fait la maj depuis !
+	if ($GLOBALS['spip_version_branche']!==reset($maj))
+		return "";
+
+	if (!autoriser('webmestre'))
+		return "";
+
+	array_shift($maj);
+	$maj = implode('|',$maj);
+
+	return "<br />$maj</br>";
+}
+
 // http://doc.spip.org/@info_copyright
 function info_copyright() {
 	global $spip_version_affichee, $spip_lang;
