@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2009                                                *
+ *  Copyright (c) 2001-2010                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -138,10 +138,17 @@ function recherche_en_base($recherche='', $tables=NULL, $options=array(), $serve
 	include_spip('inc/charsets');
 	$recherche = translitteration($recherche);
 
-	$preg = '/'.str_replace('/', '\\/', $recherche).'/' . $options['preg_flags'];
+	$is_preg = false;
+	if (substr($recherche,0,1)=='/' AND substr($recherche,-1,1)=='/'){
+		// c'est une preg
+		$preg = $recherche.$options['preg_flags'];
+		$is_preg = true;
+	}
+	else
+		$preg = '/'.str_replace('/', '\\/', $recherche).'/' . $options['preg_flags'];
 	// Si la chaine est inactive, on va utiliser LIKE pour aller plus vite
 	// ou si l'expression reguliere est invalide
-	if (preg_quote($recherche, '/') == $recherche
+	if (!$is_preg
 	OR (@preg_match($preg,'')===FALSE) ) {
 		$methode = 'LIKE';
 		$u = $GLOBALS['meta']['pcre_u'];
@@ -178,7 +185,7 @@ function recherche_en_base($recherche='', $tables=NULL, $options=array(), $serve
 		
 	} else {
 		$methode = 'REGEXP';
-		$q = sql_quote($recherche);
+		$q = sql_quote(substr($recherche,1,-1));
 	}
 
 	$jointures = $options['jointures']
@@ -277,18 +284,23 @@ function recherche_en_base($recherche='', $tables=NULL, $options=array(), $serve
 				array_merge($options, array('jointures' => false))
 			)
 		) {
-			foreach ($joints as $jtable => $jj) {
-				$it = id_table_objet($table);
-				$ij =  id_table_objet($jtable);
-				$table_sql = preg_replace('/^spip_/', '', table_objet_sql($table));
-				$jtable_sql = preg_replace('/^spip_/', '', table_objet_sql($jtable));				
-				if ($jtable == 'document')
-					$s = sql_select("id_objet as $it, $ij", "spip_documents_liens", array("objet='$table'",sql_in('id_'.${jtable}, array_keys($jj))), '','','','',$serveur);
+			foreach ($joints as $table_liee => $ids_trouves) {
+				if (!$rechercher_joints = charger_fonction("rechercher_joints_${table}_${table_liee}","inc",true)){
+					$cle_depart = id_table_objet($table);
+					$cle_arrivee =  id_table_objet($table_liee);
+					$table_sql = preg_replace('/^spip_/', '', table_objet_sql($table));
+					$table_liee_sql = preg_replace('/^spip_/', '', table_objet_sql($table_liee));
+					if ($table_liee == 'document')
+						$s = sql_select("id_objet as $cle_depart, $cle_arrivee", "spip_documents_liens", array("objet='$table'",sql_in('id_'.${table_liee}, array_keys($ids_trouves))), '','','','',$serveur);
+					else
+						$s = sql_select("$cle_depart,$cle_arrivee", "spip_${table_liee_sql}_${table_sql}", sql_in('id_'.${table_liee}, array_keys($ids_trouves)), '','','','',$serveur);
+				}
 				else
-					$s = sql_select("$it,$ij", "spip_${jtable_sql}_${table_sql}", sql_in('id_'.${jtable}, array_keys($jj)), '','','','',$serveur);
-				while ($t = sql_fetch($s)) {
-					$id = $t[$it];
-					$joint = $jj[$t[$ij]];
+					list($cle_depart,$cle_arrivee,$s) = $rechercher_joints($table,$table_liee,array_keys($ids_trouves), $serveur);
+
+				while ($t = is_array($s)?array_shift($s):sql_fetch($s)) {
+					$id = $t[$cle_depart];
+					$joint = $ids_trouves[$t[$cle_arrivee]];
 					if (!isset($results[$table]))
 						$results[$table] = array();
 					if (!isset($results[$table][$id]))
@@ -297,10 +309,10 @@ function recherche_en_base($recherche='', $tables=NULL, $options=array(), $serve
 						$results[$table][$id]['score'] += $joint['score'];
 					if ($joint['champs'])
 					foreach($joint['champs'] as $c => $val)
-						$results[$table][$id]['champs'][$jtable.'.'.$c] = $val;
+						$results[$table][$id]['champs'][$table_liee.'.'.$c] = $val;
 					if ($joint['matches'])
 					foreach($joint['matches'] as $c => $val)
-						$results[$table][$id]['matches'][$jtable.'.'.$c] = $val;
+						$results[$table][$id]['matches'][$table_liee.'.'.$c] = $val;
 				}
 			}
 		}
