@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2009                                                *
+ *  Copyright (c) 2001-2010                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -45,16 +45,15 @@ function aff_statistique_visites_popularite($serveur, $id_article, &$classement,
 	}
 
 	return !$out ? '' : (
-		"<br />\n"
-		."<div class='iconeoff' style='padding: 5px'>\n"
-		."<div class='verdana1 spip_x-small'>"
+		"<div class='cadre cadre-e'>\n"
+		."<div class='cadre_padding verdana1 spip_x-small'>"
 		.typo(_T('info_visites_plus_populaires'))
 		."<ul class='classement'>"
 		.$out
 
 		."</ul>"
-
-		."<b>"._T('info_comment_lire_tableau')."</b><br />"._T('texte_comment_lire_tableau')
+		
+		."<div class='arial11'><b>"._T('info_comment_lire_tableau')."</b><br />"._T('texte_comment_lire_tableau')."</div>"
 
 		."</div>"
 		."</div>");
@@ -101,8 +100,8 @@ function aff_statistique_visites_par_visites($serveur='', $id_article=0, $classe
 
 	if (!$res) return '';
 
-	return "<br /><div class='iconeoff' style='padding: 5px;'>"
-	  . "<div style='overflow:hidden;' class='verdana1 spip_x-small'>"
+	return "<div class='cadre cadre-e' style='padding: 5px;'>"
+	  . "<div class='cadre_padding verdana1 spip_x-small'>"
 	  . typo(_T('info_affichier_visites_articles_plus_visites'))
 	  . "<ul class='classement'>"
 	  . $res
@@ -164,9 +163,15 @@ function statistiques_tous($log, $id_article, $table, $where, $order, $serveur,
 {
 	$r = array_keys($log);
 	$date_fin = max($r);
+	$today = strtotime(date('Y-m-d 01:00:01'));
+	if ($today-$date_fin>$interval){
+		$log[$today] = 0;
+		$r = array_keys($log);
+		$date_fin = max($r);
+	}
 	$date_debut = min($r);
 	$date_premier = sql_getfetsel("UNIX_TIMESTAMP($order) AS d", $table, $where, '', $order, 1,'',$serveur);
-	$last = (time()-$date_fin>$interval) ? 0 : $log[$date_fin];
+	$last = $log[$date_fin];
 	$max = max($log);
 	$maxgraph = maxgraph($max);
 	$rapport = 200 / $maxgraph;
