@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2009                                                *
+ *  Copyright (c) 2001-2010                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -27,6 +27,9 @@ function analyser_backend($rss, $url_syndic='') {
 
 	$rss = pipeline('pre_syndication', $rss);
 
+	// si true, les URLs de type feedburner sont dereferencees
+	define('_SYNDICATION_DEREFERENCER_URL', false);
+
 	// Echapper les CDATA
 	$echappe_cdata = array();
 	if (preg_match_all(',<!\[CDATA\[(.*)]]>,Uims', $rss,
@@ -59,9 +62,11 @@ function analyser_backend($rss, $url_syndic='') {
 	} else
 		$les_auteurs_du_site = '';
 
-	if (preg_match(',<([^>]*xml:)?lang(uage)?'.'>([^<>]+)<,i',
-	$header, $match))
+	if (preg_match(',<([^>]*xml[:])?lang(uage)?'.'>([^<>]+)<,i', $header, $match))
 		$langue_du_site = $match[3];
+	// atom
+	elseif (preg_match(',<feed\s[^>]*xml:lang=[\'"]([^<>\'"]+)[\'"],i', $header, $match))
+		$langue_du_site = $match[1];
 
 	// Attention en PCRE 6.7 preg_match_all casse sur un backend avec de gros <content:encoded>
 	$items = preg_split(',<(item|entry)\b.*>,Uims', $rss);
@@ -87,7 +92,11 @@ function analyser_backend($rss, $url_syndic='') {
 		$item, $regs) AND preg_match(',^(true|1)?$,i',
 		extraire_attribut($regs[0], 'ispermalink')))
 			$data['url'] = $regs[1];
-
+		// contourner les redirections feedburner
+		else if (_SYNDICATION_DEREFERENCER_URL
+		AND preg_match(',<feedburner:origLink>(.*)<,Uims',
+		$item, $regs))
+			$data['url'] = $regs[1];
 		// <link>, plus classique
 		else if (preg_match(
 		',<link[^>]*[[:space:]]rel=["\']?alternate[^>]*>(.*)</link>,Uims',
@@ -354,10 +363,12 @@ function ajouter_tags($matches, $item) {
 		}
 		else if (
 			// cas atom1, a faire apres flickr
-			$scheme = extraire_attribut($match[0], 'scheme')
-			AND $term = extraire_attribut($match[0], 'term')
+			$term = extraire_attribut($match[0], 'term')
 		) {
+			if ($scheme = extraire_attribut($match[0], 'scheme'))
 				$url = suivre_lien($scheme,$term);
+			else
+				$url = $term;
 		}
 		else {
 			# type delicious.com
