@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2009                                                *
+ *  Copyright (c) 2001-2010                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -101,11 +101,11 @@ function pipeline($action, $val=null) {
 
 	// chargement initial des fonctions mises en cache, ou generation du cache
 	if (!$charger) {
-		if (!($ok = @is_readable($charger = _DIR_TMP."charger_pipelines.php"))) {
+		if (!($ok = @is_readable($charger = _CACHE_PIPELINES))) {
 			include_spip('inc/plugin');
 			// generer les fichiers php precompiles
 			// de chargement des plugins et des pipelines
-			verif_plugin();
+			actualise_plugins_actifs();
 			if (!($ok = @is_readable($charger)))
 				spip_log("fichier $charger pas cree");
 		}
@@ -124,7 +124,7 @@ function pipeline($action, $val=null) {
 		include_spip('inc/plugin');
 		// on passe $action en arg pour creer la fonction meme si le pipe
 		// n'est defini nul part ; vu qu'on est la c'est qu'il existe !
-		verif_plugin(strtolower($action));
+		actualise_plugins_actifs(strtolower($action));
 		spip_log("fonction $fonc absente : pipeline desactive");
 	}
 
@@ -143,57 +143,8 @@ function pipeline($action, $val=null) {
 //
 // http://doc.spip.org/@spip_log
 function spip_log($message, $logname=NULL, $logdir=NULL, $logsuf=NULL) {
-	static $compteur = array();
-	global $nombre_de_logs, $taille_des_logs;
-
-	if (is_null($logname))
-		$logname = defined('_FILE_LOG') ? _FILE_LOG : 'spip';
-	if (!isset($compteur[$logname])) $compteur[$logname] = 0;
-	if (($logname != 'maj') AND
-	    ( $compteur[$logname]++ > _MAX_LOG || !$nombre_de_logs || !$taille_des_logs))
-		return;
-
-	$logfile = ($logdir===NULL ? _DIR_LOG : $logdir)
-	  . (test_espace_prive()?'prive_':'') //distinguer les logs prives et publics
-	  . ($logname)
-	  . ($logsuf===NULL ? _FILE_LOG_SUFFIX : $logsuf);
-
-	// si spip_log() dans mes_options, poser dans spip.log
-	if (!defined('_DIR_LOG'))
-		$logfile = _DIR_RACINE._NOM_TEMPORAIRES_INACCESSIBLES.$logname.'.log';
-
-	$rotate = 0;
-	$pid = '(pid '.@getmypid().')';
-
-	// accepter spip_log( Array )
-	if (!is_string($message)) $message = var_export($message, true);
-
-	$m = date("M d H:i:s").' '.$GLOBALS['ip'].' '.$pid.' '
-		.preg_replace("/\n*$/", "\n", $message);
-
-
-	if (@is_readable($logfile)
-	AND (!$s = @filesize($logfile) OR $s > $taille_des_logs * 1024)) {
-		$rotate = $nombre_de_logs;
-		$m .= "[-- rotate --]\n";
-	}
-
-	$f = @fopen($logfile, "ab");
-	if ($f) {
-		fputs($f, ($logname!==NULL) ? $m : str_replace('<','&lt;',$m));
-		fclose($f);
-	}
-
-	if ($rotate-- > 0) {
-		spip_unlink($logfile . '.' . $rotate);
-		while ($rotate--) {
-			@rename($logfile . ($rotate ? '.' . $rotate : ''), $logfile . '.' . ($rotate + 1));
-		}
-	}
-
-	// Dupliquer les erreurs specifiques dans le log general
-	if ($logname !== _FILE_LOG)
-		spip_log($logname=='maj' ? 'cf maj.log' : $message);
+	$log = charger_fonction('log', 'inc');
+	$log( $message, $logname, $logdir, $logsuf);
 }
 
 // Renvoie le _GET ou le _POST emis par l'utilisateur
@@ -333,10 +284,11 @@ function ancre_url($url, $ancre) {
 // pour le nom du cache, les types_urls et self
 //
 // http://doc.spip.org/@nettoyer_uri
-function nettoyer_uri()
+function nettoyer_uri($reset = null)
 {
 	static $done = false;
 	static $propre = '';
+	if (!is_null($reset)) return $propre=$reset;
 	if ($done) return $propre;
 	$done = true;
 
@@ -394,11 +346,22 @@ function test_espace_prive() {
 	return defined('_ESPACE_PRIVE') ? _ESPACE_PRIVE : false;
 }
 
+/**
+ * Verifie la presence d'un plugin active, identifie par son prefix
+ *
+ *
+ * @param string $plugin
+ * @return bool
+ */
+function test_plugin_actif($plugin){
+	return ($plugin AND defined('_DIR_PLUGIN_'.strtoupper($plugin)))? true:false;
+}
+
 //
 // Traduction des textes de SPIP
 //
 // http://doc.spip.org/@_T
-function _T($texte, $args=array()) {
+function _T($texte, $args=array(), $class='') {
 
 	static $traduire=false ;
 
@@ -409,27 +372,33 @@ function _T($texte, $args=array()) {
 	$text = $traduire($texte,$GLOBALS['spip_lang']);
 
 	if (!strlen($text))
-		// pour les chaines non traduites
+		// pour les chaines non traduites, assurer un service minimum
 		$text = str_replace('_', ' ',
 			 (($n = strpos($texte,':')) === false ? $texte :
 				substr($texte, $n+1)));
 
-	if (is_array($args))
-	foreach ($args as $name => $value)
-		$text = str_replace ("@$name@", $value, $text);
-
-	return $text;
+	return _L($text, $args, $class);
 
 }
 
-// chaines en cours de traduction
+// Remplacer les variables @....@ par leur valeur dans une chaine de langue.
+// Aussi appelee quand une chaine n'est pas encore dans les fichiers de langue
 // http://doc.spip.org/@_L
-function _L($text, $args=array()) {
-	if (is_array($args))
-	foreach ($args as $name => $value)
-		$text = str_replace ("@$name@", $value, $text);
+function _L($text, $args=array(), $class=NULL) {
 
-	if ($GLOBALS['test_i18n'])
+	if (is_array($args)) {
+		foreach ($args as $name => $value) {
+			if ($class)
+				$value = "<span class='$class'>$value</span>";
+			$t = str_replace ("@$name@", $value, $text);
+			if ($text !== $t) {unset($args[$name]); $text = $t;}
+		}
+		// Si des variables n'ont pas ete inserees, le signaler
+		// (chaines de langues pas a jour)
+		if ($args) spip_log("$text:  variables inutilisees " . join(', ', $args));
+	}
+
+	if ($GLOBALS['test_i18n'] AND $class===NULL)
 		return "<span style='color:red;'>$text</span>";
 	else
 		return $text;
@@ -451,20 +420,28 @@ function joli_repertoire($rep) {
 // spip_timer : on l'appelle deux fois et on a la difference, affichable
 //
 // http://doc.spip.org/@spip_timer
-function spip_timer($t='rien') {
+function spip_timer($t='rien', $raw = false) {
 	static $time;
 	$a=time(); $b=microtime();
 	// microtime peut contenir les microsecondes et le temps
 	$b=explode(' ',$b);
 	if (count($b)==2) $a = end($b); // plus precis !
 	$b = reset($b);
-	if (isset($time[$t])) {
-		$p = $a + $b - $time[$t];
-		unset($time[$t]);
-		if ($p>0.01)	return sprintf("%.3fs", $p);
-		else					return sprintf("%.1fms", $p*1000);
-	} else
+	if (!isset($time[$t])) {
 		$time[$t] = $a + $b;
+	} else {
+		$p = ($a + $b - $time[$t]) * 1000;
+		unset($time[$t]);
+#			echo "'$p'";exit;
+		if ($raw) return $p;
+		if ($p < 1000)
+			$s = '';
+		else {
+			$s = sprintf("%d ", $x = floor($p/1000));
+			$p -= ($x*1000);
+		}
+		return $s . sprintf("%.3f ms", $p);
+	}
 }
 
 
@@ -508,15 +485,17 @@ function action_cron() {
 
 // http://doc.spip.org/@cron
 function cron ($gourmand=false, $taches= array()) {
-
-	// Si base inaccessible, laisser tomber.
-	if (!spip_connect()) return false;
+	if (!defined(_CRON_DELAI_GOURMAND))
+		define('_CRON_DELAI_GOURMAND',60);
+	if (!defined(_CRON_DELAI))
+		define('_CRON_DELAI',is_int($gourmand) ? $gourmand : 2);
 
 	// Si on est gourmand, ou si le fichier gourmand n'existe pas
 	// ou est trop vieux (> 60 sec), on va voir si un cron est necessaire.
 	// Au passage si on est gourmand on le dit aux autres
-	if (spip_touch(_DIR_TMP.'cron.lock-gourmand', 60, $gourmand)
-	OR ($gourmand!==false)) {
+	if (!_CRON_DELAI_GOURMAND
+	 OR spip_touch(_DIR_TMP.'cron.lock-gourmand', _CRON_DELAI_GOURMAND, $gourmand)
+	 OR ($gourmand!==false)) {
 
 	// Le fichier cron.lock indique la date de la derniere tache
 	// Il permet d'imposer qu'il n'y ait qu'une tache a la fois
@@ -524,8 +503,11 @@ function cron ($gourmand=false, $taches= array()) {
 	// ca soulage le serveur et ca evite
 	// les conflits sur la base entre taches.
 
-	if (spip_touch(_DIR_TMP.'cron.lock',
-			(is_int($gourmand) ? $gourmand : 2))) {
+	if (!_CRON_DELAI 
+	  OR spip_touch(_DIR_TMP.'cron.lock',_CRON_DELAI)) {
+			// Si base inaccessible, laisser tomber.
+			if (!spip_connect()) return false;
+
 			$genie = charger_fonction('genie', 'inc', true);
 			if ($genie) {
 				$genie($taches);
@@ -606,24 +588,25 @@ function _chemin($dir_path=NULL){
 		if (strlen($GLOBALS['dossier_squelettes']))
 			foreach (array_reverse(explode(':', $GLOBALS['dossier_squelettes'])) as $d)
 				array_unshift($path_full, ($d[0] == '/' ? '' : _DIR_RACINE) . $d . '/');
-
+		$GLOBALS['path_sig'] = md5(serialize($path_full));
 	}
 	if ($dir_path===NULL) return $path_full;
 
 	if (strlen($dir_path)){
-		if ($dir_path{0}!='/')
-			$dir_path = $dir_path;
-		if (substr($dir_path,-1) != '/')
-			$dir_path .= "/";
-		if (!in_array($dir_path,$path_base)){
-			$tete = "";
-			if (reset($path_base)==_DIR_RACINE.'squelettes/')
-				$tete = array_shift($path_base);
-
-			array_unshift($path_base,$dir_path);
-			if (strlen($tete))
-				array_unshift($path_base,$tete);
+		$tete = "";
+		if (reset($path_base)==_DIR_RACINE.'squelettes/')
+			$tete = array_shift($path_base);
+		$dirs = array_reverse(explode(':',$dir_path));
+		foreach($dirs as $dir_path){
+				#if ($dir_path{0}!='/')
+				#	$dir_path = $dir_path;
+				if (substr($dir_path,-1) != '/')
+					$dir_path .= "/";
+				if (!in_array($dir_path,$path_base))
+					array_unshift($path_base,$dir_path);
 		}
+		if (strlen($tete))
+			array_unshift($path_base,$tete);
 	}
 	$path_full = $path_base;
 	// Et le(s) dossier(s) des squelettes nommes
@@ -631,6 +614,7 @@ function _chemin($dir_path=NULL){
 		foreach (array_reverse(explode(':', $GLOBALS['dossier_squelettes'])) as $d)
 			array_unshift($path_full, ($d[0] == '/' ? '' : _DIR_RACINE) . $d . '/');
 
+	$GLOBALS['path_sig'] = md5(serialize($path_full));
 	return $path_full;
 }
 
@@ -639,14 +623,6 @@ function creer_chemin() {
 	$path_a = _chemin();
 	static $c = '';
 
-	// provisoire, a remplacer par un spip_unlink sur les fichiers compiles lors d'un prochain upgrade
-	if (isset($GLOBALS['plugins'])){
-		$c = '';
-		foreach($GLOBALS['plugins'] as $dir) {
-			$path_base = _chemin(_DIR_PLUGINS.$dir);
-		}
-		unset($GLOBALS['plugins']);
-	}
 	// on calcule le chemin si le dossier skel a change
 	if ($c != $GLOBALS['dossier_squelettes']) {
 		// assurer le non plantage lors de la montee de version :
@@ -678,15 +654,32 @@ function chemin($file, $dirname='', $include=false){
 // chercher un fichier $file dans le SPIP_PATH
 // si on donne un sous-repertoire en 2e arg optionnel, il FAUT le / final
 // si 3e arg vrai, on inclut si ce n'est fait.
+$GLOBALS['path_sig'] = '';
+$GLOBALS['path_files'] = null;
 
 // http://doc.spip.org/@find_in_path
 function find_in_path ($file, $dirname='', $include=false) {
-	static $files=array(), $dirs=array();
+	static $dirs=array();
+	static $inc = array(); # cf http://trac.rezo.net/trac/spip/changeset/14743
+	static $c = '';
 
-	if (isset($files[$dirname][$file])) {
-		if ($include) include_once $files[$dirname][$file];
-		return  $files[$dirname][$file];
+	// on calcule le chemin si le dossier skel a change
+	if ($c != $GLOBALS['dossier_squelettes']){
+		// assurer le non plantage lors de la montee de version :
+		$c = $GLOBALS['dossier_squelettes'];
+		creer_chemin(); // forcer un recalcul du chemin et la mise a jour de path_sig
 	}
+
+	if (isset($GLOBALS['path_files'][$GLOBALS['path_sig']][$dirname][$file])) {
+		if (!$GLOBALS['path_files'][$GLOBALS['path_sig']][$dirname][$file])
+			return false;
+		if ($include AND !isset($inc[$dirname][$file])) {
+			include_once _ROOT_CWD . $GLOBALS['path_files'][$GLOBALS['path_sig']][$dirname][$file];
+			$inc[$dirname][$file] = $inc[''][$dirname . $file] = true;
+		}
+		return $GLOBALS['path_files'][$GLOBALS['path_sig']][$dirname][$file];
+	}
+
 	$a = strrpos($file,'/');
 	if ($a !== false) {
 		$dirname .= substr($file, 0, ++$a);
@@ -695,17 +688,74 @@ function find_in_path ($file, $dirname='', $include=false) {
 
 	foreach(creer_chemin() as $dir) {
 		if (!isset($dirs[$a = $dir . $dirname]))
-			$dirs[$a] = (is_dir($a) || !$a) ;
+			$dirs[$a] = (is_dir(_ROOT_CWD . $a) || !$a) ;
 		if ($dirs[$a]) {
-			if (is_readable($a .= $file)) {
-				if ($include) include_once $a;
-				return $files[$dirname][$file] = $files[''][$dirname . $file] = $a;
+			if (file_exists(_ROOT_CWD . ($a .= $file))) {
+				if ($include AND !isset($inc[$dirname][$file])) {
+					include_once _ROOT_CWD . $a;
+					$inc[$dirname][$file] = $inc[''][$dirname . $file] = true;
+				}
+				if (!defined('_SAUVER_CHEMIN'))
+					define('_SAUVER_CHEMIN',true);
+				return $GLOBALS['path_files'][$GLOBALS['path_sig']][$dirname][$file] = $GLOBALS['path_files'][$GLOBALS['path_sig']][''][$dirname . $file] = $a;
 			}
 		}
 	}
+
+	if (!defined('_SAUVER_CHEMIN'))
+		define('_SAUVER_CHEMIN',true);
+	return $GLOBALS['path_files'][$GLOBALS['path_sig']][$dirname][$file] = $GLOBALS['path_files'][$GLOBALS['path_sig']][''][$dirname . $file] = false;
+}
+
+function clear_path_cache(){
+	$GLOBALS['path_files'] = array();
+	spip_unlink(_CACHE_CHEMIN);
+}
+function load_path_cache(){
+	// charger le path des plugins
+	if (@is_readable(_CACHE_PLUGINS_PATH)){
+		include_once(_CACHE_PLUGINS_PATH);
+	}
+	$GLOBALS['path_files'] = array();
+	// si le visiteur est admin,
+	// on ne recharge pas le cache pour forcer sa mise a jour
+	// le cache de chemin n'est utilise que dans le public
+	if (_DIR_RESTREINT
+		//AND (!isset($GLOBALS['visiteur_session']['statut']) OR $GLOBALS['visiteur_session']['statut']!='0minirezo')
+		AND !isset($_COOKIE[$GLOBALS['cookie_prefix'].'_admin'])
+		){
+		// on essaye de lire directement sans verrou pour aller plus vite
+		if ($contenu = spip_file_get_contents(_CACHE_CHEMIN)){
+			// mais si semble corrompu on relit avec un verrou
+			if (!$GLOBALS['path_files']=unserialize($contenu)){
+				lire_fichier(_CACHE_CHEMIN,$contenu);
+				if (!$GLOBALS['path_files']=unserialize($contenu))
+					$GLOBALS['path_files'] = array();
+			}
+		}
+	}
+	// pas de sauvegarde du chemin si on est pas dans le public
+	if (!_DIR_RESTREINT)
+		define('_SAUVER_CHEMIN',false);
+}
+
+function save_path_cache(){
+	if (defined('_SAUVER_CHEMIN')
+		AND _SAUVER_CHEMIN)
+		ecrire_fichier(_CACHE_CHEMIN,serialize($GLOBALS['path_files']));
 }
 
 
+/**
+ * Trouve tous les fichiers du path correspondants a un pattern
+ * pour un nom de fichier donne, ne retourne que le premier qui sera trouve
+ * par un find_in_path
+ *
+ * @param string $dir
+ * @param string $pattern
+ * @param bool $recurs
+ * @return array
+ */
 // http://doc.spip.org/@find_all_in_path
 function find_all_in_path($dir,$pattern, $recurs=false){
 	$liste_fichiers=array();
@@ -841,12 +891,16 @@ function test_valeur_serveur($truc) {
 // racine de SPIP : par exemple, sur ecrire/ elle vaut 1, sur sedna/ 1, et a
 // la racine 0. Sur url/perso/ elle vaut 2
 // http://doc.spip.org/@url_de_base
-function url_de_base() {
+function url_de_base($profondeur=null) {
 
 	static $url = array();
+	if (is_array($profondeur)) return $url = $profondeur;
+	if ($profondeur===false) return $url;
 
-	if (isset($url[$GLOBALS['profondeur_url']]))
-		return $url[$GLOBALS['profondeur_url']];
+	if (is_null($profondeur)) $profondeur = $GLOBALS['profondeur_url'];
+
+	if (isset($url[$profondeur]))
+		return $url[$profondeur];
 
 	$http = (
 		(isset($_SERVER["SCRIPT_URI"]) AND
@@ -865,15 +919,29 @@ function url_de_base() {
 				$GLOBALS['REQUEST_URI'] .= '?'.$_SERVER['QUERY_STRING'];
 		}
 	}
-	$myself = $http.'://'.$_SERVER['HTTP_HOST'].$GLOBALS['REQUEST_URI'];
 
+	$url[$profondeur] = url_de_($http,$_SERVER['HTTP_HOST'],$GLOBALS['REQUEST_URI'],$profondeur);
+
+	return $url[$profondeur];
+}
+/**
+ * fonction testable de construction d'une url appelee par url_de_base()
+ * @param string $http
+ * @param string $host
+ * @param string $request
+ * @param int $prof
+ * @return string
+ */
+function url_de_($http,$host,$request,$prof=0){
+	$prof = max($prof,0);
+
+	$myself = ltrim($request,'/');
 	# supprimer la chaine de GET
 	list($myself) = explode('?', $myself);
+	$url = join('/', array_slice(explode('/', $myself), 0, -1-$prof)).'/';
 
-	# supprimer n sous-repertoires
-	$url[$GLOBALS['profondeur_url']] = join('/', array_slice(explode('/', $myself), 0, -1-$GLOBALS['profondeur_url'])).'/';
-
-	return $url[$GLOBALS['profondeur_url']];
+	$url = $http.'://'.rtrim($host,'/').'/'.ltrim($url,'/');
+	return $url;
 }
 
 
@@ -971,7 +1039,7 @@ function generer_form_ecrire($script, $corps, $atts='', $submit='') {
 	. "<input type='hidden' name='exec' value='$script' />"
 	. $corps
 	. (!$submit ? '' :
-	     ("<div style='text-align: $spip_lang_right'><input class='fondo' type='submit' value='$submit' /></div>"))
+	     ("<div style='text-align: $spip_lang_right'><input type='submit' value='$submit' /></div>"))
 	. "</div></form>\n";
 }
 
@@ -1046,8 +1114,13 @@ function spip_initialisation_core($pi=NULL, $pa=NULL, $ti=NULL, $ta=NULL) {
 	static $too_late = 0;
 	if ($too_late++) return;
 
-	// Le charset par defaut lors de l'installation
-	define('_DEFAULT_CHARSET', 'utf-8');
+	// Declaration des repertoires
+
+	// le nom du repertoire plugins/ activables/desactivables
+	define('_DIR_PLUGINS', _DIR_RACINE . "plugins/");
+
+	// le nom du repertoire des extensions/ permanentes du core, toujours actives
+	define('_DIR_EXTENSIONS', _DIR_RACINE . "extensions/");
 
 	define('_DIR_IMG', $pa);
 	define('_DIR_LOGOS', $pa);
@@ -1062,26 +1135,32 @@ function spip_initialisation_core($pi=NULL, $pa=NULL, $ti=NULL, $ta=NULL) {
 	define('_DIR_AIDE',  _DIR_CACHE . "aide/");
 	define('_DIR_TMP', $ti);
 
-	# attention .php obligatoire pour ecrire_fichier_securise
-	define('_FILE_META', $ti . 'meta_cache.php');
-
 	define('_DIR_VAR', $ta);
 
 	define('_DIR_ETC', $pi);
 	define('_DIR_CONNECT', $pi);
 	define('_DIR_CHMOD', $pi);
 
-	define('_DIR_LOG', _DIR_TMP);
-	define('_FILE_LOG', 'spip');
-	define('_FILE_LOG_SUFFIX', '.log');
-
-	define('_MAX_LOG', 100);
-
 	if (!isset($GLOBALS['test_dirs']))
 	  // Pas $pi car il est bon de le mettre hors ecriture apres intstall
 	  // il sera rajoute automatiquement si besoin a l'etape 2 de l'install
 		$GLOBALS['test_dirs'] =  array($pa, $ti, $ta);
 
+	// Declaration des fichiers
+
+	define('_CACHE_PLUGINS_PATH', _DIR_CACHE . "charger_plugins_chemins.php");
+	define('_CACHE_PLUGINS_OPT', _DIR_CACHE . "charger_plugins_options.php");
+	define('_CACHE_PLUGINS_FCT', _DIR_CACHE . "charger_plugins_fonctions.php");
+	define('_CACHE_PLUGINS_VERIF', _DIR_CACHE . "verifier_plugins.txt");
+	define('_CACHE_PIPELINES',  _DIR_CACHE."charger_pipelines.php");
+	define('_CACHE_CHEMIN',  _DIR_CACHE."chemin.txt");
+
+	# attention .php obligatoire pour ecrire_fichier_securise
+	define('_FILE_META', $ti . 'meta_cache.php');
+	define('_DIR_LOG', _DIR_TMP);
+	define('_FILE_LOG', 'spip');
+	define('_FILE_LOG_SUFFIX', '.log');
+
 	// Le fichier de connexion a la base de donnees
 	// tient compte des anciennes versions (inc_connect...)
 	define('_FILE_CONNECT_INS', 'connect');
@@ -1110,8 +1189,14 @@ function spip_initialisation_core($pi=NULL, $pa=NULL, $ti=NULL, $ta=NULL) {
 	// Se mefier des fichiers mal remplis!
 	if (!defined('_SPIP_CHMOD')) define('_SPIP_CHMOD', 0777);
 
-	// le nom du repertoire plugins/
-	define('_DIR_PLUGINS', _DIR_RACINE . "plugins/");
+	// Le charset par defaut lors de l'installation
+	define('_DEFAULT_CHARSET', 'utf-8');
+
+	define('_ROOT_PLUGINS', _ROOT_RACINE . "plugins/");
+	define('_ROOT_EXTENSIONS', _ROOT_RACINE . "extensions/");
+
+	// La taille des Log
+	define('_MAX_LOG', 100);
 
 	// Sommes-nous dans l'empire du Mal ?
 	// (ou sous le signe du Pingouin, ascendant GNU ?)
@@ -1130,7 +1215,10 @@ function spip_initialisation_core($pi=NULL, $pa=NULL, $ti=NULL, $ta=NULL) {
 	// (non surchargeable en l'etat ; attention si on utilise include_spip()
 	// pour le rendre surchargeable, on va provoquer un reecriture
 	// systematique du noyau ou une baisse de perfs => a etudier)
-	include_once _DIR_RESTREINT . 'inc/flock.php';
+	include_once  _ROOT_RESTREINT . 'inc/flock.php';
+
+	// charger tout de suite le path et son cache
+	load_path_cache();
 
 	// *********** traiter les variables ************
 
@@ -1145,7 +1233,6 @@ function spip_initialisation_core($pi=NULL, $pa=NULL, $ti=NULL, $ta=NULL) {
 	spip_desinfecte($_POST);
 	spip_desinfecte($_COOKIE);
 	spip_desinfecte($_REQUEST);
-	spip_desinfecte($GLOBALS);
 
 	// Par ailleurs on ne veut pas de magic_quotes au cours de l'execution
 	@set_magic_quotes_runtime(0);
@@ -1155,6 +1242,9 @@ function spip_initialisation_core($pi=NULL, $pa=NULL, $ti=NULL, $ta=NULL) {
 	// il faut faire quelques verifications de base
 	if ($x = test_valeur_serveur(@ini_get('register_globals'))
 	OR  _FEED_GLOBALS) {
+		// ne pas desinfecter les globales en profondeur car elle contient aussi les
+		// precedentes, qui seraient desinfectees 2 fois.
+		spip_desinfecte($GLOBALS,false);
 		include_spip('inc/php3');
 		spip_register_globals($x);
 	}
@@ -1247,6 +1337,8 @@ function spip_initialisation_suite() {
 	define('_CACHE_RUBRIQUES', _DIR_TMP.'menu-rubriques-cache.txt');
 	define('_CACHE_RUBRIQUES_MAX', 500);
 
+	define('_EXTENSION_SQUELETTES', 'html');
+
 	define('_DOCTYPE_ECRIRE',
 		// "<!DOCTYPE HTML PUBLIC '-//W3C//DTD HTML 4.01 Transitional//EN' 'http://www.w3.org/TR/html4/loose.dtd'>\n");
 		//"<!DOCTYPE html PUBLIC '-//W3C//DTD XHTML 1.0 Transitional//EN' 'http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd'>\n");
@@ -1303,7 +1395,7 @@ function spip_initialisation_suite() {
 	define('_IMG_GD_MAX_PIXELS', (isset($GLOBALS['meta']['max_taille_vignettes'])&&$GLOBALS['meta']['max_taille_vignettes']<5500000)?$GLOBALS['meta']['max_taille_vignettes']:0);
 	define('_IMG_GD_QUALITE', 85);
 
-	@define('_MEMORY_LIMIT_MIN',10); // en Mo
+	@define('_MEMORY_LIMIT_MIN',16); // en Mo
 	// si on est dans l'espace prive et si le besoin est superieur a 8Mo (qui est vraiment le standard)
 	// on verifie que la memoire est suffisante pour le compactage css+js pour eviter la page blanche
 	// il y aura d'autres problemes et l'utilisateur n'ira pas tres loin, mais ce sera plus comprehensible qu'une page blanche
@@ -1383,6 +1475,11 @@ function init_var_mode(){
 							// indiquer qu'on doit recalculer les images
 							$GLOBALS['var_images'] = true;
 							break;
+						case 'debug':
+							$GLOBALS['var_mode'] = 'debug';
+							// et ne pas enregistrer de cache
+							$GLOBALS['var_nocache'] = true;
+							break;
 						default :
 							$GLOBALS['var_mode'] = $_GET['var_mode'];
 							break;
@@ -1412,7 +1509,7 @@ function init_var_mode(){
 // supprimer aussi les eventuels caracteres nuls %00, qui peuvent tromper
 // la commande is_readable('chemin/vers/fichier/interdit%00truc_normal')
 // http://doc.spip.org/@spip_desinfecte
-function spip_desinfecte(&$t) {
+function spip_desinfecte(&$t,$deep = true) {
 	static $magic_quotes;
 	if (!isset($magic_quotes))
 		$magic_quotes = @get_magic_quotes_gpc();
@@ -1424,13 +1521,14 @@ function spip_desinfecte(&$t) {
 			$t[$key] = str_replace(chr(0), '-', $t[$key]);
 		}
 		// traiter aussi les "texte_plus" de articles_edit
-		else if ($key == 'texte_plus' AND is_array($t[$key]))
-			spip_desinfecte($t[$key]);
+		else if ($deep AND is_array($t[$key]) AND $key!=='GLOBALS')
+			spip_desinfecte($t[$key],$deep);
 	}
 }
 
 //  retourne le statut du visiteur s'il s'annonce
 
+
 // http://doc.spip.org/@verifier_visiteur
 function verifier_visiteur() {
 
@@ -1465,8 +1563,8 @@ function verifier_visiteur() {
 		return 0;
 	}
 
-	if (isset($_COOKIE['spip_session']) OR isset($_COOKIE[$GLOBALS['cookie_prefix'].'_session']) OR
-	(isset($_SERVER['PHP_AUTH_USER'])  AND !$GLOBALS['ignore_auth_http'])) {
+	$h = (isset($_SERVER['PHP_AUTH_USER'])  AND !$GLOBALS['ignore_auth_http']);
+	if ($h OR isset($_COOKIE['spip_session']) OR isset($_COOKIE[$GLOBALS['cookie_prefix'].'_session'])) {
 
 		// Rq: pour que cette fonction marche depuis mes_options
 		// il faut forcer l'init si ce n'est fait
@@ -1484,8 +1582,14 @@ function verifier_visiteur() {
 		if ($session()) {
 			return $GLOBALS['visiteur_session']['statut'];
 		}
-		include_spip('inc/actions');
-		return verifier_php_auth();
+		if ($h  AND isset($_SERVER['PHP_AUTH_PW'])) {
+			include_spip('inc/auth');
+			$h = lire_php_auth($_SERVER['PHP_AUTH_USER'], $_SERVER['PHP_AUTH_PW']);
+		}
+		if ($h) {
+			$GLOBALS['visiteur_session'] = $h;
+			return $GLOBALS['visiteur_session']['statut'];
+		}
 	}
 	// au moins son navigateur nous dit la langue preferee de cet inconnu
 	include_spip('inc/lang');
@@ -1560,6 +1664,14 @@ function exec_info_dist() {
 		echo "pas admin";
 }
 
+function erreur_squelette($message='', $lieu='') {
+	$debusquer = charger_fonction('debusquer', 'public');
+	if (is_array($lieu)) {
+		include_spip('public/compiler');
+		$lieu = reconstruire_contexte_compil($lieu);
+	}
+	return $debusquer($message, $lieu);
+}
 
 /**
  * La fonction de base de SPIP : un squelette + un contexte => une page.
@@ -1614,11 +1726,11 @@ function recuperer_fond($fond, $contexte=array(), $options = array(), $connect='
 
 	foreach(is_array($fond) ? $fond : array($fond) as $f){
 		$page = evaluer_fond($f, $contexte, $connect);
-		if (isset($options['ajax'])AND $options['ajax'])
+		if (isset($options['ajax'])AND $options['ajax']){
+			include_spip('inc/filtres');
 			$page['texte'] = encoder_contexte_ajax(array_merge($contexte,array('fond'=>$f)),'',$page['texte']);
+		}
 
-		if ($GLOBALS['var_inclure'])
-			$page['texte'] = "<fieldset class='blocs'><legend>".$page['sourcefile']."</legend>".$page['texte']."</fieldset>";
 		$page = pipeline('recuperer_fond',array(
 			'args'=>array('fond'=>$fond,'contexte'=>$contexte,'options'=>$options,'connect'=>$connect),
 			'data'=>$page
@@ -1638,6 +1750,11 @@ function recuperer_fond($fond, $contexte=array(), $options = array(), $connect='
 		return $options['trim'] ? ltrim($texte) : $texte;
 }
 
+function trouve_modele($nom)
+{
+	return find_in_path( 'modeles/' . $nom.'.'. _EXTENSION_SQUELETTES);
+}
+
 // Charger dynamiquement une extension php
 // http://doc.spip.org/@charger_php_extension
 function charger_php_extension($module) {
