@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2009                                                *
+ *  Copyright (c) 2001-2010                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -112,7 +112,7 @@ elseif ($exec!='upgrade'
 AND !$var_auth
 AND !_DIR_RESTREINT
 AND autoriser('configurer')
-AND lire_fichier(_DIR_TMP.'verifier_plugins.txt',$l)
+AND lire_fichier(_CACHE_PLUGINS_VERIF,$l)
 AND $l = @unserialize($l)) {
 	foreach ($l as $fichier) {
 		if (!@is_readable($fichier)) {
@@ -152,16 +152,22 @@ elseif (find_in_path("prive/exec/$exec.html")) {
 }
 
 // Trouver la fonction eventuellement surchargee
-$var_f = charger_fonction($exec);
+// si absente, rerouter vers exec=404 au lieu d'echouer
+// ce qui permet de laisser la main a un plugin
+if (!$var_f = charger_fonction($exec,'exec',true)){
+	$var_f = charger_fonction('404');
+	$var_f($exec);
+}
+else {
+	// Z'y va
+	$var_f();
+}
 
-// Z'y va
-$var_f();
-
-if ($GLOBALS['var_mode'] == 'debug') {
-	include_spip('public/debug');
+$debug = ((_request('var_mode') == 'debug') OR $tableau_des_temps) ? array(1) : array();
+if ($debug) {
 	$var_mode_affiche = _request('var_mode_affiche');
-	$var_mode_objet = _request('var_mode_objet');
-	debug_dumpfile("",$var_mode_objet,$var_mode_affiche);
+	$GLOBALS['debug_objets'][$var_mode_affiche][$var_mode_objet . 'tout'] = ($var_mode_affiche== 'validation' ? $page['texte'] :"");
+	echo erreur_squelette();
 }
 if (isset($tableau_des_erreurs) AND count($tableau_des_erreurs) AND $affiche_boutons_admin)
 	echo affiche_erreurs_page($tableau_des_erreurs);
