@@ -26,8 +26,9 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 'avis_conseil_selection_mot_cle' => '<b>Wichtige Kategorie:</b> Bitte w&auml;hlen Sie ein Schl&uuml;sselwort dieser Gruppe.',
 'avis_deplacement_rubrique' => 'Achtung! diese Rubrik enth&auml;lt @contient_breves@ Meldungen@scb@: wenn Sie Rubrik verschieben wollen, markieren Sie bitte zur Best&auml;tigung dieses K&auml;stchen.',
 'avis_destinataire_obligatoire' => 'Sie m&uuml;ssen einen Empf&auml;nger angeben, bevor Sie die Nachricht abschicken.',
+'avis_doublon_mot_cle' => 'Dieses Schlagwort gibt es bereits. Wollen sie es wirklich anlegen?', # MODIF
 'avis_erreur_connexion_mysql' => 'Verbindungsfehler (SQL)',
-'avis_erreur_version_archive' => '<b>Achtung! Die Datei @archive@ entspricht nicht der von Ihnen installierten Version von SPIP.</b> Bitte brechen Sie den Import jetzt ab. Sie riskieren anderenfalls die Funktionalit&auml;t Ihrer Website zu beeintr&auml;chtigen oder sogar die Datenbank zu zerst&ouml;ren. Bitte brechen Sie den Vorgang jetzt ab.<p> Mehr dazu finden Sie in der <A HREF="http://www.spip.net/fr_article2632.html"> franz&ouml;sischen SPIP-Dokumentation</a>.',
+'avis_erreur_version_archive' => '<b>Achtung! Die Datei @archive@ entspricht nicht der von Ihnen installierten Version von SPIP.</b> Sie riskieren die Funktionalit&auml;t Ihrer Website zu beeintr&auml;chtigen oder sogar die Datenbank zu zerst&ouml;ren. Bitte brechen Sie den Vorgang jetzt ab.<p> Mehr dazu finden Sie in der <a href="@spipnet@"> franz&ouml;sischen SPIP-Dokumentation</a>.',
 'avis_espace_interdit' => '<b>Gesperrter Bereich</b><div>SPIP ist bereits installiert.</div>',
 'avis_lecture_noms_bases_1' => 'Das Installationsprogramm konnte die Namen der vorhandenen Datenbanken nicht lesen.',
 'avis_lecture_noms_bases_2' => 'Entweder ist keine Datenbank vorhanden oder die Funktion zum Auflisten der Datenbanken ist abgeschaltet (Das ist bei vielen Webhostern der Fall).',
@@ -113,6 +114,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 'config_erreur_base_sup' => 'SPIP kann nicht auf die Liste der verf&uuml;gbaren Datenbanken zugreifen.',
 'config_info_base_sup' => 'Wenn Sie andere Datenbanken auf dem selben Server oder auf einem anderen mit SPIP abfragen m&ouml;chten, k&ouml;nnen Sie sie mit dem Formular weiter unten deklarieren. Wenn Sie Felder leer lassen, werden die Verbindungsdaten der Hauptdatenbank verwendet.',
 'config_info_base_sup_disponibles' => 'Bereits abfragbare Datenbanken:',
+'config_info_enregistree' => 'Neue Einstellungen wurden gespeichert',
 'config_info_logos' => 'Jedes Element der Website kann ein Logo und ein &laquo;mouseover-Logo&raquo; erhalten.',
 'config_info_logos_utiliser' => 'Logos verwenden',
 'config_info_logos_utiliser_non' => 'Logos nicht verwenden',
@@ -138,6 +140,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 // E
 'email' => 'E-Mail',
 'email_2' => 'E-Mail:',
+'en_savoir_plus' => 'Weitere Informationen',
 'entree_adresse_annuaire' => 'Adresse des Verzeichnisses',
 'entree_adresse_email' => 'Ihre E-Mail Adresse',
 'entree_adresse_fichier_syndication' => 'Adresse der &#132;backend&#147;-Datei:',
@@ -173,6 +176,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 'entree_texte_breve' => 'Text der Meldung',
 'entree_titre_obligatoire' => '<b>Titel</b> [Pflichtfeld]<br />',
 'entree_url' => 'Adresse (URL) Ihrer Website',
+'erreur_plugin_desinstalation_echouee' => 'Das Plugin konnte nicht deinstalliert werden. Sie m&uuml;ssen es auf jeden Fall deaktivieren.',
 'erreur_plugin_fichier_absent' => 'Datei nicht vorhanden',
 'erreur_plugin_fichier_def_absent' => 'Definitionsdatei nicht vorhanden',
 'erreur_plugin_nom_fonction_interdit' => 'Unzul&auml;ssiger Funktionsname',
@@ -184,9 +188,13 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 // F
 'forum_info_original' => 'Original',
 
+// H
+'htaccess_a_simuler' => 'Achtung: Ihr HTTP-Server ist so konfiguriert, da&szlig; er @htaccess@ Dateien ignoriert. Eine sichere Konfiguration des Servers erzielen sie, indem sie diese Einstellung &auml;ndern, oder indem sie die @Konstanten@ in der Datei mes_options.php so setzen, da&szlig; die Verzeichnisse au&szlig;erhalb des @document_root@ liegen.',
+'htaccess_inoperant' => 'htaccess unwirksam',
+
 // I
 'ical_info1' => 'Diese Seite erm&ouml;glicht auf mehrere Arten an der Entwicklung der Website teilzunehmen.',
-'ical_info2' => 'Um mehr &uuml;ber diese Techniken zu erfahren, lesen Sie bitte die <a href="http://www.spip.net/de_suivi">SPIP Dokumentation</a>.',
+'ical_info2' => 'Um mehr &uuml;ber diese Techniken zu erfahren, lesen Sie bitte die <a href="@spipnet@">SPIP Dokumentation</a>.',
 'ical_info_calendrier' => 'Sie verf&uuml;gen &uuml;ber zwei Kalender. Einer gibt Ihnen eine &Uuml;bersicht &uuml;ber die Website und alle dort ver&ouml;ffentlichten Artikel. Der zweite enth&auml;lt editorische Ank&uuml;ndigungen und Ihre pers&ouml;nlichen Nachrichten. Sie allein haben Zugriff auf ihn indem Sie Ihr Passwort eingeben. Sie k&ouml;nne es &auml;ndern, indem Sie Ihr Zugangspasswort f&uuml;r diese Website &auml;ndern.',
 'ical_lien_rss_breves' => 'Syndikation der Meldungen dieser Website',
 'ical_methode_http' => 'Download',
@@ -246,6 +254,8 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
  die Moderation im Standardmodus:</i>',
 'info_admin_gere_rubriques' => 'Dieser Administrator verwaltet die folgenden Rubriken:',
 'info_admin_gere_toutes_rubriques' => 'Dieser Administrator verwaltet <b>alle Rubriken</b>.',
+'info_admin_statuer_webmestre' => 'Diesem Administrator Webmaster-Rechte geben',
+'info_admin_webmestre' => 'Dieser Administrator ist <b>Webmaster</b>',
 'info_administrateur' => 'Administrator',
 'info_administrateur_1' => 'Administrator',
 'info_administrateur_2' => 'der Website (<i>vorsichtig einsetzen</i>)',
@@ -318,7 +328,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 'info_conflit_edition_votre_version' => 'Ihre Fassung:',
 'info_connexion_base' => 'Test der Verbindung zur Datenbank',
 'info_connexion_base_donnee' => 'Verbindung mit Ihrer Datenbank',
-'info_connexion_ldap_ok' => 'Die Verbindung zum LDAP-Verzeichnis wurde hergestellt.</b><p> Sie k&ouml;nnen mit dem n&auml;chsten Schritt fortfahren.',
+'info_connexion_ldap_ok' => 'Die LDAP-Verbindung wurde hergestellt.</b><p> Sie k&ouml;nnen mit dem n&auml;chsten Schritt fortfahren.',
 'info_connexion_mysql' => 'Verbindung zur SQL-Datenbank',
 'info_connexion_ok' => 'Die Verbindung wurde hergestellt.',
 'info_contact' => 'Kontakt',
@@ -503,7 +513,7 @@ Ihr Status wird durch die Farbe ihres Symbols angezeigt (Redakteur = gelb; Admin
 'info_question_activer_compresseur' => 'M&ouml;chten sie die HTTP-&Uuml;bertragung komprimieren?',
 'info_question_gerer_statistiques' => 'Soll SPIP Besucherstatistiken anlegen?',
 'info_question_inscription_nouveaux_redacteurs' => 'M&ouml;chten Sie, dass sich neue Redakteure vom &ouml;ffentlichen Bereich
- aus anmelden k&ouml;nnen?&nbsp; Wenn Sie das erm&ouml;glichen, k&ouml;nnen sich Besucher &uuml;ber ein automatisch
+ aus anmelden k&ouml;nnen?&nbsp; Wenn Sie es wollen, k&ouml;nnen sich Besucher &uuml;ber ein automatisch
  erstelltes Formular anmelden und Artikel vorschlagen.
  <blockquote><i>Nach der Anmeldung erhalten die neuen Redakteure automatisch
  eine E-Mail mit ihren Zugangsdaten. Manche Webhoster unterbinden den Mailversand
@@ -522,7 +532,7 @@ Ihr Status wird durch die Farbe ihres Symbols angezeigt (Redakteur = gelb; Admin
 'info_recharger_page' => 'Bitte laden Sie diese Seite in ein paar Augenblicken erneut.',
 'info_recherche_auteur_a_affiner' => 'Zu viele Fundstellen f&uuml;r R20;@cherche_auteur@R21; - bitte grenzen Sie die Suche ein.',
 'info_recherche_auteur_ok' => 'Zu &bdquo;@cherche_auteur@&ldquo; wurde mehrere Autoren gefunden:',
-'info_recherche_auteur_zero' => 'Dem Kriterium @cherche_auteur@ entspricht kein Autor.',
+'info_recherche_auteur_zero' => 'Dem Kriterium “@cherche_auteur@” entspricht kein Autor.',
 'info_recommencer' => 'Bitte wiederholen.',
 'info_redacteur_1' => 'Redakteur',
 'info_redacteur_2' => 'mit Zugang zum Redaktionssystem (<i>empfohlen</i>)',
@@ -616,6 +626,7 @@ Ihr Status wird durch die Farbe ihres Symbols angezeigt (Redakteur = gelb; Admin
 'info_total' => 'Gesamt: ',
 'info_tous_articles_en_redaction' => 'Alle Artikel in Bearbeitung',
 'info_tous_articles_presents' => 'Alle ver&ouml;ffentlichten Artikel dieser Rubrik',
+'info_tous_articles_refuses' => 'Alle abgelehnten Artikel',
 'info_tous_les' => 'alle',
 'info_tous_redacteurs' => 'Ank&uuml;ndigung f&uuml;r alle Redakteure',
 'info_tout_site' => 'Ganze Website',
@@ -656,7 +667,7 @@ in einer Farbe, die den Status anzeigt&nbsp;:',
 'install_select_langue' => 'W&auml;hlen Sie eine Sprache aus und klicken Sie auf &laquo;Weiter&raquo;, um die Installation zu starten.',
 'install_select_type_db' => 'Geben Sie den Typ der Datenbank an:',
 'install_select_type_mysql' => 'MySQL',
-'install_select_type_pgsql' => 'PostgreSQL',
+'install_select_type_pg' => 'PostgreSQL',
 'install_select_type_sqlite2' => 'SQLite 2',
 'install_select_type_sqlite3' => 'SQLite 3',
 'install_serveur_hebergeur' => 'Vom Provider bereitgestellter Datenbankserver',
@@ -766,7 +777,6 @@ in einer Farbe, die den Status anzeigt&nbsp;:',
 'logo_article' => 'ARTIKEL-LOGO',
 'logo_auteur' => 'AUTOREN-LOGO',
 'logo_breve' => 'MELDUNGS-LOGO',
-'logo_groupe' => 'LOGO DER GRUPPE',
 'logo_mot_cle' => 'SCHLAGWORT-LOGO',
 'logo_rubrique' => 'RUBRIK-LOGO',
 'logo_site' => 'WEBSITE-LOGO',
@@ -782,6 +792,9 @@ in einer Farbe, die den Status anzeigt&nbsp;:',
 'module_texte_traduction' => 'Die Sprachdatei f&uuml;r &laquo;&nbsp;@module@&nbsp;&raquo; liegt vor auf&nbsp;',
 'mois_non_connu' => 'unbekannt',
 
+// N
+'nouvelles_versions' => 'Neue Versionen von SPIP sind verf&uuml;gbar',
+
 // O
 'onglet_contenu' => 'Inhalt',
 'onglet_declarer_une_autre_base' => 'Weitere Datenbank deklarieen',
@@ -809,6 +822,7 @@ in einer Farbe, die den Status anzeigt&nbsp;:',
 'page_pas_proxy' => 'Diese Seite darf nicht durch den Proxy &uuml;bertragen werden.',
 'pas_de_proxy_pour' => 'Falls erforderlich, k&ouml;nne Sie die Rechner und Domainen angeben, die nicht &uuml;ber den Proxy angesprochen werden (z.B. @exemple@)',
 'plugin_charge_paquet' => 'Paket @name@ wird geladen',
+'plugin_charger' => '&Uuml;bertragen',
 'plugin_erreur_charger' => 'Fehler: @zip@ kann nicht geladen werden',
 'plugin_erreur_droit1' => 'In das Verzeichnis <code>@dest@</code> kann nicht geschrieben werden.',
 'plugin_erreur_droit2' => 'Bitte &uuml;berpr&uuml;fen Sie die Schreibrechte f&uuml;r dieses Verzeichnis oder legen Sie es an, falls es noch nicht existiert, oder installieren Sie die Dateien per FTP.',
@@ -819,8 +833,9 @@ in einer Farbe, die den Status anzeigt&nbsp;:',
 'plugin_etat_test' => 'Im Test',
 'plugin_impossible_activer' => 'Das Plugin @plugin@ kann nicht aktiviert werden.',
 'plugin_info_automatique1' => 'Wenn Sie die automatische Installation von Plugins nutzen m&ouml;chten, f&uuml;hren Sie bitte folgende Schritte aus:',
+'plugin_info_automatique1_lib' => 'Wenn diese Bibliothek automatisch installiert werden soll, f&uuml;hren sie bitte diese Schritte aus:',
 'plugin_info_automatique2' => 'Anlegen des Verzeichnis <code>@rep@</code>&nbsp;;',
-'plugin_info_automatique3' => '&uuml;berpr&uuml;fen, ob der Server in das Verzeuichnis schreiben kann.',
+'plugin_info_automatique3' => '&uuml;berpr&uuml;fen, ob der Server in das Verzeichnis schreiben kann.',
 'plugin_info_automatique_creer' => 'im Wurzelverzeichnis der Website.',
 'plugin_info_automatique_exemples' => 'Beispiele:',
 'plugin_info_automatique_ftp' => 'Sie k&ouml;nnen Plugins per FTP in dem Vezeichnis <tt>@rep@</tt> installieren',
@@ -830,6 +845,8 @@ in einer Farbe, die den Status anzeigt&nbsp;:',
 'plugin_info_automatique_liste_update' => 'Listen aktualisieren',
 'plugin_info_automatique_ou' => 'oder...',
 'plugin_info_automatique_select' => 'W&auml;hlen Sie ein Plugin aus. SPIP wird es herunterladen und im Verzeichnis <code>@rep@</code> installieren. Falls das Plugin bereits installiert ist, wird es auf den neuesten Stand gebracht.',
+'plugin_info_extension_1' => 'Diese Erweiterungen liegen im Verzeichnis @extensions@ und sind aktiviert.',
+'plugin_info_extension_2' => 'Man kann sie nicht deaktivieren.',
 'plugin_info_telecharger' => 'herunterladen von @url@ und in @rep@ installieren',
 'plugin_librairies_installees' => 'Installierte Bibliotheken',
 'plugin_necessite_lib' => 'Dieses Plugin ben&ouml;tigt die Bibliothek @lib@',
@@ -838,6 +855,7 @@ in einer Farbe, die den Status anzeigt&nbsp;:',
 'plugin_source' => 'Quelle:&nbsp;',
 'plugin_titre_automatique' => 'Automatische Installation',
 'plugin_titre_automatique_ajouter' => 'Plugins hinzuf&uuml;gen',
+'plugin_titre_installation' => 'Installation des Plugins @plugin@',
 'plugin_zip_active' => 'Weiter zum Aktivieren',
 'plugin_zip_adresse' => 'Geben Sie hier die Adresse einer ZIP-Datei, die das Plugin enth&auml;lt, oder die Adresse einer Plugin-Liste an.',
 'plugin_zip_adresse_champ' => 'Adresse des Plugins oder der Liste&nbsp;',
@@ -846,11 +864,17 @@ in einer Farbe, die den Status anzeigt&nbsp;:',
 'plugin_zip_installe_rep_finie' => 'Die Datei @zip@ wurde entpackt und in das Verzeichnis @rep@ installiert.',
 'plugin_zip_installer' => 'Sie k&ouml;nnen es jetzt installieren.',
 'plugin_zip_telecharge' => 'Die Datei @zip@ wurde heruntergeladen',
+'plugins_actif_aucun' => 'Kein aktives Plugin.',
+'plugins_actif_un' => 'Ein aktives Plugin.',
 'plugins_actifs' => '@count@ aktive Plugins.',
+'plugins_actifs_liste' => 'Aktive Plugins',
 'plugins_compte' => '@count@ Plugins',
+'plugins_disponible_un' => 'Ein Plugin verf&uuml;gbar.',
 'plugins_disponibles' => '@count@ verf&uuml;gbare Plugins.',
 'plugins_erreur' => 'Fehler in den Plugins: @plugins@',
 'plugins_liste' => 'Liste der Plugins',
+'plugins_liste_extensions' => 'Erweiterungen',
+'plugins_recents' => 'Neueste Plugins.',
 'plugins_vue_hierarchie' => 'Hierarchie',
 'plugins_vue_liste' => 'Liste',
 'protocole_ldap' => 'Version des Protokolls:',
@@ -887,11 +911,7 @@ in einer Farbe, die den Status anzeigt&nbsp;:',
 'texte_admin_effacer_01' => 'Dieser Befehl l&ouml;scht den <i>gesamten</i> Inhalt der Datenbank mit <i>allen</i> Redakteuren und Administratoren. Nach der Ausf&uuml;hrung dieses Befehls m&uuml;ssen Sie SPIP neu installieren und einen ersten Administrator anlegen.',
 'texte_admin_effacer_stats' => 'Dieser Befehl l&ouml;scht alle Daten der Besucherstatistiken, auch die zur Popularit&auml;t der Artikel.',
 'texte_admin_tech_01' => 'Diese Option erm&ouml;glicht es, den Inhalt der Datenbank in das Verzeichnis @dossier@ zu sichern. Vergessen Sie bitte nicht, ebenfalls den Inhalt des Verzeichnisses <i>img/</i> zu sichern, denn es enth&auml;lt die Bilder und Grafiken, welche f&uuml;r Rubriken und Artikel verwendet werden.',
-'texte_admin_tech_02' => 'Achtung: Diese Sicherungskopie kann AUSSCHLIESSLICH in eine Website wieder eingespielt werden, die unter der gleichen Version von SPIP l&auml;uft. Bitte verwenden Sie keine Sicherungskopie, um den Inhalt einer Website nach einem Update wieder einzuspielen. Mehr dazu steht in der <a href="http://www.spip.net/fr_article1489.html">die SPIP Dokumentation</a>.
-
-
-
-',
+'texte_admin_tech_02' => 'Achtung: Diese Sicherungskopie kann AUSSCHLIESSLICH in eine Website wieder eingespielt werden, die unter der gleichen Version von SPIP l&auml;uft.  So darf insbesondere die Datenbank vor einem Update nicht "geleert" werden. Bitte verwenden Sie keine Sicherungskopie, um den Inhalt einer Website nach einem Update wieder einzuspielen. Mehr dazu steht in der <a href="@spipnet@">die SPIP Dokumentation</a>.',
 'texte_admin_tech_03' => 'Sie k&ouml;nnen die Daten in komprimierter Form sichern und damit Speicherplatz auf dem Server und Downloadzeit sparen.',
 'texte_admin_tech_04' => 'Um das Zusammenf&uuml;hren mit einer anderen Datenbank vorzubereiten, k&ouml;nnen Sie die Datensicherung auf eine bestimmte Rubrik beschr&auml;nken: ',
 'texte_adresse_annuaire_1' => '(Wenn Ihr Verzeichnis auf dem selben Rechner installiert ist wie diese Website, m&uuml;ssen Sie wahrscheinlich &bdquo;localhost&ldquo; angeben.)',
@@ -942,9 +962,9 @@ jedoch zus&auml;tzliche Serverleistung.',
 'texte_effacer_statistiques' => 'Statistiken l&ouml;schen',
 'texte_en_cours_validation' => 'Die folgenden Artikel und Meldungen sind zur Ver&ouml;ffentlichung vorgeschlagen.',
 'texte_en_cours_validation_forum' => 'Bitte schreiben Sie Ihre Kommentare in die entsprechenden Foren.',
-'texte_enrichir_mise_a_jour' => 'Sie k&ouml;nnen Ihren Text ansprechend gestalten, indem Sie die &bdquo;typografischen Abk&uuml;rzungen&ldquo; verwenden.',
-'texte_fichier_authent' => '<b>Soll SPIP die Dateien <tt>.htpasswd</tt> und <tt>.htpasswd-admin</tt> im Verzeichnis @dossier@ anlegen?</b><p />
- Mit diesen Dateien k&ouml;nnen Sie den Zugang zu anderen Bereichen Ihrer Website (z.B. externe Logfile-Auswertungen) auf Redakteure und Administratoren beschr&auml;nken.<p />Wenn Sie diese M&ouml;glickeit nicht nutzen, k&ouml;nnn Sie hier die Grundeinstellung (Dateien werden nicht angelegt) beibehalten.',
+'texte_enrichir_mise_a_jour' => 'Sie k&ouml;nnen Ihren Text ansprechend gestalten, indem Sie die &#132;typografischen Abk&uuml;rzungen&#147; verwenden.',
+'texte_fichier_authent' => '<b>Soll SPIP die Dateien <tt>.htpasswd</tt> und <tt>.htpasswd-admin</tt> im Verzeichnis @dossier@ anlegen?</b><p>
+ Mit diesen Dateien k&ouml;nnen Sie den Zugang zu anderen Bereichen Ihrer Website (z.B. externe Logfile-Auswertungen) auf Redakteure und Administratoren beschr&auml;nken.</p><p>Wenn Sie diese M&ouml;glickeit nicht nutzen, k&ouml;nnn Sie hier die Grundeinstellung (Dateien werden nicht angelegt) beibehalten.</p>',
 'texte_informations_personnelles_1' => 'Das System nun pers&ouml;nliche Zugangsdaten f&uuml;r Sie anlegen.',
 'texte_informations_personnelles_2' => '(Wenn Sie die Site erneut installieren, und Ihre Zugangsdaten funktionieren, k&ouml;nnen Sie',
 'texte_introductif_article' => '(Einleitender Text des Artikels.)',
@@ -973,13 +993,7 @@ jedoch zus&auml;tzliche Serverleistung.',
 'texte_nouveau_message' => 'Neue Nachricht',
 'texte_nouveau_mot' => 'Neues Wort',
 'texte_nouvelle_version_spip_1' => 'Sie haben eine neue Version von SPIP installiert.',
-'texte_nouvelle_version_spip_2' => 'Diese neue Version erfordert eine weiter gehende Aktualisierung Ihres Systems als g.
-ew&ouml;hnlich.        Wenn Sie Webmaster dieser Site sind, l&ouml;schen Sie bitte die Datei
-       @connect@         und nehmen Sie die Installation wieder auf, indem Sie
-        die Verbindungsdaten zur Datenbank neu eingeben.
-        <p>(Tipp: Sollten Sie Ihre Verbindungsdaten vergessen haben,
-        schauen Sie in der Datei @connect@ nach,
-        bevor Sie sie l&ouml;schen ...)',
+'texte_nouvelle_version_spip_2' => 'Diese neue Version erfordert eine weiter gehende Aktualisierung Ihres Systems als gew&ouml;hnlich. Wenn Sie Webmaster dieser Site sind, l&ouml;schen Sie bitte die Datei @connect@ und setzen Sie die Installation fort, indem Sie die Verbindungsdaten zur Datenbank neu eingeben.<p>(Tipp: Sollten Sie Ihre Verbindungsdaten vergessen haben, schauen Sie in der Datei @connect@ nach, bevor Sie sie l&ouml;schen ...)</p>',
 'texte_operation_echec' => 'Gehen Sie zur vorigen Seite zur&uuml;ck und w&auml;hlen Sie eine andere Datenbank aus bzw. legen Sie eine neue an. &Uuml;berpr&uuml;fen Sie die Angaben Ihres Providers.',
 'texte_plus_trois_car' => 'mehr als 3 Zeichen',
 'texte_plusieurs_articles' => 'Mehrere Autoren f&uuml;r &bdquo;@cherche_auteur@&ldquo; gefunden:',
@@ -1000,7 +1014,7 @@ Meistens kann dieses Feld aber leer bleiben.',
 'texte_referencement_automatique' => '<b>Automatische Verlinkung einer Website</b><br />Sie k&ouml;nnen eine Website im Schnellverfahren verlinken, indem Sie seinen URL oder den seiner Backend-Datei angeben. SPIP wird dann die Daten der Website selbst&auml;ndig einlesen (Titel, Beschreibung ...).',
 'texte_referencement_automatique_verifier' => 'Bitte &uuml;berpr&uuml;fen Sie die Informationen von <tt>@url@</tt> vor dem Speichern.',
 'texte_requetes_echouent' => '<b>Wenn manche SQL-Befehle ohne ersichtlichen Grund systematisch fehlschlagen, kann es an einer besch&auml;digten Datenbank liegen.</b><p>
-SQL kann Tabellen reparieren, die besch&auml;digt worden sind. Starten Sie hier einen Reparaturversuch. Sollte das fehlschlagen, notieren Sie bitte die Fehlermeldung, die u.U. einen Hinweis auf den Grund des Problems gibt ...<p>
+SQL kann Tabellen reparieren, die besch&auml;digt worden sind. Starten Sie hier einen Reparaturversuch. Sollte das fehlschlagen, notieren Sie bitte die Fehlermeldung, die u.U. einen Hinweis auf die Ursache des Problems gibt ...<p>
 Wenn das Problem weiter besteht, nehmen Sie bitte Kontakt mit Ihrem Provider auf.<p>',
 'texte_restaurer_base' => 'Wiederherstellung des Inhalts der Datenbank',
 'texte_restaurer_sauvegarde' => 'Mit dieser Funktion k&ouml;nnen Sie eine Sicherungskopie Ihrer Datenbank wieder einspielen. Dazu muss die Sicherungsdatei in das Verzeichnis @dossier@ kopiert werden. Verwenden Sie diese Funktion mit der n&ouml;tigen Vorsicht. <b>Die &Auml;nderungen k&ouml;nnen nicht wieder r&uuml;ckg&auml;ngig gemacht werden.</b>',
