@@ -24,7 +24,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 'admin_modifier_rubrique' => 'Modificar aquesta secci&oacute;',
 'admin_recalculer' => 'Recarregar aquesta p&agrave;gina',
 'afficher_trad' => 'visualitzar les traduccions',
-'alerte_maj_impossible' => '<b>Alerta&nbsp;!</b> L\'actualitzaci&oacute;  de la base de dades SQL cap a la versi&oacute; @version@ &eacute;s impossible. Pot ser que tingueu un problema de drets de modificaci&oacute; de la base de dades. Si us plau, contacteu amb el vostre prove&iuml;dor d\'hostatge.',
+'alerte_maj_impossible' => '<b>Alerta&nbsp;!</b> L\'actualitzaci&oacute; de la base de dades SQL cap a la versi&oacute; @version@ &eacute;s impossible. Pot ser que tingueu un problema de drets de modificaci&oacute; de la base de dades. Si us plau, contacteu amb el vostre prove&iuml;dor d\'hostatge.',
 'alerte_modif_info_concourante' => 'ATENCI&Oacute;: Aquesta informaci&oacute; s\'ha modificat per una altra banda. El valor actual &eacute;s:',
 'analyse_xml' => 'An&agrave;lisi XML',
 'annuler' => 'Anul&middot;lar',
@@ -188,7 +188,13 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 'date_saison_2' => 'primavera',
 'date_saison_3' => 'estiu',
 'date_saison_4' => 'tardor',
+'date_secondes' => 'segons',
 'date_semaines' => 'setmanes',
+'date_un_mois' => 'mes',
+'date_une_heure' => 'hora',
+'date_une_minute' => 'minut',
+'date_une_seconde' => 'segon',
+'date_une_semaine' => 'setmana',
 'dirs_commencer' => 'per comen&ccedil;ar realment la instal&middot;laci&oacute;',
 'dirs_preliminaire' => 'Preliminar: <b>Regular els drets d\'acc&eacute;s</b>',
 'dirs_probleme_droits' => 'Problema de drets d\'acc&eacute;s',
@@ -198,7 +204,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 'dirs_repertoires_suivants' => '<p><b>Els seg&uuml;ents directoris no s&oacute;n accessibles a l\'escriptura:</b></p> <ul>@bad_dirs@</ul>
   <p>Per solucionar-ho, feu servir el vostre client FTP per tal de regular els drets d\'acc&eacute;s de cadascun d\'aquests directoris. El procediment s\'explica detalladament a la guia d\'instal&middot;laci&oacute;.</p>
   <p>Un cop feta aquesta manipulaci&oacute;, podreu ',
-'double_occurrence' => 'Doble inst&agrave;ncia',
+'double_occurrence' => 'Doble inst&agrave;ncia de @balise@ ',
 
 // E
 'en_cours' => 'en curs',
@@ -213,6 +219,16 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 
 // F
 'fichier_introuvable' => 'Fitxer @fichier@ introbable',
+'form_auteur_confirmation' => 'Confirmeu el vostre correu electr&ograve;nic',
+'form_auteur_email_modifie' => 'El vostre correu electr&ograve;nic s\'ha modificat.',
+'form_auteur_envoi_mail_confirmation' => 'Us acabem d\'enviar un correu electr&ograve;nic de confirmaci&oacute; a @email@. Per validar la vostra adre&ccedil;a de correu electr&ograve;nic, haureu de visitar l\'adre&ccedil;a Web esmentada en aquest correu.',
+'form_auteur_mail_confirmation' => 'Bon dia,
+
+Heu demanat canviar la vostra adre&ccedil;a electr&ograve;nica.
+Per confirmar la nova adre&ccedil;a, nom&eacute;s heu de connectar-vos a l\'adre&ccedil;a que hi ha m&eacute;s avall (de no fer-ho aix&iacute;, la vostra petici&oacute; s\'ignorar&agrave;):
+
+    @url@
+',
 'form_deja_inscrit' => 'Ja est&agrave;s inscrit/a.',
 'form_email_non_valide' => 'La seva adre&ccedil;a electr&ograve;nica no ha estat validada.',
 'form_forum_access_refuse' => 'No teniu acc&eacute;s a aquest lloc.',
@@ -265,7 +281,7 @@ Gr&agrave;cies per la participaci&oacute;
 'form_pet_signature_validee' => 'La seva signatura ha estat validada. Gr&agrave;cies!',
 'form_pet_site_deja_enregistre' => 'Aquest lloc est&agrave; ja enregistrat',
 'form_pet_url_invalide' => 'L\'URL que heu indicat no &eacute;s v&agrave;lida.',
-'form_pet_votre_email' => 'El vostre correu electr&ograve;nic',
+'form_pet_votre_email' => 'Correu electr&ograve;nic:',
 'form_pet_votre_nom' => 'El vostre nom o pseud&ograve;nim',
 'form_pet_votre_site' => 'Si teniu un lloc Web, podeu indicar-ho aqu&iacute; sota',
 'form_prop_confirmer_envoi' => 'Confirmar l\'enviament',
@@ -278,7 +294,7 @@ Gr&agrave;cies per la participaci&oacute;
 'form_prop_message_envoye' => 'Missatge enviat',
 'form_prop_nom_site' => 'Nom del lloc',
 'form_prop_non_enregistre' => 'La seva proposta no ha estat registrada.',
-'form_prop_sujet' => 'Assumpte',
+'form_prop_sujet' => 'Assumpte:',
 'form_prop_url_site' => 'Adre&ccedil;a (URL) del lloc',
 'forum_acces_refuse' => 'Ja no teniu acc&eacute;s a aquests f&ograve;rums.',
 'forum_attention_dix_caracteres' => '<b>Atenci&oacute;!</b> el vostre missatge ha de tenir almenys deu car&agrave;cters.',
@@ -298,7 +314,7 @@ Gr&agrave;cies per la participaci&oacute;
 'forum_poste_par' => 'Missatge enviat@parauteur@ a continuaci&oacute; de l\'article &laquo; @titre@ &raquo;.',
 'forum_probleme_database' => 'Problema de la base de dades, el vostre missatge no s\'ha registrat.',
 'forum_qui_etes_vous' => '<b>Qui s&oacute;u?</b> (opcional)',
-'forum_texte' => 'Text del vostre missatge:',
+'forum_texte' => 'Text del missatge:',
 'forum_titre' => 'Titol:',
 'forum_titre_erreur' => 'Error...',
 'forum_url' => 'URL:',
@@ -387,19 +403,23 @@ Si ja n\'esteu, escriviu a continuaci&oacute; l\'identifcador que us ha estat pr
 'info_article_supprime' => 'Article suprimit',
 'info_articles' => 'Articles',
 'info_articles_a_valider' => 'Articles per validar',
+'info_articles_nb' => '@nb@ articles',
 'info_articles_proposes' => 'Articles proposats',
+'info_articles_un' => '1 article',
 'info_auteurs_nombre' => 'autor(s)/es:',
 'info_authentification_ftp' => 'Autenticaci&oacute; (per FTP).',
 'info_bloquer_lien' => 'blocar aquest enlla&ccedil;',
 'info_breves_02' => 'Breus',
 'info_breves_2' => 'breus',
+'info_breves_nb' => '@nb@ breus',
+'info_breves_un' => '1 breu',
 'info_breves_valider' => 'Breus per validar',
 'info_connexion_refusee' => 'Connexi&oacute; denegada',
 'info_contact_developpeur' => 'Contacteu amb un desenvolupador.',
 'info_contenance' => 'Aquest lloc cont&eacute;:',
 'info_contribution' => 'contribucions del f&ograve;rum',
 'info_copyright' => '@spip@ &eacute;s programari lliure distribu&iuml;t @lien_gpl@.',
-'info_copyright_doc' => 'Per a m&eacute;s informaci&oacute;, veure el lloc <a href=\'http://www.spip.net/ca\'>http://www.spip.net/ca</a>.',
+'info_copyright_doc' => 'Per a m&eacute;s informaci&oacute;, veure el lloc <a href="@spipnet@">http://www.spip.net/ca</a>.',
 'info_copyright_gpl' => 'sota llic&egrave;ncia GPL',
 'info_cours_edition' => 'Els vostres articles en proc&eacute;s de redacci&oacute;',
 'info_creer_repertoire' => 'Creeu un fitxer o un directori anomenat:',
@@ -413,6 +433,8 @@ Si ja n\'esteu, escriviu a continuaci&oacute; l\'identifcador que us ha estat pr
 'info_document' => 'Document',
 'info_document_indisponible' => 'Aquest document no est&agrave; disponible',
 'info_documents' => 'Documents',
+'info_documents_nb' => '@nb@ documents',
+'info_documents_un' => '1 document',
 'info_echange_message' => 'SPIP permet l\'intercanvi de missatges i la creaci&oacute; de f&ograve;rums de discussi&oacute;
   privats entre els participants d\'un lloc. Podeu habilitar o
   inhabilitar aquesta funcionalitat.',
@@ -459,6 +481,8 @@ Si ja n\'esteu, escriviu a continuaci&oacute; l\'identifcador que us ha estat pr
 'info_mail_fournisseur' => 'elteu@proveidor.com',
 'info_message_2' => 'MISSATGE',
 'info_message_supprime' => 'MISSATGE SUPRIMIT',
+'info_messages_nb' => '@nb@ missatges',
+'info_messages_un' => '1 missatge',
 'info_mise_en_ligne' => 'Data de publicaci&oacute;:',
 'info_modification_parametres_securite' => 'modificacions dels par&agrave;metres de seguretat',
 'info_mois_courant' => 'Durant aquest mes:',
@@ -503,6 +527,8 @@ Si ja n\'esteu, escriviu a continuaci&oacute; l\'identifcador que us ha estat pr
 'info_retablir_lien' => 'restaurar aquest enlla&ccedil;',
 'info_retirer_mot' => 'suprimir aquesta paraula',
 'info_retirer_mots' => 'suprimir totes les paraules',
+'info_rubriques_nb' => '@nb@ seccions',
+'info_rubriques_un' => '1 secci&oacute;',
 'info_sans_titre_2' => 'sense t&iacute;tol',
 'info_selectionner_fichier' => 'Podeu seleccionar un fitxer de la carpeta @upload@',
 'info_selectionner_fichier_2' => 'Seleccionar un fitxer:',
@@ -511,7 +537,9 @@ Si ja n\'esteu, escriviu a continuaci&oacute; l\'identifcador que us ha estat pr
 'info_site_attente' => 'Lloc Web pendent de validaci&oacute;',
 'info_site_reference' => 'Lloc referenciat en l&iacute;nia',
 'info_site_refuse' => 'Lloc Web rebutjat',
+'info_sites_nb' => '@nb@ llocs',
 'info_sites_referencer' => 'Referenciar un lloc',
+'info_sites_un' => '1 lloc',
 'info_supprimer_vignette' => 'suprimir la icona',
 'info_symbole_bleu' => 'El s&iacute;mbol <b>blau</b> indica un <b>recordatori</b>: &eacute;s a dir un missatge per a &uacute;s personal.',
 'info_symbole_jaune' => 'El s&iacute;mbol <b>groc</b> indica un <b>av&iacute;s a tots els redactors</b>&nbsp;: modificable per tots els administradors i visible per tots els redactors.',
@@ -542,7 +570,6 @@ Si ja n\'esteu, escriviu a continuaci&oacute; l\'identifcador que us ha estat pr
 'lien_afficher_icones_seuls' => 'Mostrar nom&eacute;s les icones',
 'lien_afficher_texte_icones' => 'Mostrar les icones i el text',
 'lien_afficher_texte_seul' => 'Mostrar nom&eacute;s el text',
-'lien_icones_interface' => 'Les icones de la interf&iacute;cie s&oacute;n de <a href=\'http://jimmac.musichall.cz/\'>Jakub \'Jimmac\' Steiner</a>.',
 'lien_liberer' => 'alliberar',
 'lien_liberer_tous' => 'alliberar aquests articles',
 'lien_nouvea_pense_bete' => 'NOU RECORDATORI',
@@ -583,6 +610,7 @@ Si ja n\'esteu, escriviu a continuaci&oacute; l\'identifcador que us ha estat pr
 'login_retour_site' => 'Tornar al lloc p&uacute;blic',
 'login_retoursitepublic' => 'tornar al lloc p&uacute;blic',
 'login_sans_cookiie' => 'Identificaci&oacute; sense galeta',
+'login_securise' => 'Inici de sessi&oacute; segur',
 'login_sinscrire' => 'inscriure\'s',
 'login_test_navigateur' => 'prova de navegador/tornar a connectar',
 'login_verifiez_navigateur' => '(Verifiqueu no obstant que el vostre navegador no ha memoritzat la contrasenya...)',
@@ -725,34 +753,34 @@ i tornar-vos a connectar al lloc.
 
 // Z
 'zbug_balise_b_aval' => '&nbsp;: l\'etiqueta B ha d\'anar abans',
-'zbug_balise_inexistante' => 'error @from@: l\'etiqueta #@balise@ no existeix',
+'zbug_balise_inexistante' => 'etiqueta @balise@ mal declarada per a @from@ ',
 'zbug_balise_sans_argument' => 'Argument que falta a l\'etiqueta @balise@',
 'zbug_boucle' => 'bucle',
-'zbug_boucle_recursive_undef' => 'bucle recurrent no definit',
+'zbug_boucle_recursive_undef' => 'Bucle recurrent no definit: @nom@',
 'zbug_calcul' => 'c&agrave;lcul',
 'zbug_champ_hors_boucle' => 'Camp @champ@ fora de bucle',
-'zbug_champ_hors_motif' => 'Camp @champ@ fora del context d\'un bucle  @motif@',
+'zbug_champ_hors_motif' => 'Camp @champ@ fora d\'un context @motif@',
 'zbug_code' => 'codi',
-'zbug_critere_inconnu' => 'criteri desconegut @critere@',
-'zbug_distant_interdit' => 'prohibit amb dades externes',
-'zbug_doublon_table_sans_cle_primaire' => 'doublons en una taula sense clau prim&agrave;ria at&ograve;mica',
-'zbug_doublon_table_sans_index' => 'dobles em una taula sense &iacute;ndex',
-'zbug_erreur_boucle_double' => 'BOUCLE@id@: doble definici&oacute;',
-'zbug_erreur_boucle_fermant' => ' BOUCLE@id@: falta tag que tanque',
-'zbug_erreur_boucle_syntaxe' => 'Sintaxi incorrecte del bucle',
+'zbug_critere_inconnu' => 'Criteri desconegut @critere@',
+'zbug_distant_interdit' => 'Prohibit amb dades externes',
+'zbug_doublon_table_sans_cle_primaire' => 'Doublons en una taula sense clau prim&agrave;ria at&ograve;mica',
+'zbug_doublon_table_sans_index' => 'Doublons em una taula sense &iacute;ndex',
+'zbug_erreur_boucle_double' => 'Doble definici&oacute; del bucle @id@ ',
+'zbug_erreur_boucle_fermant' => 'Bucle @id@ no tancat',
+'zbug_erreur_boucle_syntaxe' => 'Sintaxi incorrecte del bucle @id@',
 'zbug_erreur_compilation' => 'Error de compilaci&oacute;',
-'zbug_erreur_execution_page' => 'error d\'execuci&oacute; de la p&agrave;gina',
-'zbug_erreur_filtre' => 'Error: filtre <b>&laquo; @filtre@ &raquo;</b> no definit',
-'zbug_erreur_meme_parent' => '{meme_parent} nom&eacute;s s\'aplica als bucles (FORUMS) o (RUBRIQUES)',
+'zbug_erreur_execution_page' => 'Eerror d\'execuci&oacute;',
+'zbug_erreur_filtre' => 'Filtre @filtre@ no definit',
+'zbug_erreur_meme_parent' => 'El criteri {meme_parent} nom&eacute;s s\'aplica als bucles (FORUMS) o (RUBRIQUES)',
 'zbug_erreur_squelette' => 'Error(s) en l\'esquelet',
 'zbug_hors_compilation' => 'Sense Compilaci&oacute;',
 'zbug_info_erreur_squelette' => 'Error en el lloc Web',
-'zbug_inversion_ordre_inexistant' => 'inversi&oacute; d\'un ordre inexistent',
-'zbug_pagination_sans_critere' => '#PAGINATION sense criteri {pagination} o  fet servir a dins d\'un bucle recursiu.',
-'zbug_parametres_inclus_incorrects' => 'Par&agrave;metres d\'inclusi&oacute; incorrectes',
+'zbug_inversion_ordre_inexistant' => 'Inversi&oacute; d\'un ordre inexistent',
+'zbug_pagination_sans_critere' => 'Etiqueta #PAGINATION sense criteri {pagination} o  fet servir a dins d\'un bucle recursiu.',
+'zbug_parametres_inclus_incorrects' => 'Par&agrave;metre d\'inclusi&oacute; incorrecte: @param@',
 'zbug_profile' => 'Temps de c&agrave;lcul&nbsp;: @time@',
 'zbug_resultat' => 'resultat',
-'zbug_serveur_indefini' => 'servidor SQL sense definir',
+'zbug_serveur_indefini' => 'Servidor SQL sense definir',
 'zbug_statistiques' => 'Estad&iacute;stiques de peticions SQL classificades per durada',
 'zbug_table_inconnue' => 'Taula SQL &laquo; @table@ &raquo; desconeguda',
 'zxml_connus_attributs' => 'atributs conneguts',
