@@ -68,7 +68,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 'bouton_changer' => '&Auml;ndern',
 'bouton_chercher' => 'Suchen',
 'bouton_choisir' => 'Ausw&auml;hlen',
-'bouton_download' => 'Herunterladen',
+'bouton_download' => '&Uuml;bertragen',
 'bouton_enregistrer' => 'Speichern',
 'bouton_radio_desactiver_messagerie_interne' => 'Interne Nachrichten abschalten',
 'bouton_radio_envoi_annonces' => 'Editorische Ank&uuml;ndigungen verschicken',
@@ -188,20 +188,26 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 'date_saison_2' => 'Fr&uuml;hling',
 'date_saison_3' => 'Sommer',
 'date_saison_4' => 'unabh&auml;ngig',
+'date_secondes' => 'Sekunden',
 'date_semaines' => 'Wochen',
+'date_un_mois' => 'Monat',
+'date_une_heure' => 'Stunde',
+'date_une_minute' => 'Minute',
+'date_une_seconde' => 'Sekunde',
+'date_une_semaine' => 'Woche',
 'dirs_commencer' => 'um die Installation wirklich zu starten',
 'dirs_preliminaire' => 'Vorbereitung: <b>Berechtigungen einstellen</b>',
 'dirs_probleme_droits' => 'Problem mit den Berechtigungen',
-'dirs_repertoires_absents' => '<p><b>Folgende Verzeichnisse wurden nicht gefunden:</b><(p><ul>@bad_dirs@</ul> 
+'dirs_repertoires_absents' => '<p><b>Folgende Verzeichnisse wurden nicht gefunden:</b></p><ul>@bad_dirs@</ul>
   <p>Das liegt wahrscheinlich an unzutreffender Gross- und Kleinschreibung.
   &Uuml;berpr&uuml;fen Sie bitte die genaue Schreibweise der oben stehenden Verzeichnisse,
-  sollten Sie Abweichungen feststellen, benennen Sie bitte mit Ihrem FTP-Programm die betreffenden Verzeichnisse um.
+  sollten Sie Abweichungen feststellen, benennen Sie bitte mit Ihrem FTP-Programm die betreffenden Verzeichnisse um.</p>
   <p>Danach k&ouml;nnen Sie ',
 'dirs_repertoires_suivants' => '<p><b>In die folgenden Verzeichnisse kann nicht geschrieben werden:</b></p><ul>@bad_dirs@</ul>
 <p>Um das Problem zu l&ouml;sen, verwenden Sie bitte Ihren FTP-Client, um die Zugriffsrechte f&uuml;r diese
 Verzeichnisse zu setzen.Die Installationsanleitung erl&auml;utert die Details dazu.</p>
 <p>Wenn Sie diesen Vorgang abgeschlossen haben, k&ouml;nnen Sie',
-'double_occurrence' => 'Dublette',
+'double_occurrence' => 'Dublette von @balise@',
 
 // E
 'en_cours' => 'l&auml;uft',
@@ -216,11 +222,22 @@ Verzeichnisse zu setzen.Die Installationsanleitung erl&auml;utert die Details da
 
 // F
 'fichier_introuvable' => 'Datei @fichier@ unauffindbar',
+'form_auteur_confirmation' => 'Best&auml;tigen Sie Ihre Mailadresse',
+'form_auteur_email_modifie' => 'Ihre Mailadresse wurde ge&auml;ndert.',
+'form_auteur_envoi_mail_confirmation' => 'Eine Mail wurde an @email@ gesendet. Sie m&uuml;ssen auf den in ihr angegebenen Link klicken, um die Korrektheit Ihrer Adresse zu best&auml;tigen.',
+'form_auteur_mail_confirmation' => 'Hallo,
+
+Sie m&ouml;chten Ihre Mail-Adresse &auml;ndern.Um Ihre neue Adresse zu best&auml;tigen,
+ brauchen Sie nur diesen Link zu &ouml;ffnen (wenn Sie darauf verzichten,
+wird Ihre Adresse beibehalten):
+
+    @url@
+',
 'form_deja_inscrit' => 'Sie sind bereits eingetragen.',
 'form_email_non_valide' => 'Ihre E-Mail-Adresse ist ung&uuml;ltig.',
 'form_forum_access_refuse' => 'Sie haben keinen Zugang mehr zu dieser Website.',
 'form_forum_bonjour' => 'Hallo @nom@,',
-'form_forum_email_deja_enregistre' => 'Diese E-mail-adresse ist bereits eingetragen. Sie k&ouml;nnen also Ihr normals Passwort verwenden.',
+'form_forum_email_deja_enregistre' => 'Diese E-Mail-Adresse ist bereits eingetragen. Sie k&ouml;nnen also Ihr normals Passwort verwenden.',
 'form_forum_identifiant_mail' => 'Ihre neuen Zugangsdaten wurden Ihnen per Mail zugestellt.',
 'form_forum_identifiants' => 'Pers&ouml;nliche Zugangsdaten',
 'form_forum_indiquer_nom_email' => 'Tragen Sie bitte hier Ihren Namen und Ihre E-Mail-Adresse ein. Die pers&ouml;nlichen Zugangsdaten werden Ihnen dann per E-Mail zugeschickt.',
@@ -386,19 +403,23 @@ Vielen Dank f&uuml;r Ihre Teilnahme
 'info_article_supprime' => 'Gel&ouml;schter Artikel',
 'info_articles' => 'Artikel',
 'info_articles_a_valider' => 'Zur Ver&ouml;ffentlichung vorgeschlagenen Artikel',
+'info_articles_nb' => '@nb@ Artikel',
 'info_articles_proposes' => 'Vorgeschlagene Artikel',
+'info_articles_un' => '1 Artikel',
 'info_auteurs_nombre' => 'Autor(en):',
 'info_authentification_ftp' => 'Authentifizierung per FTP.',
 'info_bloquer_lien' => 'Link sperren',
 'info_breves_02' => 'Meldungen',
 'info_breves_2' => 'Meldungen',
+'info_breves_nb' => '@nb@ Meldungen',
+'info_breves_un' => '1 Meldung',
 'info_breves_valider' => 'Zur Ver&ouml;ffentlichung vorgeschlagene Meldungen',
 'info_connexion_refusee' => 'Die Verbindung wurde verweigert.',
 'info_contact_developpeur' => 'Bitte kontaktieren Sie einen der Entwickler.',
 'info_contenance' => 'Diese Website enth&auml;lt:',
 'info_contribution' => 'Forumsbeitr&auml;ge',
 'info_copyright' => '@spip@ ist freie Software im Sinne der @lien_gpl@.',
-'info_copyright_doc' => 'Weitere Informationen finden Sie unter <a href=\'http://www.spip.net/de\'>http://www.spip.net/de</a>.',
+'info_copyright_doc' => 'Weitere Informationen finden Sie unter <a href="@spipnet@">http://www.spip.net/de</a>.',
 'info_copyright_gpl' => 'GNU Public License',
 'info_cours_edition' => 'Ihre Artikel in Bearbeitung',
 'info_creer_repertoire' => 'Bitte legen Sie eine Datei oder ein Verzeichnis mit diesem Namen an: ',
@@ -412,6 +433,8 @@ Vielen Dank f&uuml;r Ihre Teilnahme
 'info_document' => 'Dokument',
 'info_document_indisponible' => 'Dokument nicht verf&uuml;gbar',
 'info_documents' => 'Dokumente',
+'info_documents_nb' => '@nb@ Dokumente',
+'info_documents_un' => '1 Dokument',
 'info_echange_message' => 'In SPIP k&ouml;nnen Sie interne Nachrichten austauschen und interne Foren f&uuml;r Teilnehmer der Website anlegen. Diese Funktionen k&ouml;nnen Sie abschalten.',
 'info_ecire_message_prive' => 'Neue private Nachricht schreiben',
 'info_email_invalide' => 'Ung&uuml;ltige E-Mail Adresse.',
@@ -456,6 +479,8 @@ Vielen Dank f&uuml;r Ihre Teilnahme
 'info_mail_fournisseur' => 'IhrName@Server.de',
 'info_message_2' => 'NACHRICHT',
 'info_message_supprime' => 'NACHRICHT GEL&Ouml;SCHT',
+'info_messages_nb' => '@nb@ Nachrichten',
+'info_messages_un' => '1 Nachricht',
 'info_mise_en_ligne' => 'Online seit:',
 'info_modification_parametres_securite' => '&Auml;nderung der Sicherheitseinstellungen',
 'info_mois_courant' => 'Im Lauf des Monats:',
@@ -500,6 +525,8 @@ Vielen Dank f&uuml;r Ihre Teilnahme
 'info_retablir_lien' => 'Link wieder freigeben',
 'info_retirer_mot' => 'Wort entfernen',
 'info_retirer_mots' => 'Alle Worte entfernen',
+'info_rubriques_nb' => '@nb@ Rubriken',
+'info_rubriques_un' => '1 Rubrik',
 'info_sans_titre_2' => 'ohne Titel',
 'info_selectionner_fichier' => 'Sie k&ouml;nnen eine Datei aus dem Verzeichnis @upload@ ausw&auml;hlen.',
 'info_selectionner_fichier_2' => 'W&auml;hlen Sie eine Datei:',
@@ -508,7 +535,9 @@ Vielen Dank f&uuml;r Ihre Teilnahme
 'info_site_attente' => 'Websites, die auf Freigabe warten',
 'info_site_reference' => 'Verlinkte Website online',
 'info_site_refuse' => 'Abgelehnte Website',
+'info_sites_nb' => '@nb@ Websites',
 'info_sites_referencer' => 'Website verlinken',
+'info_sites_un' => '1 Website',
 'info_supprimer_vignette' => 'Icon l&ouml;schen',
 'info_symbole_bleu' => 'Das <b>blaue</b> Symbol bedeutet <b>Merkzettel</b>, d.h. eine Nachricht nur zu Ihrer eigenen Verwendung.',
 'info_symbole_jaune' => 'Das <b>gelbe</b> Symbol bedeutet <b>Ank&uuml;ndigung an alle Redakteure</b> (f&uuml;r alle Redakteure sichtbar, &Auml;nderung nur durch Administratoren)',
@@ -539,7 +568,6 @@ Vielen Dank f&uuml;r Ihre Teilnahme
 'lien_afficher_icones_seuls' => 'Nur Piktogramme anzeigen',
 'lien_afficher_texte_icones' => 'Piktogramme und Beschriftung anzeigen',
 'lien_afficher_texte_seul' => 'Nur Textmen&uuml;s',
-'lien_icones_interface' => 'Piktogramme von <a href=\'http://jimmac.musichall.cz/\'>Jakub \'Jimmac\' Steiner</a>.',
 'lien_liberer' => 'freigeben',
 'lien_liberer_tous' => 'diese Artikel freigeben',
 'lien_nouvea_pense_bete' => 'NEUER MERKZETTEL',
@@ -579,7 +607,8 @@ Vielen Dank f&uuml;r Ihre Teilnahme
 'login_retour_public' => 'Zur&uuml;ck zur &ouml;ffentlichen Website',
 'login_retour_site' => 'Zur&uuml;ck zur &ouml;ffentlichen Website',
 'login_retoursitepublic' => 'Zur&uuml;ck&nbsp;zur&nbsp;&ouml;ffentlichen&nbsp;Website',
-'login_sans_cookiie' => 'Anmeldung ohne Coockies',
+'login_sans_cookiie' => 'Anmeldung ohne Cookies',
+'login_securise' => 'Sicheres Login',
 'login_sinscrire' => 'anmelden',
 'login_test_navigateur' => 'Test Webbrowser/Verbindung',
 'login_verifiez_navigateur' => '(&Uuml;berpr&uuml;fen Sie, dass Ihr Webbrowser Ihr Passwort nicht gespeichert hat ...)',
@@ -665,7 +694,7 @@ Sie k&ouml;nnen auf dieser Seite ein neues Passwort eingeben und sich wieder bei
 'taille_ko' => '@taille@&nbsp;kB',
 'taille_mo' => '@taille@&nbsp;MB',
 'taille_octets' => '@taille@&nbsp;Byte',
-'texte_actualite_site_1' => 'Wenn Sie sich mit der Oberfl&auml;che des Redaktionssystems vertraut gemacht haben, k&ouml;nnen Sie ',
+'texte_actualite_site_1' => 'Wenn Sie sich mit der Oberfl&auml;che des Redaktionssystems vertraut gemacht haben, k&ouml;nnen Sie „',
 'texte_actualite_site_2' => 'den Expertenmodus aktivieren,',
 'texte_actualite_site_3' => 'um zus&auml;tzliche Funktionen zu nutzen.',
 'texte_creation_automatique_vignette' => 'Diese Website generiert automatisch Vorschaubilder. Wenn Sie Bilder in den Formaten @gd_formats@ mit diesem Formular installieren, werden Vorschaubilder mit den maximalen Diemsionen @taille_preview@ Pixel angelegt.',
@@ -715,31 +744,31 @@ Sie k&ouml;nnen auf dieser Seite ein neues Passwort eingeben und sich wieder bei
 
 // Z
 'zbug_balise_b_aval' => '&nbsp;: Tag B muss vor der Schleife stehen',
-'zbug_balise_inexistante' => 'Fehler @from@: Der Tag #@balise@ existiert nicht',
+'zbug_balise_inexistante' => 'Fehler: Der Tag @balise@ wurde nicht richtig f&uuml;r  @from@ deklariert.',
 'zbug_balise_sans_argument' => 'Dem Tag @balise@ fehlt ein Parameter',
 'zbug_boucle' => 'Schleife',
-'zbug_boucle_recursive_undef' => 'rekursive Schleife nicht definiert',
+'zbug_boucle_recursive_undef' => 'Die rekursive Schleife @nom@ ist nicht definiert',
 'zbug_calcul' => 'berechnen',
 'zbug_champ_hors_boucle' => 'Feld @champ@ ausserhalb einer Schleife',
-'zbug_champ_hors_motif' => 'Feld @champ@ ausserhalb des zutreffenden Kontext (Schleife) @motif@',
+'zbug_champ_hors_motif' => 'Feld @champ@ befindet sich ausserhalb eines Kontexts @motif@',
 'zbug_code' => 'Code',
-'zbug_critere_inconnu' => 'unbekanntes Kriterium @critere@',
-'zbug_distant_interdit' => 'extern unzul&auml;ssig',
+'zbug_critere_inconnu' => 'Unbekanntes Kriterium @critere@',
+'zbug_distant_interdit' => 'Extern unzul&auml;ssig',
 'zbug_doublon_table_sans_cle_primaire' => 'Dublette in einer Tabelle ohne eindeutigen Prim&auml;rschl&uuml;ssel',
 'zbug_doublon_table_sans_index' => 'Dublette in Tabelle ohne Index',
-'zbug_erreur_boucle_double' => 'BOUCLE@id@: doppelt vorhanden',
-'zbug_erreur_boucle_fermant' => 'BOUCLE@id@: Schluss-Tag fehlt',
-'zbug_erreur_boucle_syntaxe' => 'Syntax der Schleife fehlerhaft',
+'zbug_erreur_boucle_double' => 'Schleife (BOUCLE) @id@ doppelt vorhanden',
+'zbug_erreur_boucle_fermant' => 'Schleife (BOUCLE) @id@: Schluss-Tag fehlt',
+'zbug_erreur_boucle_syntaxe' => 'Syntax der Schleife @id@ fehlerhaft',
 'zbug_erreur_compilation' => 'Fehler beim Kompilieren',
-'zbug_erreur_execution_page' => 'Fehler beim Ausf&uuml;hren der Seite',
-'zbug_erreur_filtre' => 'Fehler: Filter<b>&laquo; @filtre@ &raquo;</b> ist nicht definiert',
-'zbug_erreur_meme_parent' => '{meme_parent} nur in den Schleifen (FORUMS) und (RUBRIQUES) verwenden.',
+'zbug_erreur_execution_page' => 'Fehler beim Ausf&uuml;hren',
+'zbug_erreur_filtre' => 'Der Filter @filtre@ ist nicht definiert.',
+'zbug_erreur_meme_parent' => 'Das Kriterium {meme_parent} funktioniert nur mit den Schleifen (FORUMS) und (RUBRIQUES).',
 'zbug_erreur_squelette' => 'Fehler in Layoutvorlage (Skelett)',
 'zbug_hors_compilation' => 'Au&szlig;erhalb der Kompilation',
 'zbug_info_erreur_squelette' => 'Irrtum auf der Seite',
 'zbug_inversion_ordre_inexistant' => 'Umkehrung einer inexistenten Sortierung ',
 'zbug_pagination_sans_critere' => '#PAGINATION ohne Kriterium {pagination} oder in rekursiver Schleife',
-'zbug_parametres_inclus_incorrects' => 'INCLUDE-Parameter fehlerhaft',
+'zbug_parametres_inclus_incorrects' => 'INCLUDE-Parameter fehlerhaft: @param@',
 'zbug_profile' => 'Rechenzeit: @time@',
 'zbug_resultat' => 'Ergebnis',
 'zbug_serveur_indefini' => 'SQL-Server nicht definiert',
