@@ -23,11 +23,11 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 'admin_modifier_mot' => 'Modificar esta palabra clave',
 'admin_modifier_rubrique' => 'Modificar esta secci&oacute;n',
 'admin_recalculer' => 'Actualizar esta p&aacute;gina',
-'afficher_trad' => 'Mostrar las traducciones',
-'alerte_maj_impossible' => '<<b>&iexcl;Alerta!</b> La actualizaci&oacute;n de la base SQL hacia la versi&oacute;n  @version@ es imposible, quiz&aacute;s por un problema de derechos de modificaci&oacute;n de la base de datos. Por favor, contacta a tu hospedaje.',
-'alerte_modif_info_concourante' => 'ATENCI&Oacute;N: Esta informaci&oacute;n se ha modificado en otra parte. El valor actual es:',
+'afficher_trad' => 'mostrar las traducciones',
+'alerte_maj_impossible' => '<<b>&iexcl;Alerta!</b> La actualizaci&oacute;n de la base SQL a la versi&oacute;n @version@ es imposible, quiz&aacute;s por un problema de derechos de modificaci&oacute;n de la base de datos. Por favor, contacta a tu hospedaje.',
+'alerte_modif_info_concourante' => 'ATENCI&Oacute;N: Esta informaci&oacute;n fue modificada por otro lado. El valor actual es:',
 'analyse_xml' => 'An&aacute;lisis XML',
-'annuler' => 'Anular',
+'annuler' => 'Cancelar',
 'antispam_champ_vide' => 'Por favor, deje este campo vac&iacute;o&nbsp;:',
 'articles_recents' => 'Los art&iacute;culos m&aacute;s recientes',
 'avis_archive_incorrect' => 'El archivo de respaldo no es un archivo SPIP.',
@@ -54,7 +54,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 'barre_euro' => 'Insertar el s&iacute;mbolo &euro;',
 'barre_gras' => 'Poner en {{negrita}}',
 'barre_guillemets' => 'Poner entre &laquo;comillas&raquo;',
-'barre_guillemets_simples' => 'Poner entre &#147;comillas de segundo nivel',
+'barre_guillemets_simples' => 'Poner entre &#147;comillas de segundo nivel”',
 'barre_intertitre' => 'Transformar en {{{inter-t&iacute;tulo}}}',
 'barre_italic' => 'Poner en {cursiva}',
 'barre_lien' => 'Transformar en [enlace hipertexto->http://...]',
@@ -88,7 +88,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 'choix_couleur_interface' => 'color',
 'choix_interface' => 'Selecci&oacute;n de la interfase',
 'colonne' => 'Columna',
-'confirm_changer_statut' => 'Cuidado, has pedido cambiar el estado de este elemento. &iquest;Deseas continuar?',
+'confirm_changer_statut' => 'Cuidado, est&aacute;s cambiando el estado de este elemento. &iquest;Lo confirmas?',
 'correcte' => 'correcta',
 
 // D
@@ -188,7 +188,13 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 'date_saison_2' => 'primavera',
 'date_saison_3' => 'verano',
 'date_saison_4' => 'oto&ntilde;o',
+'date_secondes' => 'segundos',
 'date_semaines' => 'semanas',
+'date_un_mois' => 'mes',
+'date_une_heure' => 'hora',
+'date_une_minute' => 'minuto',
+'date_une_seconde' => 'segundo',
+'date_une_semaine' => 'semana',
 'dirs_commencer' => 'Para empezar realmente la instalaci&oacute;n',
 'dirs_preliminaire' => 'Preliminar: <b>Regular los derechos de acceso</b>',
 'dirs_probleme_droits' => 'Problema de derechos de acceso',
@@ -200,7 +206,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 <p>Para solucionar el problema debes utilizar un cliente FTP para cambiar los derechos de acceso a cada una
 de las carpetas mencionadas. El procedimiento se explica detalladamente en la gu&iacute;a de instalaci&oacute;n.</p>
 <p>Una vez terminado este proceso, podr&aacute;s ',
-'double_occurrence' => 'Doble ocurrencia',
+'double_occurrence' => 'Doble ocurrencia de @balise@',
 
 // E
 'en_cours' => 'en curso',
@@ -215,6 +221,18 @@ de las carpetas mencionadas. El procedimiento se explica detalladamente en la gu
 
 // F
 'fichier_introuvable' => 'No se encuentra el archivo @fichier@',
+'form_auteur_confirmation' => 'Confirma tu direcci&oacute;n de correo',
+'form_auteur_email_modifie' => 'Tu direcci&oacute;n de correo fue modificada',
+'form_auteur_envoi_mail_confirmation' => 'Se te acaba de enviar un mensaje de confirmaci&oacute;n a @email@. Tienes que visitar la p&aacute;gina web indicada en ese mensaje para validar tu direcci&oacute;n de correo.',
+'form_auteur_mail_confirmation' => 'Hola,
+
+Has solicitado cambiar tu direcci&oacute;n de correo.
+Para confirmar tu nueva direcci&oacute;n, alcanza con visitar la p&aacute;gina
+siguiente:
+
+    @url@
+Caso contrario, la solicitud ser&aacute; simplemente ignorada.
+',
 'form_deja_inscrit' => 'Ya est&aacute;s inscrito.',
 'form_email_non_valide' => 'La direcci&oacute;n de correo electr&oacute;nico no es v&aacute;lida.',
 'form_forum_access_refuse' => 'Ya no tienes acceso a este sitio.',
@@ -239,23 +257,22 @@ en el sitio "@nom_site_spip@" (@adresse_login@):',
 'form_pet_confirmation' => 'Ratifica tu firma: ',
 'form_pet_deja_enregistre' => 'Este sitio ya est&aacute; registrado',
 'form_pet_deja_signe' => 'Ya has firmado este texto.',
-'form_pet_envoi_mail_confirmation' => 'Acabamos de enviar un correo electr&oacute;nico de confirmaci&oacute;n a @email@. Tienes que visitar la direcci&oacute;n Web mencionada en ese mensaje para validar tu firma.',
+'form_pet_envoi_mail_confirmation' => 'Se acaba de enviar un mensaje de confirmaci&oacute;n a @email@. Tienes que ingresar a la direcci&oacute;n Web que contiene para validar tu firma.',
 'form_pet_mail_confirmation' => 'Hola,
 
-Has solicitado firmar la petici&oacute;n:
+Has solicitado a&ntilde;adir tu firma a:
 @titre@.
 
-Has facilitado la siguient informaci&oacute;n:
+Con la siguiente informaci&oacute;n:
 
     Nombre: @nom_email@
     Sitio: @nom_site@ - @url_site@
     @message@
 
 IMPORTANTE...
-
-Para validar tu firma, basta con conectarte a
-la direcci&oacute;n indicada a continuaci&oacute;n (en caso contrario, tu firma
-no ser&aacute; tomada en cuenta):
+Para confirmar tu firma, debes ingresar a
+la direcci&oacute;n web indicada a continuaci&oacute;n (de lo contrario, tu firma
+no podr&aacute; ser tomada en cuenta):
 
     @url@
 
@@ -264,7 +281,7 @@ Gracias por tu participaci&oacute;n
 ',
 'form_pet_message_commentaire' => '&iquest;Un mensaje, un comentario?',
 'form_pet_nom_site2' => 'Nombre de tu sitio Web',
-'form_pet_probleme_liens' => 'Pon otra vez tu mensaje, quitando los caracteres html.',
+'form_pet_probleme_liens' => 'Ingresa nuevamente tu mensaje, quitando los enlaces hypertexto.',
 'form_pet_probleme_technique' => 'Problema t&eacute;cnico, las firmas est&aacute;n temporalmente suspendidas.',
 'form_pet_signature_pasprise' => 'Tu firma no ha sido tomada en cuenta.',
 'form_pet_signature_validee' => 'Tu firma est&aacute; validada. &iexcl;Gracias!',
@@ -288,7 +305,7 @@ Gracias por tu participaci&oacute;n
 'forum_acces_refuse' => 'Ya no tienes acceso a estos foros.',
 'forum_attention_dix_caracteres' => '<b>&iexcl;Atenci&oacute;n!</b> tu mensaje debe tener al menos diez caracteres.',
 'forum_attention_trois_caracteres' => '<b>&iexcl;Atenci&oacute;n!</b> el t&iacute;tulo debe tener al menos tres caracteres.',
-'forum_attention_trop_caracteres' => '<b>&iexcl;Atenci&oacute;n&nbsp;!</b> su mensaje es demasiado largo (@compte@ caracteres)&nbsp;: para poder registrarlo, no debe sobrepasar los @max@ caracteres.',
+'forum_attention_trop_caracteres' => '<b>&iexcl;Atenci&oacute;n!</b> el mensaje es demasiado largo (@compte@ caracteres): para poder guardarlo, no debe sobrepasar los @max@ caracteres.',
 'forum_avez_selectionne' => 'Has seleccionado:',
 'forum_cliquer_retour' => 'Pinchar <a href=\'@retour_forum@\'>aqu&iacute;</a> para continuar.',
 'forum_forum' => 'foro',
@@ -352,7 +369,7 @@ suministrado. Si no est&aacute;s inscrito/a, debes',
 'icone_repartition_debut' => 'Mostrar el reparto desde el comienzo',
 'icone_repartition_visites' => 'Distribuci&oacute;n de las visitas',
 'icone_rubriques' => 'Secciones',
-'icone_sauver_site' => 'Hacer una copia de seguridad del sitio',
+'icone_sauver_site' => 'Respaldo del sitio',
 'icone_site_entier' => 'Todo el sitio',
 'icone_sites_references' => 'Sitios referenciados',
 'icone_statistiques' => 'Estad&iacute;sticas del sitio',
@@ -393,19 +410,23 @@ suministrado. Si no est&aacute;s inscrito/a, debes',
 'info_article_supprime' => 'Art&iacute;culo suprimido',
 'info_articles' => 'Art&iacute;culos',
 'info_articles_a_valider' => 'Los art&iacute;culos a validar',
+'info_articles_nb' => '@nb@ art&iacute;culos',
 'info_articles_proposes' => 'Art&iacute;culos propuestos',
+'info_articles_un' => '1 art&iacute;culo',
 'info_auteurs_nombre' => 'Autora(s) y autor(es):',
 'info_authentification_ftp' => 'Autentificaci&oacute;n (por FTP).',
 'info_bloquer_lien' => 'bloquear este enlace',
 'info_breves_02' => 'Breves',
 'info_breves_2' => 'breves',
+'info_breves_nb' => '@nb@ breves',
+'info_breves_un' => '1 breve',
 'info_breves_valider' => 'Breves a validar',
 'info_connexion_refusee' => 'Conexi&oacute;n rechazada',
 'info_contact_developpeur' => 'Debes contactar con un programador.',
 'info_contenance' => 'Este sitio contiene:',
 'info_contribution' => 'contribuciones del foro',
 'info_copyright' => '@spip@ es un software libre distribu&iacute;do @lien_gpl@.',
-'info_copyright_doc' => 'Para mayor informaci&oacute;n, ver el sitio <a href=\'http://www.spip.net/es\'>http://www.spip.net/es</a>.',
+'info_copyright_doc' => 'Para mayor informaci&oacute;n, ver el sitio <a href="@spipnet@">http://www.spip.net/es</a>.',
 'info_copyright_gpl' => 'bajo licencia GPL',
 'info_cours_edition' => 'Tus art&iacute;culos en curso de redacci&oacute;n',
 'info_creer_repertoire' => 'Debes crear un archivo o una carpeta llamada',
@@ -419,6 +440,8 @@ suministrado. Si no est&aacute;s inscrito/a, debes',
 'info_document' => 'Documento',
 'info_document_indisponible' => 'Este documento no est&aacute; disponible',
 'info_documents' => 'Documentos',
+'info_documents_nb' => '@nb@ documentos',
+'info_documents_un' => '1 documento',
 'info_echange_message' => 'En funci&oacute;n de las preferencias, SPIP permite el intercambio de mensajes y la existencia de foros internos
  privados entre los participantes del sitio. Esta funcionalidad
 se puede activar o desactivar .',
@@ -465,12 +488,14 @@ se puede activar o desactivar .',
 'info_mail_fournisseur' => 'tu@proveedor.com',
 'info_message_2' => 'MENSAJE',
 'info_message_supprime' => 'Mensaje suprimido',
+'info_messages_nb' => '@nb@ mensajes',
+'info_messages_un' => '1 mensaje',
 'info_mise_en_ligne' => 'Fecha de puesta en l&iacute;nea',
 'info_modification_parametres_securite' => 'modificaciones de los par&aacute;metros de seguridad',
 'info_mois_courant' => 'En el mes actual de: ',
 'info_mot_cle_ajoute' => 'La palabra clave siguiente ha sido a&ntilde;adida al art&iacute;culo',
 'info_multi_herit' => 'Idioma por omisi&oacute;n',
-'info_multi_langues_soulignees' => 'Los <u>idiomas subrayados</u> ofrecen una traducci&oacute;n de todos los textos de la interfaz. Si seleccionas dichos idiomas, varios elementos del sitio p&uacute;blico (fechas, formularios) se traducir&aacute;n autom&aacute;ticamente. Para los idiomas no subrayados, los elementos aparecer&aacute;n en la lengua principal del sitio.',
+'info_multi_langues_soulignees' => 'Los <u>idiomas subrayados</u> disponen de una traducci&oacute;n los textos de la interfaz. Si los seleccionas, diversos elementos del sitio p&uacute;blico (fechas, formularios) ser&aacute;n traducidos autom&aacute;ticamente. En los idiomas no subrayados, dichos elementos aparecer&aacute;n en la lengua principal del sitio.',
 'info_multilinguisme' => 'Multiling&uuml;ismo',
 'info_nom_non_utilisateurs_connectes' => 'Tu nombre no aparece en la lista de personas conectadas',
 'info_nom_utilisateurs_connectes' => 'Tu nombre aparece en la lista de personas conectadas.',
@@ -484,7 +509,7 @@ se puede activar o desactivar .',
 'info_panne_site_syndique' => 'El sitio sindicado tiene problemas',
 'info_pense_bete' => 'Recordatorio para memorizar',
 'info_petit_ecran' => 'Pantalla peque&ntilde;a',
-'info_petition_close' => 'Petici&oacute;n cerrada',
+'info_petition_close' => 'Ya no se firma',
 'info_pixels' => 'p&iacute;xeles',
 'info_plusieurs_mots_trouves' => 'Hemos encontrado varias palabras clave para "@cherche_mot@":',
 'info_popularite_5' => 'Popularidad:',
@@ -509,15 +534,19 @@ se puede activar o desactivar .',
 'info_retablir_lien' => 'restablecer el enlace',
 'info_retirer_mot' => 'Retirar la palabra',
 'info_retirer_mots' => 'Retirar todas las palabras',
+'info_rubriques_nb' => '@nb@ secciones',
+'info_rubriques_un' => '1 secci&oacute;n',
 'info_sans_titre_2' => 'sin t&iacute;tulo',
 'info_selectionner_fichier' => 'Puedes seleccionar un documento del directorio @upload@',
 'info_selectionner_fichier_2' => 'Seleccionar un documento...',
 'info_signature_supprimee' => 'Firma eliminada',
-'info_signature_supprimee_erreur' => 'Error&nbsp;: este c&amp;oacute;digo de eliminaci&amp;oacute;n no se corresponde a ninguna firma',
+'info_signature_supprimee_erreur' => 'Error: este c&oacute;digo de eliminaci&oacute;n no  corresponde a ninguna firma',
 'info_site_attente' => 'Sitio Web en espera de validaci&oacute;n',
 'info_site_reference' => 'Sitio referenciado en l&iacute;nea',
 'info_site_refuse' => 'Sitio Web rechazado',
+'info_sites_nb' => '@nb@ sitios',
 'info_sites_referencer' => 'Referenciar un sitio',
+'info_sites_un' => '1 sitio',
 'info_supprimer_vignette' => 'Suprimir este icono',
 'info_symbole_bleu' => 'El s&iacute;mbolo <b>azul</b> representa un <b>recordatorio personal</b>, o sea una manera de recordar algo.',
 'info_symbole_jaune' => 'El s&iacute;mbolo <b>amarillo</b> representa un <b>anuncio para todos</b>: s&oacute;lo es modificable por las/os administradoras/es del sitio, y es visible por todos los redactores.',
@@ -529,7 +558,7 @@ se puede activar o desactivar .',
 'info_telecharger_ordinateur' => 'Subir desde tu ordenador:',
 'info_tous_resultats_enregistres' => '[todos los resultados son registrados]',
 'info_tout_afficher' => 'Mostrar todo',
-'info_travaux_texte' => 'Este sitio todav&iacute;a no est&aacute; configurado. Vuelve m&aacute;s adelante',
+'info_travaux_texte' => 'Este sitio todav&iacute;a no est&aacute; configurado. Vuelve m&aacute;s adelante...',
 'info_travaux_titre' => 'Sitio en curso de modificaci&oacute;n',
 'info_trop_resultat' => 'Demasiados resultados para la b&uacute;squeda de "@cherche_mot@" . Precise los criterios.',
 'info_utilisation_messagerie_interne' => 'Utilizas la mensajer&iacute;a interna del sitio.',
@@ -548,7 +577,6 @@ se puede activar o desactivar .',
 'lien_afficher_icones_seuls' => 'Mostrar s&oacute;lo los iconos',
 'lien_afficher_texte_icones' => 'Mostrar iconos y texto',
 'lien_afficher_texte_seul' => 'Mostrar s&oacute;lo el texto',
-'lien_icones_interface' => 'Los iconos de la interfaz fueron realizados por <a href=\'http://jimmac.musichall.cz/\'>Jakub \'Jimmac\' Steiner</a>.',
 'lien_liberer' => 'Liberar',
 'lien_liberer_tous' => 'liberar estos art&iacute;culos',
 'lien_nouvea_pense_bete' => 'Nuevo recordatorio',
@@ -567,34 +595,36 @@ se puede activar o desactivar .',
 'ligne' => 'L&iacute;nea',
 'login' => 'Conexi&oacute;n',
 'login_acces_prive' => 'acceso al espacio privado',
-'login_autre_identifiant' => 'conectarse con otro nombre de usuario',
+'login_autre_identifiant' => 'conectarse con otro nombre de usuario o usuaria',
 'login_cookie_accepte' => 'Configura tu navegador para que las acepte (al menos para este sitio).',
 'login_cookie_oblige' => 'Para identificarte de manera segura en este sitio, tienes que aceptar las "cookies".',
 'login_deconnexion_ok' => 'Desconexi&oacute;n efectuada.',
 'login_erreur_pass' => 'Error de contrase&ntilde;a.',
 'login_espace_prive' => 'espacio privado',
-'login_identifiant_inconnu' => 'El nombre de usuario &laquo;@login@&raquo; es desconocido.',
-'login_login' => 'Nombre de usuario:',
-'login_login2' => 'Login (nombre de usuario para conexi&oacute;n al sitio)&nbsp;:',
-'login_login_pass_incorrect' => '(Nombre de usuario o contrase&ntilde;a incorrecta.)',
+'login_identifiant_inconnu' => 'El nombre de usuario o usuaria &laquo;@login@&raquo; es desconocido.',
+'login_login' => 'Nombre de usuario o usuaria:',
+'login_login2' => 'Login (identificador de conexi&oacute;n al sitio):',
+'login_login_pass_incorrect' => '(Identificador o contrase&ntilde;a incorrecta.)',
 'login_motpasseoublie' => '&iquest;contrase&ntilde;a&nbsp;olvidada?',
-'login_non_securise' => 'Atenci&oacute;n, este formulario no est&aacute; asegurado. Si no deseas que tu contrase&ntilde;a pueda ser interceptada en la red, activa JavaScript en tu navegador y',
+'login_non_securise' => 'Atenci&oacute;n, este formulario no est&aacute; asegurado.
+ Si no deseas que tu contrase&ntilde;a pueda ser interceptada en la red, activa JavaScript en tu navegador y',
 'login_nouvelle_tentative' => 'Nuevo intento',
 'login_par_ici' => 'Est&aacute;s registrado o registrada... por aqu&iacute;...',
 'login_pass2' => 'Contrase&ntilde;a:',
 'login_preferez_refuser' => '<b>Si prefieres rechazar las "cookies"</b>, otro m&eacute;todo de conexi&oacute;n (menos seguro) est&aacute; a tu disposici&oacute;n:',
-'login_recharger' => 'recargar esta p&aacute;gina',
+'login_recharger' => 'actualizar esta p&aacute;gina',
 'login_rester_identifie' => 'Quedar identificado unos d&iacute;as',
 'login_retour_public' => 'Volver al sitio p&uacute;blico',
 'login_retour_site' => 'Volver al sitio p&uacute;blico',
 'login_retoursitepublic' => 'volver&nbsp;al&nbsp;sitio&nbsp;p&uacute;blico',
 'login_sans_cookiie' => 'Identificaci&oacute;n sin "cookie"',
+'login_securise' => 'Conexi&oacute;n segura',
 'login_sinscrire' => 'inscribirse',
 'login_test_navigateur' => 'prueba de navegador/reconexi&oacute;n',
 'login_verifiez_navigateur' => '(No obstante, comprueba que tu navegador no memoriz&oacute; tu contrase&ntilde;a...)',
 
 // M
-'masquer_colonne' => 'Esconder esta columna',
+'masquer_colonne' => 'Ocultar esta columna',
 'masquer_trad' => 'Ocultar las traducciones',
 'module_fichiers_langues' => 'Archivos de idioma',
 
@@ -653,7 +683,7 @@ volver a conectarte al sitio.
 'pass_ok' => 'OK',
 'pass_oubli_mot' => 'Contrase&ntilde;a olvidada',
 'pass_quitter_fenetre' => 'Abandonar esta ventana',
-'pass_rappel_login' => 'Recuerda: tu nombre de usuario (login) es &laquo;@login@&raquo;.',
+'pass_rappel_login' => 'Recuerda: tu identificador (login) es &laquo;@login@&raquo;.',
 'pass_recevoir_mail' => 'Recibir&aacute;s un mensaje de correo electr&oacute;nico indicando como recuperar tu acceso al sitio.',
 'pass_retour_public' => 'Volver al sitio p&uacute;blico',
 'pass_rien_a_faire_ici' => 'Nada que hacer aqu&iacute;.',
@@ -663,7 +693,7 @@ volver a conectarte al sitio.
 'previsualiser' => 'Previsualizar',
 
 // R
-'retour' => 'Retorno',
+'retour' => 'Volver',
 
 // S
 'spip_conforme_dtd' => 'SPIP considera este documento como conforme a su DOCTYPE:',
@@ -686,8 +716,8 @@ volver a conectarte al sitio.
 La imagen <b>@fichier@</b> no ha pasado (art&iacute;culo @id_article@).
 Tome nota de esta referencia, reintente la actualizaci&oacute;n y verifique que las im&aacute;genes aparecen en los art&iacute;culos.',
 'texte_erreur_visiteur' => 'Has intentado entrar al espacio privado con un identificador que no lo permite.',
-'texte_inc_auth_1' => 'Te identificaste con el
- login  <b>@auth_login@</b>, pero &eacute;ste no existe (ya) en la base.
+'texte_inc_auth_1' => 'Est&aacute;s identificado con el
+ login  <b>@auth_login@</b>, pero &eacute;ste (ya) no existe en la base.
 Intenta',
 'texte_inc_auth_2' => 'reconectarte',
 'texte_inc_auth_3' => ', eventualmente despu&eacute;s de cerrar y reiniciar tu navegador.',
@@ -717,7 +747,7 @@ Intenta',
 'titre_joindre_document' => 'A&ntilde;adir un documento',
 'titre_liens_entrants' => 'Los enlaces entrantes ',
 'titre_mots_cles' => 'Palabras clave',
-'titre_probleme_technique' => 'Atenci&oacute;n: una dificultad t&eacute;cnica (servidor SQL) impide el acceso a esta parte del sitio. Se agradece su comprensi&oacute;n hasta resolver el problema.',
+'titre_probleme_technique' => 'Atenci&oacute;n: una problema t&eacute;cnico (servidor SQL) impide el acceso a esta parte del sitio. Se agradece su comprensi&oacute;n.',
 'titre_publier_document' => 'PUBLICAR UN DOCUMENTO EN ESTA SECCION',
 'titre_signatures_attente' => 'Firmas esperando validaci&oacute;n',
 'titre_signatures_confirmees' => 'Firmas confirmadas',
@@ -727,36 +757,36 @@ Intenta',
 'trad_reference' => '(art&iacute;culo de referencia)',
 
 // Z
-'zbug_balise_b_aval' => ': balize de bucle B m&aacute;s adelante',
-'zbug_balise_inexistante' => 'error @from@: la baliza #@balise@ no existe',
+'zbug_balise_b_aval' => ': baliza de bucle B m&aacute;s adelante',
+'zbug_balise_inexistante' => 'Baliza @balise@  mal declarada para @from@',
 'zbug_balise_sans_argument' => 'Falta un argumento en la baliza @balise@',
 'zbug_boucle' => 'bucle',
-'zbug_boucle_recursive_undef' => 'bucle recursivo no defindo',
+'zbug_boucle_recursive_undef' => 'Bucle recursivo no defindo&nbsp;: @nom@',
 'zbug_calcul' => 'c&aacute;lculo',
 'zbug_champ_hors_boucle' => 'Campo @champ@ fuera de bucle',
-'zbug_champ_hors_motif' => 'Campo @champ@ fuera de un buclede motivo @motif@',
+'zbug_champ_hors_motif' => 'El campo @champ@ est&aacute; fuera de contexto @motif@',
 'zbug_code' => 'c&oacute;digo',
-'zbug_critere_inconnu' => 'criterio desconocido @critere@',
-'zbug_distant_interdit' => 'externo prohibido',
-'zbug_doublon_table_sans_cle_primaire' => 'repetidos en una tabla sin clave primaria simple',
-'zbug_doublon_table_sans_index' => 'duplicados en una tabla sin &iacute;ndice',
-'zbug_erreur_boucle_double' => 'BOUCLE@id@: doble definici&oacute;n',
-'zbug_erreur_boucle_fermant' => 'BOUCLE@id@: falta la baliza de cierre',
-'zbug_erreur_boucle_syntaxe' => 'Sintaxis de bucle incorrecto',
+'zbug_critere_inconnu' => 'Criterio @critere@ desconocido ',
+'zbug_distant_interdit' => 'Acceso externo prohibido',
+'zbug_doublon_table_sans_cle_primaire' => 'Doublons en una tabla sin clave primaria simple',
+'zbug_doublon_table_sans_index' => 'Doublons en una tabla sin &iacute;ndice',
+'zbug_erreur_boucle_double' => 'Doble definici&oacute;n del bucle @id@',
+'zbug_erreur_boucle_fermant' => 'Bucle @id@ sin baliza de cierre',
+'zbug_erreur_boucle_syntaxe' => 'Sintaxis del bucle @id@ incorrecta',
 'zbug_erreur_compilation' => 'Error de compilaci&oacute;n',
-'zbug_erreur_execution_page' => 'error de ejecuci&oacute;n de la p&aacute;gina',
-'zbug_erreur_filtre' => 'Error: filtro <b>&laquo; @filtre@ &raquo;</b> no definido',
-'zbug_erreur_meme_parent' => '{meme_parent} s&oacute;lo se aplica a los  bucles (FORUMS) o (RUBRIQUES)',
+'zbug_erreur_execution_page' => 'Error de ejecuci&oacute;n',
+'zbug_erreur_filtre' => 'Error: filtro @filtre@ no definido',
+'zbug_erreur_meme_parent' => 'El criterio {meme_parent} s&oacute;lo se aplica a los  bucles (FORUMS) o (RUBRIQUES)',
 'zbug_erreur_squelette' => 'Error(es) en el esqueleto',
 'zbug_hors_compilation' => 'Sin compilaci&oacute;n',
 'zbug_info_erreur_squelette' => 'Error en el sitio',
-'zbug_inversion_ordre_inexistant' => 'inversi&oacute;n de un orden inexistente',
-'zbug_pagination_sans_critere' => '#PAGINATION sin criterio {pagination} o empleado en un bucle recurssivo',
-'zbug_parametres_inclus_incorrects' => 'Par&aacute;metreos de inclusi&oacute;n incorrectos',
-'zbug_profile' => 'Duraci&oacute;n de c&aacute;lculo&nbsp;: @time@',
+'zbug_inversion_ordre_inexistant' => 'Inversi&oacute;n de un orden inexistente',
+'zbug_pagination_sans_critere' => 'Baliza #PAGINATION sin criterio {pagination} o empleado en un bucle recursivo',
+'zbug_parametres_inclus_incorrects' => 'Par&aacute;metro de inclusi&oacute;n incorrecto: @param@',
+'zbug_profile' => 'Duraci&oacute;n del c&aacute;lculo: @time@',
 'zbug_resultat' => 'resultado',
-'zbug_serveur_indefini' => 'servidor SQL indefinido',
-'zbug_statistiques' => 'Estad&iacute;stica de las peticiones SQL ordenadas por duraci&oacute;n',
+'zbug_serveur_indefini' => 'Servidor SQL indefinido',
+'zbug_statistiques' => 'Estad&iacute;stica de las consultas SQL ordenadas por duraci&oacute;n',
 'zbug_table_inconnue' => 'Tabla SQL &laquo;@table@&raquo; desconocida',
 'zxml_connus_attributs' => 'atributos conocidos',
 'zxml_de' => 'de',
