@@ -23,10 +23,12 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 'admin_modifier_mot' => 'Modificar aqueth mot clau',
 'admin_modifier_rubrique' => 'Modificar aquera rubrica',
 'admin_recalculer' => 'Tornar calcular la pagina',
-'afficher_trad' => '<NEW>afficher les traductions',
+'afficher_trad' => 'afficher les traductions', # NEW
 'alerte_maj_impossible' => '<b>Al&egrave;rta!</b> Qu\'ei impossible d\'actualizar la basa SQL de cap t&agrave; la version @version@; dilh&egrave;u que i a un probl&egrave;ma relatiu au dret de modificar la basa de dadas. Volhatz contactar lo v&ograve;ste aubergader.',
+'alerte_modif_info_concourante' => 'ATTENTION : Cette information a &eacute;t&eacute; modifi&eacute;e par ailleurs. La valeur actuelle est&nbsp;:', # NEW
 'analyse_xml' => 'Analisi XML',
-'antispam_champ_vide' => '<NEW>Veuillez laisser ce champ vide&nbsp;:',
+'annuler' => 'Annuler', # NEW
+'antispam_champ_vide' => 'Veuillez laisser ce champ vide&nbsp;:', # NEW
 'articles_recents' => 'Los articles mei recents',
 'avis_archive_incorrect' => 'lo fichi&egrave;r archiu n\'ei pas un fichi&egrave;r SPIP',
 'avis_archive_invalide' => 'lo fichi&egrave;r archiu n\'ei pas valid',
@@ -41,30 +43,32 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 'avis_erreur_fonction_contexte' => 'Error de programacion. Non cau pas aperar aquera foncion dens aqueth cont&egrave;xt.',
 'avis_erreur_mysql' => 'Error SQL ',
 'avis_erreur_sauvegarde' => 'Error dens la sauvagarda (@type@ @id_objet@)! ',
-'avis_erreur_visiteur' => '<NEW>Probl&egrave;me d\'acc&egrave;s &agrave; l\'espace priv&eacute;',
+'avis_erreur_visiteur' => 'Probl&egrave;me d\'acc&egrave;s &agrave; l\'espace priv&eacute;', # NEW
 
 // B
 'barre_a_accent_grave' => 'Inserir ua A accent gr&egrave;u majuscula',
 'barre_aide' => 'Utilizar las acorcidas tipograficas ent&agrave; enriquir la v&ograve;sta compaginacion',
 'barre_e_accent_aigu' => 'Inserir ua E accent agut majuscula',
 'barre_eo' => 'Inserir ua E dens l\'O',
-'barre_eo_maj' => '<MODIF>Inserir ua E dens l\'O majuscula',
+'barre_eo_maj' => 'Inserir ua E dens l\'O majuscula', # MODIF
 'barre_euro' => 'Inserir lo simb&egrave;u de l\'&egrave;uro: &#8364;',
 'barre_gras' => 'Hicar en {{gras}}',
 'barre_guillemets' => 'Enrodar dab &laquo; verguetas &raquo;',
-'barre_guillemets_simples' => 'Enrodar dab verguetas',
+'barre_guillemets_simples' => 'Enrodar dab „verguetas“',
 'barre_intertitre' => 'Transformar en {{{intert&iacute;tol}}}',
 'barre_italic' => 'Hicar en {italics}',
 'barre_lien' => 'Transformar en [ligam ipert&egrave;xt->http://...]',
 'barre_lien_input' => 'Volhatz indicar l\'adrei&ccedil;a deu v&ograve;ste ligam (que podetz indicar ua adrei&ccedil;a web devath la forma http://www.lomensit.com o simplament indicar lo num&egrave;ro d\'un article d\'aqueth sit).',
 'barre_note' => 'Transformar en [[N&ograve;ta de p&egrave;]]',
+'barre_paragraphe' => 'Cr&#233;er un paragraphe', # NEW
 'barre_quote' => '<quote>Citar un messatge</quote>',
-'bouton_ajouter_document' => '<MODIF>AJUSTAR UN DOCUMENT',
-'bouton_ajouter_image' => '<MODIF>AJUSTAR UN IMATGE',
+'bouton_ajouter_document' => 'AJUSTAR UN DOCUMENT', # MODIF
+'bouton_ajouter_image' => 'AJUSTAR UN IMATGE', # MODIF
+'bouton_ajouter_image_document' => 'Ajouter une image ou&nbsp;un&nbsp;document', # NEW
 'bouton_changer' => 'Cambiar',
 'bouton_chercher' => 'Cercar',
 'bouton_choisir' => 'Causir',
-'bouton_download' => '<NEW>T&eacute;l&eacute;charger',
+'bouton_download' => 'T&eacute;l&eacute;charger', # NEW
 'bouton_enregistrer' => 'Registrar',
 'bouton_radio_desactiver_messagerie_interne' => 'Desactivar la messatjaria int&egrave;rna',
 'bouton_radio_envoi_annonces' => 'Mandar los anoncis editoriaus',
@@ -81,11 +85,11 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 'cal_par_jour' => 'calend&egrave;r per dia',
 'cal_par_mois' => 'calend&egrave;r per mes',
 'cal_par_semaine' => 'calend&egrave;r per setmana',
-'choix_couleur_interface' => '<NEW>couleur ',
-'choix_interface' => '<NEW>choix  de l\'interface',
-'colonne' => '<NEW>Colonne',
+'choix_couleur_interface' => 'couleur ', # NEW
+'choix_interface' => 'choix  de l\'interface', # NEW
+'colonne' => 'Colonne', # NEW
 'confirm_changer_statut' => 'Atencion, qu\'avetz demandat de cambiar l\'estatut d\'aqueth element. E desiratz de contunhar? ',
-'correcte' => '<NEW>correcte',
+'correcte' => 'correcte', # NEW
 
 // D
 'date_aujourdhui' => 'uei',
@@ -145,26 +149,26 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 'date_jnum8' => '8',
 'date_jnum9' => '9',
 'date_jour_1' => 'dimenge',
-'date_jour_1_abbr' => '<NEW>dim.',
-'date_jour_1_initiale' => '<NEW>d.',
+'date_jour_1_abbr' => 'dim.', # NEW
+'date_jour_1_initiale' => 'd.', # NEW
 'date_jour_2' => 'diluns',
-'date_jour_2_abbr' => '<NEW>lun.',
-'date_jour_2_initiale' => '<NEW>l.',
+'date_jour_2_abbr' => 'lun.', # NEW
+'date_jour_2_initiale' => 'l.', # NEW
 'date_jour_3' => 'dimars',
-'date_jour_3_abbr' => '<NEW>mar.',
-'date_jour_3_initiale' => '<NEW>m.',
+'date_jour_3_abbr' => 'mar.', # NEW
+'date_jour_3_initiale' => 'm.', # NEW
 'date_jour_4' => 'dim&egrave;rcs',
-'date_jour_4_abbr' => '<NEW>mer.',
-'date_jour_4_initiale' => '<NEW>m.',
+'date_jour_4_abbr' => 'mer.', # NEW
+'date_jour_4_initiale' => 'm.', # NEW
 'date_jour_5' => 'dijaus',
-'date_jour_5_abbr' => '<NEW>jeu.',
-'date_jour_5_initiale' => '<NEW>j.',
+'date_jour_5_abbr' => 'jeu.', # NEW
+'date_jour_5_initiale' => 'j.', # NEW
 'date_jour_6' => 'div&eacute;s',
-'date_jour_6_abbr' => '<NEW>ven.',
-'date_jour_6_initiale' => '<NEW>v.',
+'date_jour_6_abbr' => 'ven.', # NEW
+'date_jour_6_initiale' => 'v.', # NEW
 'date_jour_7' => 'dissabte',
-'date_jour_7_abbr' => '<NEW>sam.',
-'date_jour_7_initiale' => '<NEW>s.',
+'date_jour_7_abbr' => 'sam.', # NEW
+'date_jour_7_initiale' => 's.', # NEW
 'date_jours' => 'dias',
 'date_minutes' => 'minutas',
 'date_mois' => 'mes',
@@ -184,32 +188,52 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 'date_saison_2' => 'prima',
 'date_saison_3' => 'estiu',
 'date_saison_4' => 'ag&ograve;r',
+'date_secondes' => 'secondes', # NEW
 'date_semaines' => 'setmana(s)',
+'date_un_mois' => 'mois', # NEW
+'date_une_heure' => 'heure', # NEW
+'date_une_minute' => 'minute', # NEW
+'date_une_seconde' => 'seconde', # NEW
+'date_une_semaine' => 'semaine', # NEW
 'dirs_commencer' => 'ent&agrave; comen&ccedil;ar vertad&egrave;rament l\'installacion',
 'dirs_preliminaire' => 'Preliminar: <b>Reglar los drets d\'acc&egrave;s</b>',
-'dirs_probleme_droits' => '<MODIF>Probl&egrave;ma de drets d\'acc&egrave;s',
-'dirs_repertoires_absents' => '<MODIF><b>Non s\'ei pas trobat los repert&ograve;ris seguents: <ul>@bad_dirs@.</ul> </b>
+'dirs_probleme_droits' => 'Probl&egrave;ma de drets d\'acc&egrave;s', # MODIF
+'dirs_repertoires_absents' => '<b>Non s\'ei pas trobat los repert&ograve;ris seguents: <ul>@bad_dirs@.</ul> </b>
   <p>Que\'s p&ograve;t que venga d\'un probl&egrave;ma de majusculas o minusculas mau hicadas.
   Verificatz que las minusculas e majusculas d\'aqueths repert&ograve;ris e corresp&oacute;nian plan dab &ccedil;&ograve; d\'afichat
   &ccedil;a sus; se n\'ei pas lo cas, tornatz nommar los repert&ograve;ris dab lo v&ograve;ste logiciau FTP en corregir l\'error.
-  <p>Un c&ograve;p qu\'auratz h&egrave;it aqu&ograve;, que poiratz ',
-'dirs_repertoires_suivants' => '<MODIF><b>Los repert&ograve;ris seguents non son pas accessibles en escritura: <ul>@bad_dirs@.</ul> </b>
+  <p>Un c&ograve;p qu\'auratz h&egrave;it aqu&ograve;, que poiratz ', # MODIF
+'dirs_repertoires_suivants' => '<b>Los repert&ograve;ris seguents non son pas accessibles en escritura: <ul>@bad_dirs@.</ul> </b>
   <p>Ent&agrave; adobar aqu&ograve;, utilizatz lo v&ograve;ste client FTP ent&agrave; reglar los drets d\'acc&egrave;s de cadun
   d\'aqueths repert&ograve;ris. La guida d\'installacion qu\'explica en detalh quin cau procedir.
-  <p>Tanl&egrave;u qu\'auratz h&egrave;ita aquera manipulacion, que poiratz ',
-'double_occurrence' => '<NEW>Double occurrence',
+  <p>Tanl&egrave;u qu\'auratz h&egrave;ita aquera manipulacion, que poiratz ', # MODIF
+'double_occurrence' => 'Double occurrence', # MODIF
 
 // E
+'en_cours' => 'en cours', # NEW
 'entree_dimensions' => 'Dimensions:',
 'entree_titre_document' => 'T&iacute;tol deu document:',
 'entree_titre_image' => 'T&iacute;tol de l\'imatge:',
 'envoi_via_le_site' => 'Mandad&iacute;s dab lo biaish deu sit web',
-'erreur' => '<NEW>Erreur',
-'erreur_balise_non_fermee' => '<NEW>derni&egrave;re balise non referm&eacute;e :',
-'erreur_texte' => '<NEW>erreur(s)',
+'erreur' => 'Erreur', # NEW
+'erreur_balise_non_fermee' => 'derni&egrave;re balise non referm&eacute;e :', # NEW
+'erreur_texte' => 'erreur(s)', # NEW
+'etape' => '&Eacute;tape', # NEW
 
 // F
 'fichier_introuvable' => 'Non s\'ei pas pogut trobar lo fichi&egrave;r @fichier@.',
+'form_auteur_confirmation' => 'Confirmez votre adresse email', # NEW
+'form_auteur_email_modifie' => 'Votre adresse email a &eacute;t&eacute; modifi&eacute;e.', # NEW
+'form_auteur_envoi_mail_confirmation' => 'Un courrier &eacute;lectronique de confirmation vient d\'&ecirc;tre envoy&eacute; &agrave; @email@. Vous devrez visiter l\'adresse Web mentionn&eacute;e dans ce courrier pour valider votre adresse mail.', # NEW
+'form_auteur_mail_confirmation' => 'Bonjour,
+
+Vous avez demand&eacute; &agrave; changer votre adresse email.
+Pour confirmer votre nouvelle adresse, il suffit de vous connecter &agrave;
+l\'adresse ci-dessous (dans le cas contraire, votre demande
+sera ignor&eacute;e) :
+
+    @url@
+', # NEW
 'form_deja_inscrit' => 'Qu\'&egrave;tz ja inscriut(a).',
 'form_email_non_valide' => 'La v&ograve;sta adrei&ccedil;a e-mail n\'ei pas valida.',
 'form_forum_access_refuse' => 'Non podetz plus accedir a aqueth sit.',
@@ -222,10 +246,10 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 'form_forum_message_auto' => '(aqu&ograve; qu\'ei un messatge automatic)',
 'form_forum_pass' => 'mot de santa Clara:',
 'form_forum_probleme_mail' => 'Probl&egrave;ma d\'e-mail: ne\'s p&ograve;t pas mandar l\'identificant.',
-'form_forum_voici1' => '<MODIF>Ti&egrave;tz los v&ograve;stes identificants ent&agrave; poder participar aus forums
-deu sit "@nom_site_spip@" (@adresse_site@):',
-'form_forum_voici2' => '<MODIF>Ti&egrave;tz los v&ograve;stes identificants ent&agrave; perpausar articles 
- suu sit "@nom_site_spip@" (@adresse_login@):',
+'form_forum_voici1' => 'Ti&egrave;tz los v&ograve;stes identificants ent&agrave; poder participar aus forums
+deu sit "@nom_site_spip@" (@adresse_site@):', # MODIF
+'form_forum_voici2' => 'Ti&egrave;tz los v&ograve;stes identificants ent&agrave; perpausar articles 
+ suu sit "@nom_site_spip@" (@adresse_login@):', # MODIF
 'form_indiquer_email' => 'Volhatz indicar la v&ograve;sta adrei&ccedil;a e-mail.',
 'form_indiquer_nom' => 'Volhatz indicar lo v&ograve;ste nom.',
 'form_indiquer_nom_site' => 'Volhatz indicar lo nom deu v&ograve;ste sit.',
@@ -234,8 +258,8 @@ deu sit "@nom_site_spip@" (@adresse_site@):',
 'form_pet_confirmation' => 'Volhatz confirmar la v&ograve;sta signatura:',
 'form_pet_deja_enregistre' => 'Ja aqueth sit qu\'ei registrat',
 'form_pet_deja_signe' => 'Qu\'avetz ja signat aqueth t&egrave;xt.',
-'form_pet_envoi_mail_confirmation' => '<MODIF>Ara que receberatz un e-mail de confirmacion. T&agrave; validar la v&ograve;sta signatura, que cau vesitar l\'adrei&ccedil;a web men&ccedil;onada per aqueste corri&egrave;r.',
-'form_pet_mail_confirmation' => '<MODIF>Adishatz,
+'form_pet_envoi_mail_confirmation' => 'Ara que receberatz un e-mail de confirmacion. T&agrave; validar la v&ograve;sta signatura, que cau vesitar l\'adrei&ccedil;a web men&ccedil;onada per aqueste corri&egrave;r.', # MODIF
+'form_pet_mail_confirmation' => 'Adishatz,
 
 qu\'avetz demandat de signar la peticion:
 @titre@.
@@ -253,9 +277,10 @@ la v&ograve;sta demanda):
 
 
 Merc&eacute;s ent&agrave; la v&ograve;sta participacion
-',
+', # MODIF
 'form_pet_message_commentaire' => 'Un messatge, ua remarca?',
 'form_pet_nom_site2' => 'Nom deu v&ograve;ste sit web',
+'form_pet_probleme_liens' => 'Veuillez reprendre votre message en supprimant les liens hypertexte.', # NEW
 'form_pet_probleme_technique' => 'Probl&egrave;ma tecnic, las signaturas que son tempor&agrave;riament arrestadas.',
 'form_pet_signature_pasprise' => 'La v&ograve;sta signatura n\'ei pas presa en compte.',
 'form_pet_signature_validee' => 'La v&ograve;sta signatura qu\'ei validada. Merc&eacute;s!',
@@ -279,7 +304,7 @@ Merc&eacute;s ent&agrave; la v&ograve;sta participacion
 'forum_acces_refuse' => 'Non podetz plus accedir a aqueths forums.',
 'forum_attention_dix_caracteres' => '<b>Atencion!</b> lo v&ograve;ste messatge que deu ti&eacute;ner aumensh d&egrave;tz caract&egrave;rs.',
 'forum_attention_trois_caracteres' => '<b>Atencion!</b> lo v&ograve;ste t&iacute;tol que deu ti&eacute;ner aumensh de tres caract&egrave;rs.',
-'forum_attention_trop_caracteres' => '<NEW><b>Attention&nbsp;!</b> votre message est trop long (@compte@ caract&egrave;res)&nbsp;: pour pouvoir &ecirc;tre enregistr&eacute;, il ne doit pas d&eacute;passer @max@ caract&egrave;res.',
+'forum_attention_trop_caracteres' => '<b>Attention&nbsp;!</b> votre message est trop long (@compte@ caract&egrave;res)&nbsp;: pour pouvoir &ecirc;tre enregistr&eacute;, il ne doit pas d&eacute;passer @max@ caract&egrave;res.', # NEW
 'forum_avez_selectionne' => 'Qu\'avetz seleccionat:',
 'forum_cliquer_retour' => 'Clicatz <a href=\'@retour_forum@\'>ac&iacute;</a> t&agrave; contunhar.',
 'forum_forum' => 'forum',
@@ -291,7 +316,7 @@ Merc&eacute;s ent&agrave; la v&ograve;sta participacion
 'forum_non_inscrit' => 'Sia n\'&egrave;tz pas inscriut(a), sia avetz h&egrave;it ua error d\'adrei&ccedil;a o de mot de santa Clara. ',
 'forum_page_url' => '(se lo v&ograve;ste messatge e\'s refereish a un article publicat peu web, o a ua pagina qui baile mei informacions, que podetz marcar &ccedil;a devath lo t&iacute;tol de la pagina e la soa adrei&ccedil;a URL.)',
 'forum_par_auteur' => 'per @auteur@',
-'forum_poste_par' => '<MODIF>Messatge poste@parauteur@ qui h&egrave; seguida au v&ograve;ste article.',
+'forum_poste_par' => 'Messatge poste@parauteur@ qui h&egrave; seguida au v&ograve;ste article.', # MODIF
 'forum_probleme_database' => 'Probl&egrave;ma de basa de dadas, lo v&ograve;ste messatge non s\'ei pas registrat.',
 'forum_qui_etes_vous' => '<b>Qui &egrave;tz?</b> (opcionau)',
 'forum_texte' => 'T&egrave;xt deu v&ograve;ste messatge:',
@@ -366,7 +391,7 @@ Merc&eacute;s ent&agrave; la v&ograve;sta participacion
 'image_tourner_droite' => 'Rotacion 90&deg; cap a dreta',
 'image_tourner_gauche' => 'Rotacion 90&deg; cap a esqu&egrave;rra',
 'img_indisponible' => 'imatge indisponible',
-'impossible' => '<NEW>impossible',
+'impossible' => 'impossible', # NEW
 'info_a_suivre' => 'DE SEGUIR&gt;&gt;',
 'info_a_valider' => '[de validar]',
 'info_acces_interdit' => 'Acc&egrave;s pro&iuml;bit',
@@ -385,23 +410,27 @@ Merc&eacute;s ent&agrave; la v&ograve;sta participacion
 'info_article_supprime' => 'Article suprimit',
 'info_articles' => 'Articles',
 'info_articles_a_valider' => 'Los articles de validar',
+'info_articles_nb' => '@nb@ articles', # NEW
 'info_articles_proposes' => 'Articles perpausats',
+'info_articles_un' => '1 article', # NEW
 'info_auteurs_nombre' => 'autor(s)',
 'info_authentification_ftp' => 'autentificacion (per FTP).',
 'info_bloquer_lien' => 'Blocar aqueth ligam',
 'info_breves_02' => 'Br&egrave;vas',
 'info_breves_2' => 'br&egrave;vas',
+'info_breves_nb' => '@nb@ br&egrave;ves', # NEW
+'info_breves_un' => '1 br&egrave;ve', # NEW
 'info_breves_valider' => 'Br&egrave;vas de validar',
 'info_connexion_refusee' => 'Connexion arrefusada',
 'info_contact_developpeur' => 'Volhatz contactar un desvolopaire.',
 'info_contenance' => 'Aqueth sit que contien:',
 'info_contribution' => 'Contribucions de forum',
 'info_copyright' => '@spip@ qu\'ei un logiciau liure distribuit @lien_gpl@.',
-'info_copyright_doc' => 'Per mei informacions, v&eacute;der lo sit <a href=\'http://www.spip.net/oc\'>http://www.spip.net/oc</a>.',
+'info_copyright_doc' => 'Per mei informacions, v&eacute;der lo sit <a href="@spipnet@">http://www.spip.net/oc</a>.', # MODIF
 'info_copyright_gpl' => 'devath lic&eacute;ncia GPL',
 'info_cours_edition' => 'Los v&ograve;stes articles en cors de redaccion',
 'info_creer_repertoire' => 'Volhatz crear un fichi&egrave;r o un repert&ograve;ri nomentat',
-'info_creer_repertoire_2' => '<MODIF>laguens lo sosrepert&ograve;ri   <b>@repertoire@</b>, puish:',
+'info_creer_repertoire_2' => 'laguens lo sosrepert&ograve;ri   <b>@repertoire@</b>, puish:', # MODIF
 'info_creer_vignette' => 'creacion automatica de la vinheta',
 'info_deplier' => 'Desplegar',
 'info_descriptif_nombre' => 'descriptiu(s):',
@@ -409,7 +438,10 @@ Merc&eacute;s ent&agrave; la v&ograve;sta participacion
 'info_description_2' => 'Descripcion:',
 'info_dimension' => 'Dimensions:',
 'info_document' => 'Document ',
+'info_document_indisponible' => 'Ce document n\'est pas disponible', # NEW
 'info_documents' => 'Documents',
+'info_documents_nb' => '@nb@ documents', # NEW
+'info_documents_un' => '1 document', # NEW
 'info_echange_message' => 'SPIP que permet d\'escambiar messatges e de constituir forums privats de discussion entre los participants deu sit. Que podetz activar o desactivar aquera foncionalitat.',
 'info_ecire_message_prive' => 'Escr&iacute;ver un messatge privat',
 'info_email_invalide' => 'Adrei&ccedil;a e-mail invalida',
@@ -419,23 +451,23 @@ Merc&eacute;s ent&agrave; la v&ograve;sta participacion
 'info_erreur_requete' => 'Error dens la requ&egrave;sta',
 'info_erreur_squelette2' => 'Nada esqueleta <b>@fichier@</b> n\'ei pas disponibla...',
 'info_erreur_systeme' => 'Error sist&egrave;ma (errno @errsys@)',
-'info_erreur_systeme2' => '<MODIF>Lo disc dur qu\'ei dilh&egrave;u plen, o la basa de dadas gastada. <br />
+'info_erreur_systeme2' => 'Lo disc dur qu\'ei dilh&egrave;u plen, o la basa de dadas gastada. <br />
  <font color=\'red\'>Ensajatz de <a href=\'@script@\'>reparar la basa</a>,
- o contactatz lo v&ograve;ste aubergader.</font>',
+ o contactatz lo v&ograve;ste aubergader.</font>', # MODIF
 'info_fini' => 'Qu\'ei acabat!',
 'info_format_image' => 'Formats d\'imatges qui\'s p&ograve;den utilizar t&agrave; crear vinhetas: @gd_formats@.',
 'info_format_non_defini' => 'format non definit',
 'info_grand_ecran' => 'Ecran gran ',
 'info_image_aide' => 'AJUDA',
 'info_image_process_titre' => 'Met&ograve;de de fabricacion de las vinhetas',
-'info_impossible_lire_page' => '<MODIF><b>Error!</b> Impossible de legir la pagina <tt><html>@test_proxy@</html></tt> a trav&egrave;rs deu proxy <tt>',
+'info_impossible_lire_page' => '<b>Error!</b> Impossible de legir la pagina <tt><html>@test_proxy@</html></tt> a trav&egrave;rs deu proxy <tt>', # MODIF
 'info_inclusion_directe' => 'Inclusion dir&egrave;cta:',
 'info_inclusion_vignette' => 'Inclusion de la vinheta:',
 'info_installation_systeme_publication' => 'Installacion deu sist&egrave;ma de publicacion...',
-'info_installer_documents' => '<MODIF>Que podetz installar automaticament tots los documents contenguts dens lo repert&ograve;ri @upload@.',
-'info_installer_ftp' => '<MODIF>Com administrator, que podetz installar (per FTP) fichi&egrave;rs dens lo dorsi&egrave;r @upload@, puish seleccion&agrave;\'us dir&egrave;ctament ac&iacute;.',
+'info_installer_documents' => 'Que podetz installar automaticament tots los documents contenguts dens lo repert&ograve;ri @upload@.', # MODIF
+'info_installer_ftp' => 'Com administrator, que podetz installar (per FTP) fichi&egrave;rs dens lo dorsi&egrave;r @upload@, puish seleccion&agrave;\'us dir&egrave;ctament ac&iacute;.', # MODIF
 'info_installer_images' => 'Que podetz installar imatges aus formats JPEG, GIF e PNG.',
-'info_installer_images_dossier' => '<MODIF>Installar imatges dens lo dorsi&egrave;r @upload@ ent&agrave;\'us poder seleccionar ac&iacute;.',
+'info_installer_images_dossier' => 'Installar imatges dens lo dorsi&egrave;r @upload@ ent&agrave;\'us poder seleccionar ac&iacute;.', # MODIF
 'info_installer_tous_documents' => 'Installar tots los documents ',
 'info_interface_complete' => 'Interf&agrave;cia completa',
 'info_interface_simple' => 'Interf&agrave;cia simplificada',
@@ -454,6 +486,8 @@ Merc&eacute;s ent&agrave; la v&ograve;sta participacion
 'info_mail_fournisseur' => 'vos@hornider.com',
 'info_message_2' => 'MESSATGE',
 'info_message_supprime' => 'MESSATGE SUPRIMIT',
+'info_messages_nb' => '@nb@ messages', # NEW
+'info_messages_un' => '1 message', # NEW
 'info_mise_en_ligne' => 'Data de hicada en linha:',
 'info_modification_parametres_securite' => 'modificacions deus param&egrave;tres de seguretat',
 'info_mois_courant' => 'Dens lo corrent deu mes:',
@@ -469,9 +503,11 @@ Merc&eacute;s ent&agrave; la v&ograve;sta participacion
 'info_nouveau_message' => 'QU\'AVETZ UN MESSATGE NAU',
 'info_nouveaux_messages' => 'QU\'AVETZ @total_messages@ MESSATGES NAUS',
 'info_numero_abbreviation' => 'N&deg;&nbsp;',
+'info_obligatoire' => 'Cette information est obligatoire', # NEW
 'info_panne_site_syndique' => 'Sit sindicat en pana',
 'info_pense_bete' => 'MEMENTO',
 'info_petit_ecran' => 'Ecran petit ',
+'info_petition_close' => 'P&eacute;tition close', # NEW
 'info_pixels' => 'pix&egrave;ls',
 'info_plusieurs_mots_trouves' => 'Mei d\'un mot clau trobat per "@cherche_mot@":',
 'info_popularite_5' => 'popularitat:',
@@ -495,17 +531,23 @@ Merc&eacute;s ent&agrave; la v&ograve;sta participacion
 'info_retablir_lien' => 'Restablir aqueth ligam',
 'info_retirer_mot' => 'Quitar aqueth mot',
 'info_retirer_mots' => 'Quitar tots los mots ',
+'info_rubriques_nb' => '@nb@ rubriques', # NEW
+'info_rubriques_un' => '1 rubrique', # NEW
 'info_sans_titre_2' => 'shens t&iacute;tol',
-'info_selectionner_fichier' => '<MODIF>Que podetz seleccionar un fichi&egrave;r deu dorsi&egrave;r @upload@',
+'info_selectionner_fichier' => 'Que podetz seleccionar un fichi&egrave;r deu dorsi&egrave;r @upload@', # MODIF
 'info_selectionner_fichier_2' => 'Seleccionar un fichi&egrave;r:',
+'info_signature_supprimee' => 'Signature supprim&eacute;e', # NEW
+'info_signature_supprimee_erreur' => 'Erreur&nbsp;: ce code de suppression ne correspond a aucune signature', # NEW
 'info_site_attente' => 'Sit web en esp&egrave;ra de validacion',
 'info_site_reference' => 'Sit referenciat en linha',
 'info_site_refuse' => 'Sit web arrefusat',
+'info_sites_nb' => '@nb@ sites', # NEW
 'info_sites_referencer' => 'Referenciar un sit',
+'info_sites_un' => '1 site', # NEW
 'info_supprimer_vignette' => 'suprimir la vinheta',
-'info_symbole_bleu' => '<MODIF>Lo simb&egrave;u <b>blau</b> que marca un <b>memento</b>: qu\'ei a d&iacute;ser un messatge tau v&ograve;ste usatge personau.',
-'info_symbole_jaune' => '<MODIF>Lo simb&egrave;u <b>jaune</b> que marca un <b>anonci t&agrave; tots los redactors </b>: los administrators que\'u p&ograve;den modificar, cada redactor que\'u p&ograve;t v&eacute;der.',
-'info_symbole_vert' => '<MODIF>Lo simb&egrave;u <b>verd</b> que marca los <b>messatges escambiats dab autes utilizaires</b> deu sit.',
+'info_symbole_bleu' => 'Lo simb&egrave;u <b>blau</b> que marca un <b>memento</b>: qu\'ei a d&iacute;ser un messatge tau v&ograve;ste usatge personau.', # MODIF
+'info_symbole_jaune' => 'Lo simb&egrave;u <b>jaune</b> que marca un <b>anonci t&agrave; tots los redactors </b>: los administrators que\'u p&ograve;den modificar, cada redactor que\'u p&ograve;t v&eacute;der.', # MODIF
+'info_symbole_vert' => 'Lo simb&egrave;u <b>verd</b> que marca los <b>messatges escambiats dab autes utilizaires</b> deu sit.', # MODIF
 'info_syndication' => 'sindicacion:',
 'info_syndication_articles' => 'article(s)',
 'info_telecharger' => 'Telecargar a partir deu v&ograve;ste ordenader:',
@@ -532,7 +574,6 @@ Merc&eacute;s ent&agrave; la v&ograve;sta participacion
 'lien_afficher_icones_seuls' => 'Afichar sonque las ic&ograve;nas',
 'lien_afficher_texte_icones' => 'Afichar las ic&ograve;nas e lo t&egrave;xt',
 'lien_afficher_texte_seul' => 'Afichar sonque lo t&egrave;xt',
-'lien_icones_interface' => 'Las ic&ograve;nas de l\'interf&agrave;cia que son de <a href=\'http://jimmac.musichall.cz/\'>Jakub \'Jimmac\' Steiner</a>.',
 'lien_liberer' => 'liberar',
 'lien_liberer_tous' => 'liberar aqueths articles',
 'lien_nouvea_pense_bete' => 'MEMENTO NAU ',
@@ -548,7 +589,8 @@ Merc&eacute;s ent&agrave; la v&ograve;sta participacion
 'lien_visite_site' => 'vesitar aqueth sit',
 'lien_visites' => '@visites@&nbsp;vesitas',
 'lien_voir_auteur' => 'V&eacute;der aqueth autor',
-'ligne' => '<NEW>Ligne',
+'ligne' => 'Ligne', # NEW
+'login' => 'Connexion', # NEW
 'login_acces_prive' => 'acc&egrave;s a l\'espaci privat',
 'login_autre_identifiant' => 'connect&agrave;\'s dab un aute identificant',
 'login_cookie_accepte' => 'Volhatz configurar lo v&ograve;ste navigader t&agrave; que\'us acc&egrave;pte (aumensh t&agrave; aqueth sit).',
@@ -575,20 +617,22 @@ Merc&eacute;s ent&agrave; la v&ograve;sta participacion
 'login_retour_site' => 'Tornar au sit public',
 'login_retoursitepublic' => 'tornar&nbsp;au&nbsp;sit&nbsp;public',
 'login_sans_cookiie' => 'Identificacion shens cookie',
+'login_securise' => 'Login s&eacute;curis&eacute;', # NEW
 'login_sinscrire' => 'inscrive\'s',
 'login_test_navigateur' => 'Ensai navigader/tornar&nbsp;connectar',
 'login_verifiez_navigateur' => '(totun verificatz que lo v&ograve;ste navigader n\'aja pas servat lo v&ograve;ste mot de santa Clara en mem&ograve;ria...)',
 
 // M
-'masquer_trad' => '<NEW>masquer les traductions',
+'masquer_colonne' => 'Masquer cette colonne', # NEW
+'masquer_trad' => 'masquer les traductions', # NEW
 'module_fichiers_langues' => 'Fichi&egrave;rs de lenga',
 
 // N
 'navigateur_pas_redirige' => 'Se lo v&ograve;ste navigader n\'ei pas redirigit, clicatz ac&iacute; t&agrave; contunhar.',
-'numero' => '<NEW>Num&eacute;ro',
+'numero' => 'Num&eacute;ro', # NEW
 
 // O
-'occurence' => '<NEW>Occurrence',
+'occurence' => 'Occurrence', # NEW
 'onglet_affacer_base' => 'Esfa&ccedil;ar la basa',
 'onglet_auteur' => 'L\'autor',
 'onglet_contenu_site' => 'Contengut deu sit',
@@ -626,7 +670,7 @@ Merc&eacute;s ent&agrave; la v&ograve;sta participacion
  vos registr&egrave;tz lo c&ograve;p passat. 
    Que receberatz un e-mail qui\'vs bailar&agrave; la man&egrave;ra de 
     tornar trobar lo v&ograve;ste acc&egrave;s.',
-'pass_mail_passcookie' => '<MODIF>(aqu&ograve; qu\'ei un messatge automatic)
+'pass_mail_passcookie' => '(aqu&ograve; qu\'ei un messatge automatic)
 T&agrave; tornar trobar lo v&ograve;ste acc&egrave;s au sit
 @nom_site_spip@ (@adresse_site@)
 
@@ -637,7 +681,7 @@ Volhatz anar a l\'adrei&ccedil;a seguenta:
 Alavetz que poiratz entrar un mot de santa Clara nav&egrave;th
 e tornar connect&agrave;\'vs au sit.
 
-',
+', # MODIF
 'pass_mot_oublie' => 'Mot de santa Clara desmembrat',
 'pass_nouveau_enregistre' => 'Lo v&ograve;ste mot de santa Clara nav&egrave;th qu\'ei estat registrat.',
 'pass_nouveau_pass' => 'Mot de santa Clara nav&egrave;th',
@@ -653,11 +697,14 @@ e tornar connect&agrave;\'vs au sit.
 'previsualisation' => 'Previsualizacion',
 'previsualiser' => 'Previsualizar',
 
+// R
+'retour' => 'Retour', # NEW
+
 // S
-'spip_conforme_dtd' => '<NEW>SPIP consid&egrave;re ce document comme conforme &agrave; son DOCTYPE :',
-'squelette' => '<NEW>squelette',
-'squelette_inclus_ligne' => '<NEW>squelette inclus, ligne',
-'squelette_ligne' => '<NEW>squelette, ligne',
+'spip_conforme_dtd' => 'SPIP consid&egrave;re ce document comme conforme &agrave; son DOCTYPE :', # NEW
+'squelette' => 'squelette', # NEW
+'squelette_inclus_ligne' => 'squelette inclus, ligne', # NEW
+'squelette_ligne' => 'squelette, ligne', # NEW
 'stats_visites_et_popularite' => '@visites@ vesitas; popularitat: @popularite@',
 'suivant' => 'seguent',
 
@@ -673,25 +720,25 @@ e tornar connect&agrave;\'vs au sit.
  mes non s\'insereishen pas
  dir&egrave;ctament. Segon la compaginacion deu sit public,
  que poir&agrave;n apar&eacute;isher devath forma de documents junts.',
-'texte_erreur_mise_niveau_base' => '<MODIF>Error de basa de dadas pendent la hicada a niv&egrave;u. L\'imatge <b>@fichier@</b> n\'ei pas passat (article @id_article@).
+'texte_erreur_mise_niveau_base' => 'Error de basa de dadas pendent la hicada a niv&egrave;u. L\'imatge <b>@fichier@</b> n\'ei pas passat (article @id_article@).
   Notatz plan aquera refer&eacute;ncia, tornatz ensajar la hicada a
  niv&egrave;u, e verificatz puish que los imatges aparegan
- enq&uuml;&egrave;ra dens los articles.',
-'texte_erreur_visiteur' => '<NEW>Vous avez tent&eacute; de d\'acc&eacute;der &agrave; l\'espace priv&eacute; avec un login qui ne le permet pas.',
-'texte_inc_auth_1' => '<MODIF>Qu\'&egrave;tz identificat/ada com
+ enq&uuml;&egrave;ra dens los articles.', # MODIF
+'texte_erreur_visiteur' => 'Vous avez tent&eacute; de d\'acc&eacute;der &agrave; l\'espace priv&eacute; avec un login qui ne le permet pas.', # NEW
+'texte_inc_auth_1' => 'Qu\'&egrave;tz identificat/ada com
    <b>@auth_login@</b>, mes aqueth login n\'existeish pas o plus dens la basa.
-  Ensajatz de\'vs',
+  Ensajatz de\'vs', # MODIF
 'texte_inc_auth_2' => 'tornar connectar',
 'texte_inc_auth_3' => ', apr&egrave;s qu\'auratz quitat eventuaument, puish
   tornat lan&ccedil;ar lo v&ograve;ste navigader.',
-'texte_inc_config' => '<MODIF>Las modificacions h&egrave;itas dens aquestas paginas qu\'influ&eacute;ncian de b&egrave;th pro lo
+'texte_inc_config' => 'Las modificacions h&egrave;itas dens aquestas paginas qu\'influ&eacute;ncian de b&egrave;th pro lo
  foncionament deu v&ograve;ste sit. Que vs\'aconselham de n\'interviene\'i pas tant que non siatz pas
  acostumat/ada au foncionament deu sist&egrave;ma SPIP. <br /><br /><b>
  En generau, que\'s conselha h&ograve;rt
- de deishar la carga d\'aquestas paginas au webm&egrave;stre principau deu v&ograve;ste sit.</b>',
-'texte_inc_meta_1' => '<MODIF>Lo sist&egrave;ma qu\'a rescontrat ua error dens l\'escritura deu fichi&egrave;r <code>@fichier@</code>.Volhatz, com administrator/tritz deu sit,',
+ de deishar la carga d\'aquestas paginas au webm&egrave;stre principau deu v&ograve;ste sit.</b>', # MODIF
+'texte_inc_meta_1' => 'Lo sist&egrave;ma qu\'a rescontrat ua error dens l\'escritura deu fichi&egrave;r <code>@fichier@</code>.Volhatz, com administrator/tritz deu sit,', # MODIF
 'texte_inc_meta_2' => 'verificar los drets d\'escritura',
-'texte_inc_meta_3' => '<MODIF>dens lo repert&ograve;ri <code>@repertoire@</code>.',
+'texte_inc_meta_3' => 'dens lo repert&ograve;ri <code>@repertoire@</code>.', # MODIF
 'texte_statut_en_cours_redaction' => 'en cors de redaccion',
 'texte_statut_poubelle' => 'a la caisha de las d&egrave;ishas',
 'texte_statut_propose_evaluation' => 'perpausat per avaloracion',
@@ -716,51 +763,61 @@ e tornar connect&agrave;\'vs au sit.
 'titre_mots_cles' => 'MOTS CLAU',
 'titre_probleme_technique' => 'Atencion: un probl&egrave;ma tecnic (servider SQL) qu\'empacha d\'accedir a aquera part deu sit. Merc&eacute;s de la v&ograve;sta indulg&eacute;ncia.',
 'titre_publier_document' => 'PUBLICAR UN DOCUMENT DENS AQUERA RUBRICA',
+'titre_signatures_attente' => 'Signatures en attente de validation', # NEW
+'titre_signatures_confirmees' => 'Signatures confirm&eacute;es', # NEW
 'titre_statistiques' => 'Estadisticas deu sit',
 'titre_titre_document' => 'T&iacute;tol deu document:',
+'todo' => '&agrave; venir', # NEW
 'trad_reference' => '(article de refer&eacute;ncia)',
 
 // Z
 'zbug_balise_b_aval' => '&nbsp;: balisa B cap envath',
+'zbug_balise_inexistante' => 'Balise @balise@ mal d&eacute;clar&eacute;e pour @from@', # NEW
+'zbug_balise_sans_argument' => 'Argument manquant dans la balise @balise@', # NEW
 'zbug_boucle' => 'bloca',
-'zbug_boucle_recursive_undef' => 'bloca recursiva non definida',
+'zbug_boucle_recursive_undef' => 'bloca recursiva non definida', # MODIF
+'zbug_calcul' => 'calcul', # NEW
 'zbug_champ_hors_boucle' => 'Camp @champ@ h&ograve;ra bloca',
-'zbug_champ_hors_motif' => 'Camp @champ@ en deh&ograve;ra d\'ua bloca de motiu @motif@',
+'zbug_champ_hors_motif' => 'Camp @champ@ en deh&ograve;ra d\'ua bloca de motiu @motif@', # MODIF
 'zbug_code' => 'c&ograve;de',
-'zbug_critere_inconnu' => 'crit&egrave;ri inconegut @critere@',
-'zbug_distant_interdit' => 'ext&egrave;rne enebit',
-'zbug_doublon_table_sans_index' => '<NEW>doublons sur une table sans index',
-'zbug_erreur_boucle_double' => 'BLOCA@id@: definicion dobla',
-'zbug_erreur_boucle_fermant' => 'BLOCA@id@: lo tag barrader que manca',
-'zbug_erreur_boucle_syntaxe' => 'Sintaxi bloca incorr&egrave;cta',
-'zbug_erreur_compilation' => '<NEW>Erreur de compilation',
-'zbug_erreur_execution_page' => 'error d\'execucion de la pagina',
-'zbug_erreur_filtre' => 'Error: filtre <b>&laquo; @filtre@ &raquo;</b> non definit',
-'zbug_erreur_meme_parent' => '{meme_parent} que s\'aplica sonque a las blocas (FORUMS) o (RUBRIQUES)',
+'zbug_critere_inconnu' => 'crit&egrave;ri inconegut @critere@', # MODIF
+'zbug_distant_interdit' => 'ext&egrave;rne enebit', # MODIF
+'zbug_doublon_table_sans_cle_primaire' => 'Doublons sur une table sans clef primaire atomique', # NEW
+'zbug_doublon_table_sans_index' => 'doublons sur une table sans index', # MODIF
+'zbug_erreur_boucle_double' => 'BLOCA@id@: definicion dobla', # MODIF
+'zbug_erreur_boucle_fermant' => 'BLOCA@id@: lo tag barrader que manca', # MODIF
+'zbug_erreur_boucle_syntaxe' => 'Sintaxi bloca incorr&egrave;cta', # MODIF
+'zbug_erreur_compilation' => 'Erreur de compilation', # NEW
+'zbug_erreur_execution_page' => 'error d\'execucion de la pagina', # MODIF
+'zbug_erreur_filtre' => 'Error: filtre <b>&laquo; @filtre@ &raquo;</b> non definit', # MODIF
+'zbug_erreur_meme_parent' => '{meme_parent} que s\'aplica sonque a las blocas (FORUMS) o (RUBRIQUES)', # MODIF
 'zbug_erreur_squelette' => 'Error(s) dens l\'esqueleta',
+'zbug_hors_compilation' => 'Hors Compilation', # NEW
 'zbug_info_erreur_squelette' => 'Error suber lo sit',
-'zbug_inversion_ordre_inexistant' => 'inversion d\'un &ograve;rdre inexistent',
-'zbug_pagination_sans_critere' => '<NEW>#PAGINATION sans crit&egrave;re {pagination} ou employ&eacute; dans une boucle recursive',
-'zbug_parametres_inclus_incorrects' => 'Param&egrave;tres d\'inclusion incorr&egrave;ctes',
+'zbug_inversion_ordre_inexistant' => 'inversion d\'un &ograve;rdre inexistent', # MODIF
+'zbug_pagination_sans_critere' => '#PAGINATION sans crit&egrave;re {pagination} ou employ&eacute; dans une boucle recursive', # MODIF
+'zbug_parametres_inclus_incorrects' => 'Param&egrave;tres d\'inclusion incorr&egrave;ctes', # MODIF
+'zbug_profile' => 'Temps de calcul&nbsp;: @time@', # NEW
 'zbug_resultat' => 'resultat',
-'zbug_serveur_indefini' => 'servidor SQL indefinit',
+'zbug_serveur_indefini' => 'servidor SQL indefinit', # MODIF
+'zbug_statistiques' => 'Statistiques des requ&ecirc;tes SQL class&eacute;es par dur&eacute;e', # NEW
 'zbug_table_inconnue' => 'Taula SQL &laquo;@table@&raquo; inconeguda',
-'zxml_connus_attributs' => '<NEW>attributs connus',
-'zxml_de' => '<NEW>de',
-'zxml_inconnu_attribut' => '<NEW>attribut inconnu',
-'zxml_inconnu_balise' => '<NEW>balise inconnue',
-'zxml_inconnu_entite' => '<NEW>entit&eacute; inconnue',
-'zxml_inconnu_id' => '<NEW>ID inconnu',
-'zxml_mais_de' => '<NEW>mais de',
-'zxml_non_conforme' => '<NEW>n\'est pas conforme au motif',
-'zxml_non_fils' => '<NEW>n\'est pas un fils de',
-'zxml_nonvide_balise' => '<NEW>balise non vide',
-'zxml_obligatoire_attribut' => '<NEW>attribut obligatoire mais absent dans',
-'zxml_succession_fils_incorrecte' => '<NEW>succession des fils incorrecte',
-'zxml_survoler' => '<NEW>survoler pour voir les corrects',
-'zxml_valeur_attribut' => '<NEW>valeur de l\'attribut',
-'zxml_vide_balise' => '<NEW>balise vide',
-'zxml_vu' => '<NEW>vu auparavant'
+'zxml_connus_attributs' => 'attributs connus', # NEW
+'zxml_de' => 'de', # NEW
+'zxml_inconnu_attribut' => 'attribut inconnu', # NEW
+'zxml_inconnu_balise' => 'balise inconnue', # NEW
+'zxml_inconnu_entite' => 'entit&eacute; inconnue', # NEW
+'zxml_inconnu_id' => 'ID inconnu', # NEW
+'zxml_mais_de' => 'mais de', # NEW
+'zxml_non_conforme' => 'n\'est pas conforme au motif', # NEW
+'zxml_non_fils' => 'n\'est pas un fils de', # NEW
+'zxml_nonvide_balise' => 'balise non vide', # NEW
+'zxml_obligatoire_attribut' => 'attribut obligatoire mais absent dans', # NEW
+'zxml_succession_fils_incorrecte' => 'succession des fils incorrecte', # NEW
+'zxml_survoler' => 'survoler pour voir les corrects', # NEW
+'zxml_valeur_attribut' => 'valeur de l\'attribut', # NEW
+'zxml_vide_balise' => 'balise vide', # NEW
+'zxml_vu' => 'vu auparavant', # NE
 );
 
 ?>
