@@ -23,8 +23,12 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 'admin_modifier_mot' => 'Modificar aqueu mot clau',
 'admin_modifier_rubrique' => 'Modificar aquela rubrica',
 'admin_recalculer' => 'Tornar calcular la p&agrave;gina',
+'afficher_trad' => 'afficher les traductions', # NEW
 'alerte_maj_impossible' => '<b>Al&egrave;rta!</b> Es impossible d\'actualizar la basa SQL v&egrave;rs la version @version@; benl&egrave;u i a un probl&egrave;ma relatiu au drech de modificar la basa de donadas. Vorgatz contactar lo v&ograve;stre aubergador.',
+'alerte_modif_info_concourante' => 'ATTENTION : Cette information a &eacute;t&eacute; modifi&eacute;e par ailleurs. La valeur actuelle est&nbsp;:', # NEW
 'analyse_xml' => 'Analisi XML',
+'annuler' => 'Annuler', # NEW
+'antispam_champ_vide' => 'Veuillez laisser ce champ vide&nbsp;:', # NEW
 'articles_recents' => 'Lu articles mai recents',
 'avis_archive_incorrect' => 'lo fichier archiu non es un fichier SPIP',
 'avis_archive_invalide' => 'lo fichier archiu non es valid',
@@ -39,6 +43,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 'avis_erreur_fonction_contexte' => 'Error de programacion. Non cau apelar aquela foncion dins aqueu cont&egrave;xt.',
 'avis_erreur_mysql' => 'Error SQL ',
 'avis_erreur_sauvegarde' => 'Error dins la sauvagarda (@type@ @id_objet@)! ',
+'avis_erreur_visiteur' => 'Probl&egrave;me d\'acc&egrave;s &agrave; l\'espace priv&eacute;', # NEW
 
 // B
 'barre_a_accent_grave' => 'Inserir una A accent gr&egrave;u majuscula',
@@ -55,12 +60,15 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 'barre_lien' => 'Transformar en [ligam ipert&egrave;xt->http://...]',
 'barre_lien_input' => 'Vorgatz indicar l\'adrei&ccedil;a dau v&ograve;stre ligam (pod&egrave;tz indicar una adrei&ccedil;a web sota la forma http://www.lomieusit.com &ograve; simplament indicar lo n&uacute;mero d\'un article d\'aqueu sit).',
 'barre_note' => 'Transformar en [[N&ograve;ta de p&egrave;]]',
+'barre_paragraphe' => 'Cr&#233;er un paragraphe', # NEW
 'barre_quote' => '<quote>Citar un messatge</quote>',
-'bouton_ajouter_document' => '<MODIF>APONDRE UN DOCUMENT',
-'bouton_ajouter_image' => '<MODIF>APONDRE UN IMATGE',
+'bouton_ajouter_document' => 'APONDRE UN DOCUMENT', # MODIF
+'bouton_ajouter_image' => 'APONDRE UN IMATGE', # MODIF
+'bouton_ajouter_image_document' => 'Ajouter une image ou&nbsp;un&nbsp;document', # NEW
 'bouton_changer' => 'Cambiar',
 'bouton_chercher' => 'Cercar',
 'bouton_choisir' => 'Chausir',
+'bouton_download' => 'T&eacute;l&eacute;charger', # NEW
 'bouton_enregistrer' => 'Registrar',
 'bouton_radio_desactiver_messagerie_interne' => 'Desactivar la messatjaria int&egrave;rna',
 'bouton_radio_envoi_annonces' => 'Mandar lu anoncis editoriaus',
@@ -77,7 +85,11 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 'cal_par_jour' => 'calendier per jorn',
 'cal_par_mois' => 'calendier per mes',
 'cal_par_semaine' => 'calendier per setmana',
+'choix_couleur_interface' => 'couleur ', # NEW
+'choix_interface' => 'choix  de l\'interface', # NEW
+'colonne' => 'Colonne', # NEW
 'confirm_changer_statut' => 'Atencion, av&egrave;tz demandat de cambiar l\'estatut d\'aquel element. Desiratz de contunhar? ',
+'correcte' => 'correcte', # chaine utilis&eacute;e dans le debugueur : "validation .. impossible" ou "validation .. correcte" NEW
 
 // D
 'date_aujourdhui' => 'ancuei',
@@ -137,12 +149,26 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 'date_jnum8' => '8',
 'date_jnum9' => '9',
 'date_jour_1' => 'dim&eacute;negue',
+'date_jour_1_abbr' => 'dim.', # NEW
+'date_jour_1_initiale' => 'd.', # NEW
 'date_jour_2' => 'diluns',
+'date_jour_2_abbr' => 'lun.', # NEW
+'date_jour_2_initiale' => 'l.', # NEW
 'date_jour_3' => 'dimars',
+'date_jour_3_abbr' => 'mar.', # NEW
+'date_jour_3_initiale' => 'm.', # NEW
 'date_jour_4' => 'dim&egrave;cres',
+'date_jour_4_abbr' => 'mer.', # NEW
+'date_jour_4_initiale' => 'm.', # NEW
 'date_jour_5' => 'dij&ograve;us',
+'date_jour_5_abbr' => 'jeu.', # NEW
+'date_jour_5_initiale' => 'j.', # NEW
 'date_jour_6' => 'divendres',
+'date_jour_6_abbr' => 'ven.', # NEW
+'date_jour_6_initiale' => 'v.', # NEW
 'date_jour_7' => 'dissabta',
+'date_jour_7_abbr' => 'sam.', # NEW
+'date_jour_7_initiale' => 's.', # NEW
 'date_jours' => 'jorns',
 'date_minutes' => 'minutas',
 'date_mois' => 'mes',
@@ -162,7 +188,13 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 'date_saison_2' => 'prima',
 'date_saison_3' => 'estiu',
 'date_saison_4' => 'auton',
+'date_secondes' => 'secondes', # NEW
 'date_semaines' => 'setmana(s)',
+'date_un_mois' => 'mois', # NEW
+'date_une_heure' => 'heure', # NEW
+'date_une_minute' => 'minute', # NEW
+'date_une_seconde' => 'seconde', # NEW
+'date_une_semaine' => 'semaine', # NEW
 'dirs_commencer' => 'per comen&ccedil;ar verament l\'installacion',
 'dirs_preliminaire' => 'Preliminar: <b>Reglar lu drechs d\'acc&egrave;s</b>',
 'dirs_probleme_droits' => 'Probl&egrave;ma de drechs d\'acc&egrave;s',
@@ -172,18 +204,36 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
   &ccedil;ai subre; se non es lo cas, tornatz nommar lu repert&ograve;ris embau v&ograve;stre logiciau FTP en corregissent l\'error.
   <p>Un c&ograve;up qu\'auretz fach aqu&ograve;, porretz ',
 'dirs_repertoires_suivants' => '<b>Lu repert&ograve;ris seguents non son accessibles en escritura: <ul>@bad_dirs@.</ul> </b>
-  <p />Per adobar aqu&ograve;, utilizatz lo v&ograve;stre client FTP per fin de reglar lu drechs d\'acc&egrave;s de cadun
+  <p>Per adobar aqu&ograve;, utilizatz lo v&ograve;stre client FTP per fin de reglar lu drechs d\'acc&egrave;s de cadun
   d\'aquelu repert&ograve;ris. La guida d\'installacion explica en detalh coma cau procedir.
-  <p>Tre qu\'auretz facha aquela manipulacion, porretz ',
+  <p>Tre qu\'auretz facha aquela manipulacion, porretz </p>',
+'double_occurrence' => 'Double occurrence de @balise@', # NEW
 
 // E
+'en_cours' => 'en cours', # NEW
 'entree_dimensions' => 'Dimensions:',
 'entree_titre_document' => 'T&iacute;tol dau document:',
 'entree_titre_image' => 'T&iacute;tol de l\'imatge:',
 'envoi_via_le_site' => 'Mandad&iacute;s embau biais dau sit web',
+'erreur' => 'Erreur', # NEW
+'erreur_balise_non_fermee' => 'derni&egrave;re balise non referm&eacute;e :', # NEW
+'erreur_texte' => 'erreur(s)', # NEW
+'etape' => '&Eacute;tape', # NEW
 
 // F
 'fichier_introuvable' => 'Non s\'es pogut trobar lo fichier @fichier@.',
+'form_auteur_confirmation' => 'Confirmez votre adresse email', # NEW
+'form_auteur_email_modifie' => 'Votre adresse email a &eacute;t&eacute; modifi&eacute;e.', # NEW
+'form_auteur_envoi_mail_confirmation' => 'Un courrier &eacute;lectronique de confirmation vient d\'&ecirc;tre envoy&eacute; &agrave; @email@. Vous devrez visiter l\'adresse Web mentionn&eacute;e dans ce courrier pour valider votre adresse mail.', # NEW
+'form_auteur_mail_confirmation' => 'Bonjour,
+
+Vous avez demand&eacute; &agrave; changer votre adresse email.
+Pour confirmer votre nouvelle adresse, il suffit de vous connecter &agrave;
+l\'adresse ci-dessous (dans le cas contraire, votre demande
+sera ignor&eacute;e) :
+
+    @url@
+', # NEW
 'form_deja_inscrit' => 'Siatz ja inscrich(a).',
 'form_email_non_valide' => 'La v&ograve;stra adrei&ccedil;a e-mail non es valida.',
 'form_forum_access_refuse' => 'Pod&egrave;tz pus accedir a aqueu sit.',
@@ -208,7 +258,7 @@ dau sit "@nom_site_spip@" (@adresse_site@):',
 'form_pet_confirmation' => 'Vorgatz confirmar la v&ograve;stra signatura:',
 'form_pet_deja_enregistre' => 'Ja aqueu sit es registrat',
 'form_pet_deja_signe' => 'Av&egrave;tz ja signat aqueu t&egrave;xt.',
-'form_pet_envoi_mail_confirmation' => '<MODIF>A&uuml;ra recebretz un e-mail de confirmacion. Per validar la v&ograve;stra signatura, cau vesitar l\'adrei&ccedil;a web men&ccedil;onada per aquest corrier.',
+'form_pet_envoi_mail_confirmation' => 'A&uuml;ra recebretz un e-mail de confirmacion. Per validar la v&ograve;stra signatura, cau vesitar l\'adrei&ccedil;a web men&ccedil;onada per aquest corrier.', # MODIF
 'form_pet_mail_confirmation' => 'B&ograve;njorn,
 
 av&egrave;tz demandat de signar la peticion:
@@ -230,6 +280,7 @@ Merc&eacute; per la v&ograve;stra participacion
 ',
 'form_pet_message_commentaire' => 'Un messatge, una remarca?',
 'form_pet_nom_site2' => 'Nom dau v&ograve;stre sit web',
+'form_pet_probleme_liens' => 'Veuillez reprendre votre message en supprimant les liens hypertexte.', # NEW
 'form_pet_probleme_technique' => 'Probl&egrave;ma tecnic, li signaturas son tempor&agrave;riament arrestadi.',
 'form_pet_signature_pasprise' => 'La v&ograve;stra signatura non es pilhada en c&ograve;mpte.',
 'form_pet_signature_validee' => 'La v&ograve;stra signatura es validada. Merc&eacute;!',
@@ -253,6 +304,7 @@ Merc&eacute; per la v&ograve;stra participacion
 'forum_acces_refuse' => 'Pod&egrave;tz pus accedir a aquelu forums.',
 'forum_attention_dix_caracteres' => '<b>Atencion!</b> lo v&ograve;stre messatge deu tenir aumens d&egrave;tz caract&egrave;rs.',
 'forum_attention_trois_caracteres' => '<b>Atencion!</b> lo v&ograve;stre t&iacute;tol deu tenir aumens tres caract&egrave;rs.',
+'forum_attention_trop_caracteres' => '<b>Attention&nbsp;!</b> votre message est trop long (@compte@ caract&egrave;res)&nbsp;: pour pouvoir &ecirc;tre enregistr&eacute;, il ne doit pas d&eacute;passer @max@ caract&egrave;res.', # NEW
 'forum_avez_selectionne' => 'Av&egrave;tz seleccionat:',
 'forum_cliquer_retour' => 'Clicatz <a href=\'@retour_forum@\'>aic&iacute;</a> per contunhar.',
 'forum_forum' => 'forum',
@@ -339,6 +391,7 @@ Merc&eacute; per la v&ograve;stra participacion
 'image_tourner_droite' => 'Rotacion 90&deg; v&egrave;rs la drecha',
 'image_tourner_gauche' => 'Rotacion 90&deg; v&egrave;rs la sen&egrave;ca',
 'img_indisponible' => 'imatge indisponible',
+'impossible' => 'impossible', # NEW
 'info_a_suivre' => 'DE S&Egrave;GRE&gt;&gt;',
 'info_a_valider' => '[de validar]',
 'info_acces_interdit' => 'Acc&egrave;s pro&iuml;bit',
@@ -357,19 +410,23 @@ Merc&eacute; per la v&ograve;stra participacion
 'info_article_supprime' => 'Article suprimit',
 'info_articles' => 'Articles',
 'info_articles_a_valider' => 'Lu articles de validar',
+'info_articles_nb' => '@nb@ articles', # NEW
 'info_articles_proposes' => 'Articles prepauats',
+'info_articles_un' => '1 article', # NEW
 'info_auteurs_nombre' => 'autor(s)',
 'info_authentification_ftp' => 'autentificacion (per FTP).',
 'info_bloquer_lien' => 'Blocar aqueu liame',
 'info_breves_02' => 'Br&egrave;vas',
 'info_breves_2' => 'br&egrave;vas',
+'info_breves_nb' => '@nb@ br&egrave;ves', # NEW
+'info_breves_un' => '1 br&egrave;ve', # NEW
 'info_breves_valider' => 'Br&egrave;vas de validar',
 'info_connexion_refusee' => 'Connexion refusada',
 'info_contact_developpeur' => 'Vorgatz contactar un desvolopaire.',
 'info_contenance' => 'Aqueu sit conten:',
 'info_contribution' => 'Contribucions de forum',
 'info_copyright' => '@spip@ es un logiciau liure distribuit @lien_gpl@.',
-'info_copyright_doc' => 'Per mai d\'informacions, veire lo sit <a href=\'http://www.spip.net/oc\'>http://www.spip.net/oc</a>.',
+'info_copyright_doc' => 'Per mai d\'informacions, veire lo sit <a href="@spipnet@">http://www.spip.net/oc</a>.', # MODIF
 'info_copyright_gpl' => 'sota lic&eacute;ncia GPL',
 'info_cours_edition' => 'Li v&ograve;stres articles en cors de redaccion',
 'info_creer_repertoire' => 'Vorgatz crear un fichier &ograve; un repert&ograve;ri nommat',
@@ -381,7 +438,10 @@ Merc&eacute; per la v&ograve;stra participacion
 'info_description_2' => 'Descripcion:',
 'info_dimension' => 'Dimensions:',
 'info_document' => 'Document ',
+'info_document_indisponible' => 'Ce document n\'est pas disponible', # NEW
 'info_documents' => 'Documents',
+'info_documents_nb' => '@nb@ documents', # NEW
+'info_documents_un' => '1 document', # NEW
 'info_echange_message' => 'SPIP permete d\'escambiar de messatges e de constituir de forums privats de discussion entre lu participants dau sit. Pod&egrave;tz activar &ograve; desactivar aquela foncionalitat.',
 'info_ecire_message_prive' => 'Escriure un messatge privat',
 'info_email_invalide' => 'Adrei&ccedil;a e-mail invalida',
@@ -426,6 +486,8 @@ Merc&eacute; per la v&ograve;stra participacion
 'info_mail_fournisseur' => 'vos@fornidor.com',
 'info_message_2' => 'MESSATGE',
 'info_message_supprime' => 'MESSATGE SUPRIMIT',
+'info_messages_nb' => '@nb@ messages', # NEW
+'info_messages_un' => '1 message', # NEW
 'info_mise_en_ligne' => 'Data de mesa en linha:',
 'info_modification_parametres_securite' => 'modificacions dei param&egrave;tres de seguretat',
 'info_mois_courant' => 'Dins lo corrent dau mes:',
@@ -441,9 +503,11 @@ Merc&eacute; per la v&ograve;stra participacion
 'info_nouveau_message' => 'AV&Egrave;TZ UN MESSATGE N&Ograve;U',
 'info_nouveaux_messages' => 'AV&Egrave;TZ @total_messages@ MESSATGES N&Ograve;US',
 'info_numero_abbreviation' => 'N&deg;&nbsp;',
+'info_obligatoire' => 'Cette information est obligatoire', # NEW
 'info_panne_site_syndique' => 'Sit sindicat en pana',
 'info_pense_bete' => 'MEMENTO',
 'info_petit_ecran' => 'Ecran pichin ',
+'info_petition_close' => 'P&eacute;tition close', # NEW
 'info_pixels' => 'pix&egrave;ls',
 'info_plusieurs_mots_trouves' => 'plusors mots clau trobats per "@cherche_mot@":',
 'info_popularite_5' => 'popularitat:',
@@ -468,13 +532,19 @@ Merc&eacute; per la v&ograve;stra participacion
 'info_retablir_lien' => 'Restablir aqueu ligam',
 'info_retirer_mot' => 'Quitar aqueu mot',
 'info_retirer_mots' => 'Quitar toi lu mots ',
+'info_rubriques_nb' => '@nb@ rubriques', # NEW
+'info_rubriques_un' => '1 rubrique', # NEW
 'info_sans_titre_2' => 'sensa t&iacute;tol',
 'info_selectionner_fichier' => 'Pod&egrave;tz seleccionar un fichier dau dorsier @upload@',
 'info_selectionner_fichier_2' => 'Seleccionar un fichier:',
+'info_signature_supprimee' => 'Signature supprim&eacute;e', # NEW
+'info_signature_supprimee_erreur' => 'Erreur&nbsp;: ce code de suppression ne correspond a aucune signature', # NEW
 'info_site_attente' => 'Sit web en esp&egrave;ra de validacion',
 'info_site_reference' => 'Sit referenciat en linha',
 'info_site_refuse' => 'Sit web refusat',
+'info_sites_nb' => '@nb@ sites', # NEW
 'info_sites_referencer' => 'Referenciar un sit',
+'info_sites_un' => '1 site', # NEW
 'info_supprimer_vignette' => 'suprimir la vinheta',
 'info_symbole_bleu' => 'Lo simb&egrave;u <b>blau</b> marca un <b>memento</b>: valent a dire un messatge per lo v&ograve;stre usatge personau.',
 'info_symbole_jaune' => 'Lo simb&egrave;u <b>jaune</b> marca un <b>anonci per toi lu redactors </b>: lu administrators lo p&ograve;don modificar, cada redactor lo p&ograve;u veire.',
@@ -505,7 +575,6 @@ Merc&eacute; per la v&ograve;stra participacion
 'lien_afficher_icones_seuls' => 'Afichar basta li ic&ograve;nas ',
 'lien_afficher_texte_icones' => 'Afichar basta li ic&ograve;nas e lo t&egrave;xt',
 'lien_afficher_texte_seul' => 'Afichar basta lo t&egrave;xt ',
-'lien_icones_interface' => 'Li ic&ograve;nas de l\'interf&agrave;cia son de <a href=\'http://jimmac.musichall.cz/\'>Jakub \'Jimmac\' Steiner</a>.',
 'lien_liberer' => 'liberar',
 'lien_liberer_tous' => 'liberar aquelu articles',
 'lien_nouvea_pense_bete' => 'MEMENTO N&Ograve;U',
@@ -521,6 +590,8 @@ Merc&eacute; per la v&ograve;stra participacion
 'lien_visite_site' => 'vesitar aqueu sit',
 'lien_visites' => '@visites@&nbsp;vesitas',
 'lien_voir_auteur' => 'Veire aquel autor',
+'ligne' => 'Ligne', # NEW
+'login' => 'Connexion', # NEW
 'login_acces_prive' => 'acc&egrave;s a l\'espaci privat',
 'login_autre_identifiant' => 'si connectar emb un autre identificant',
 'login_cookie_accepte' => 'Vorgatz configurar lo v&ograve;stre navigador per que lu acc&egrave;pte (aumens per aqueu sit).',
@@ -547,17 +618,22 @@ Merc&eacute; per la v&ograve;stra participacion
 'login_retour_site' => 'Tornar au sit public',
 'login_retoursitepublic' => 'tornar&nbsp;au&nbsp;sit&nbsp;public',
 'login_sans_cookiie' => 'Identificacion sensa cookie',
+'login_securise' => 'Login s&eacute;curis&eacute;', # NEW
 'login_sinscrire' => 's\'inscriure',
 'login_test_navigateur' => 'Assai navigador/tornar&nbsp;connectar',
 'login_verifiez_navigateur' => '(totun verificatz que lo v&ograve;stre navigador non auga servat lo v&ograve;stre mot de santa Clara en mem&ograve;ria...)',
 
 // M
+'masquer_colonne' => 'Masquer cette colonne', # NEW
+'masquer_trad' => 'masquer les traductions', # NEW
 'module_fichiers_langues' => 'Fichiers de lenga',
 
 // N
 'navigateur_pas_redirige' => 'Se lo v&ograve;stre navigador non es redirigit, clicatz aic&iacute; per contunhar.',
+'numero' => 'Num&eacute;ro', # NEW
 
 // O
+'occurence' => 'Occurrence', # NEW
 'onglet_affacer_base' => 'Esfa&ccedil;ar la basa',
 'onglet_auteur' => 'L\'autor',
 'onglet_contenu_site' => 'Contengut dau sit',
@@ -622,7 +698,14 @@ e vos tornar connectar au sit.
 'previsualisation' => 'Previsualizacion',
 'previsualiser' => 'Previsualizar',
 
+// R
+'retour' => 'Retour', # NEW
+
 // S
+'spip_conforme_dtd' => 'SPIP consid&egrave;re ce document comme conforme &agrave; son DOCTYPE :', # NEW
+'squelette' => 'squelette', # NEW
+'squelette_inclus_ligne' => 'squelette inclus, ligne', # NEW
+'squelette_ligne' => 'squelette, ligne', # NEW
 'stats_visites_et_popularite' => '@visites@ vesitas; popularitat: @popularite@',
 'suivant' => 'seguent',
 
@@ -642,9 +725,10 @@ e vos tornar connectar au sit.
   Notatz ben aquela refer&eacute;ncia, tornatz assaiar la mesa a
  niv&egrave;u, e verificatz pi que lu imatges aparegan
  encara dins lu articles.',
-'texte_inc_auth_1' => '<MODIF>Siatz identificat/ada coma
+'texte_erreur_visiteur' => 'Vous avez tent&eacute; d\'acc&eacute;der &agrave; l\'espace priv&eacute; avec un login qui ne le permet pas.', # NEW
+'texte_inc_auth_1' => 'Siatz identificat/ada coma
    <b>@auth_login@</b>, mas aqueu login non existisse &ograve; existisse pus dins la basa.
-  Assaiatz de vos',
+  Assaiatz de vos', # MODIF
 'texte_inc_auth_2' => 'tornar connectar',
 'texte_inc_auth_3' => ', apr&egrave;s qu\'auretz quitat eventualament, pi
   tornat lan&ccedil;ar lo v&ograve;stre navigador.',
@@ -680,32 +764,61 @@ e vos tornar connectar au sit.
 'titre_mots_cles' => 'MOTS CLAU',
 'titre_probleme_technique' => 'Atencion: un probl&egrave;ma tecnic (servidor SQL) empedisse d\'accedir a aquela part dau sit. Merc&eacute; de la v&ograve;stra indulg&eacute;ncia.',
 'titre_publier_document' => 'PUBLICAR UN DOCUMENT DINS AQUELA RUBRICA',
+'titre_signatures_attente' => 'Signatures en attente de validation', # NEW
+'titre_signatures_confirmees' => 'Signatures confirm&eacute;es', # NEW
 'titre_statistiques' => 'Estadisticas dau sit',
 'titre_titre_document' => 'T&iacute;tol dau document:',
+'todo' => '&agrave; venir', # NEW
 'trad_reference' => '(article de refer&eacute;ncia)',
 
 // Z
 'zbug_balise_b_aval' => '&nbsp;: balisa B en avau',
+'zbug_balise_inexistante' => 'Balise @balise@ mal d&eacute;clar&eacute;e pour @from@', # NEW
+'zbug_balise_sans_argument' => 'Argument manquant dans la balise @balise@', # NEW
 'zbug_boucle' => 'bloca',
-'zbug_boucle_recursive_undef' => 'bloca recursiva non definida',
+'zbug_boucle_recursive_undef' => 'bloca recursiva non definida', # MODIF
+'zbug_calcul' => 'calcul', # NEW
 'zbug_champ_hors_boucle' => 'Camp @champ@ f&ograve;ra bloca',
-'zbug_champ_hors_motif' => 'Camp @champ@ en def&ograve;ra d\'una bloca de motiu @motif@',
+'zbug_champ_hors_motif' => 'Camp @champ@ en def&ograve;ra d\'una bloca de motiu @motif@', # MODIF
 'zbug_code' => 'c&ograve;de',
-'zbug_critere_inconnu' => 'crit&egrave;ri inconegut @critere@',
-'zbug_distant_interdit' => 'ext&egrave;rne enebit',
-'zbug_erreur_boucle_double' => 'BLOCA@id@: definicion dobla',
-'zbug_erreur_boucle_fermant' => 'BLOCA@id@: lo tag barrador manca',
-'zbug_erreur_boucle_syntaxe' => 'Sintaxi bloca incorr&egrave;cta',
-'zbug_erreur_execution_page' => 'error d\'execucion de la p&agrave;gina',
-'zbug_erreur_filtre' => 'Error: filtre <b>&laquo; @filtre@ &raquo;</b> non definit',
-'zbug_erreur_meme_parent' => '{meme_parent} s\'aplica basta ai blocas (FORUMS) o (RUBRIQUES)',
+'zbug_critere_inconnu' => 'crit&egrave;ri inconegut @critere@', # MODIF
+'zbug_distant_interdit' => 'ext&egrave;rne enebit', # MODIF
+'zbug_doublon_table_sans_cle_primaire' => 'Doublons sur une table sans clef primaire atomique', # NEW
+'zbug_doublon_table_sans_index' => 'Doublons sur une table sans index', # NEW
+'zbug_erreur_boucle_double' => 'BLOCA@id@: definicion dobla', # MODIF
+'zbug_erreur_boucle_fermant' => 'BLOCA@id@: lo tag barrador manca', # MODIF
+'zbug_erreur_boucle_syntaxe' => 'Sintaxi bloca incorr&egrave;cta', # MODIF
+'zbug_erreur_compilation' => 'Erreur de compilation', # NEW
+'zbug_erreur_execution_page' => 'error d\'execucion de la p&agrave;gina', # MODIF
+'zbug_erreur_filtre' => 'Error: filtre <b>&laquo; @filtre@ &raquo;</b> non definit', # MODIF
+'zbug_erreur_meme_parent' => '{meme_parent} s\'aplica basta ai blocas (FORUMS) o (RUBRIQUES)', # MODIF
 'zbug_erreur_squelette' => 'Error(s) dins l\'esqueleta',
+'zbug_hors_compilation' => 'Hors Compilation', # NEW
 'zbug_info_erreur_squelette' => 'Error sobre lo sit',
-'zbug_inversion_ordre_inexistant' => 'inversion d\'un &ograve;rdre inexistent',
-'zbug_parametres_inclus_incorrects' => 'Param&egrave;tres d\'inclusion incorr&egrave;ctes',
+'zbug_inversion_ordre_inexistant' => 'inversion d\'un &ograve;rdre inexistent', # MODIF
+'zbug_pagination_sans_critere' => 'Balise #PAGINATION sans crit&egrave;re {pagination} ou employ&eacute; dans une boucle recursive', # NEW
+'zbug_parametres_inclus_incorrects' => 'Param&egrave;tres d\'inclusion incorr&egrave;ctes', # MODIF
+'zbug_profile' => 'Temps de calcul&nbsp;: @time@', # NEW
 'zbug_resultat' => 'resultat',
-'zbug_serveur_indefini' => 'servidor SQL indefinit',
-'zbug_table_inconnue' => 'Taula SQL &laquo;@table@&raquo; inconeguda'
+'zbug_serveur_indefini' => 'servidor SQL indefinit', # MODIF
+'zbug_statistiques' => 'Statistiques des requ&ecirc;tes SQL class&eacute;es par dur&eacute;e', # NEW
+'zbug_table_inconnue' => 'Taula SQL &laquo;@table@&raquo; inconeguda',
+'zxml_connus_attributs' => 'attributs connus', # NEW
+'zxml_de' => 'de', # NEW
+'zxml_inconnu_attribut' => 'attribut inconnu', # NEW
+'zxml_inconnu_balise' => 'balise inconnue', # NEW
+'zxml_inconnu_entite' => 'entit&eacute; inconnue', # NEW
+'zxml_inconnu_id' => 'ID inconnu', # NEW
+'zxml_mais_de' => 'mais de', # NEW
+'zxml_non_conforme' => 'n\'est pas conforme au motif', # NEW
+'zxml_non_fils' => 'n\'est pas un fils de', # NEW
+'zxml_nonvide_balise' => 'balise non vide', # NEW
+'zxml_obligatoire_attribut' => 'attribut obligatoire mais absent dans', # NEW
+'zxml_succession_fils_incorrecte' => 'succession des fils incorrecte', # NEW
+'zxml_survoler' => 'survoler pour voir les corrects', # NEW
+'zxml_valeur_attribut' => 'valeur de l\'attribut', # NEW
+'zxml_vide_balise' => 'balise vide', # NEW
+'zxml_vu' => 'vu auparavant', # NE
 );
 
 ?>
