@@ -188,7 +188,13 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 'date_saison_2' => 'primavera',
 'date_saison_3' => 'ver&atilde;o',
 'date_saison_4' => 'outono',
+'date_secondes' => 'segundos',
 'date_semaines' => 'semanas',
+'date_un_mois' => 'm&ecirc;s',
+'date_une_heure' => 'hora',
+'date_une_minute' => 'minuto',
+'date_une_seconde' => 'segundo',
+'date_une_semaine' => 'semana',
 'dirs_commencer' => 'Para come&ccedil;ar realmente a instala&ccedil;&atilde;o',
 'dirs_preliminaire' => 'Preliminar: <b>Configurar os direitos de acesso</b>',
 'dirs_probleme_droits' => 'Problema com as permiss&otilde;es de acesso',
@@ -199,7 +205,7 @@ Verifique se as mai&uacute;sculas e min&uacute;suculas destes diret&oacute;rios
 'dirs_repertoires_suivants' => '<p><b>Os diret&oacute;rios a seguir n&atilde;o est&atilde;o acessiveis para leitura:</b></p><ul>@bad_dirs@.</ul>
 <p>Para corrigir, utilize o seu programa de FTP para configurar os direitos de acesso de cada um destes diret&oacute;rios. O procedimento est&aacute; explicado em detalhes no guia de instala&ccedil;&atilde;o.</p>
 <p>Uma v&ecirc;z feita esta altera&ccedil;&atilde;o, voc&ecirc; poder&aacute; ',
-'double_occurrence' => 'Duplica&ccedil;&atilde;o',
+'double_occurrence' => 'Ocorr&ecirc;ncia dupla de @balise@',
 
 // E
 'en_cours' => 'em curso',
@@ -214,6 +220,16 @@ Verifique se as mai&uacute;sculas e min&uacute;suculas destes diret&oacute;rios
 
 // F
 'fichier_introuvable' => 'Arquivo @fichier@ n&atilde;o encontrado',
+'form_auteur_confirmation' => 'Confirme o seu endere&ccedil;o de e-mail',
+'form_auteur_email_modifie' => 'O seu endere&ccedil;o de e-mail foi alterado.',
+'form_auteur_envoi_mail_confirmation' => 'Uma mensagem de confirma&ccedil;&atilde;o acabou de ser enviada para @email@. Voc&ecirc; precisa entrar no endere&ccedil;o web mencionado na mensagem para validar o seu endere&ccedil;o de e-mail.',
+'form_auteur_mail_confirmation' => 'Ol&aacute;,
+
+Voc&ecirc; pediu para alterar o seu endere&ccedil;o de e-mail
+Para confirmar o seu novo endere&ccedil;o, basta acessar o endere&ccedil;o abaixo (cas contr&aacute;rio, a sua solicita&ccedil;&atilde;o ser&aacute; ignorada):
+
+    @url@
+',
 'form_deja_inscrit' => 'Voc&ecirc; j&aacute; est&aacute; inscrito.',
 'form_email_non_valide' => 'Seu endere&ccedil;o de e-mail n&atilde;o &eacute; v&aacute;lido.',
 'form_forum_access_refuse' => 'Voc&ecirc; n&atilde;o tem mais acesso a este site.',
@@ -386,19 +402,23 @@ Obrigado por participar
 'info_article_supprime' => 'Mat&eacute;ria suprimida',
 'info_articles' => 'Mat&eacute;rias',
 'info_articles_a_valider' => 'As mat&eacute;rias para validar',
+'info_articles_nb' => '@nb@ mat&eacute;rias',
 'info_articles_proposes' => 'Mat&eacute;rias propostas',
+'info_articles_un' => '1 mat&eacute;ria',
 'info_auteurs_nombre' => 'autor(es):',
 'info_authentification_ftp' => 'Autentica&ccedil;&atilde;o (por FTP).',
 'info_bloquer_lien' => 'bloquear este link',
 'info_breves_02' => 'Notas',
 'info_breves_2' => 'notas',
+'info_breves_nb' => '@nb@ notas',
+'info_breves_un' => '1 nota',
 'info_breves_valider' => 'Notas para validar',
 'info_connexion_refusee' => 'Conex&atilde;o recusada',
 'info_contact_developpeur' => 'Por favor, contate um desenvolvedor.',
 'info_contenance' => 'Este site cont&eacute;m:',
 'info_contribution' => 'contribui&ccedil;&otilde;es de f&oacute;rum',
 'info_copyright' => '@spip@ &eacute; um software livre distribu&iacute;do @lien_gpl@.',
-'info_copyright_doc' => 'Para mais informa&ccedil;&otilde;es, veja o site <a href=\'http://www.spip.net/fr\'>http://www.spip.net/</a>.',
+'info_copyright_doc' => 'Para mais informa&ccedil;&otilde;es, veja o site <a href="@spipnet@">http://www.spip.net/</a>.',
 'info_copyright_gpl' => 'sob licen&ccedil;a GPL',
 'info_cours_edition' => 'Suas mat&eacute;rias em fase de reda&ccedil;&atilde;o',
 'info_creer_repertoire' => 'Por favor, crie um arquivo ou diret&oacute;rio com o nome:',
@@ -412,6 +432,8 @@ Obrigado por participar
 'info_document' => 'Documento',
 'info_document_indisponible' => 'Este documento n&atilde;o est&aacute; dispon&iacute;vel',
 'info_documents' => 'Documentos',
+'info_documents_nb' => '@nb@ documentos',
+'info_documents_un' => '1 documento',
 'info_echange_message' => 'O SPIP permite a troca de mensagens e a forma&ccedil;&atilde;o de f&oacute;runs de discuss&atilde;o privados entre os participantes do site. Voc&ecirc; pode ativar ou desativar esta funcionalidade.',
 'info_ecire_message_prive' => 'Escrever uma mensagem privada',
 'info_email_invalide' => 'Endere&ccedil;o de e-mail inv&aacute;lido.',
@@ -456,6 +478,8 @@ Obrigado por participar
 'info_mail_fournisseur' => 'voce@seudominio.com.br',
 'info_message_2' => 'MENSAGEM',
 'info_message_supprime' => 'MENSAGEM EXCLU&Iacute;DA',
+'info_messages_nb' => '@nb@ mensagens',
+'info_messages_un' => '1 mensagem',
 'info_mise_en_ligne' => 'Data de publica&ccedil;&atilde;o online:',
 'info_modification_parametres_securite' => 'modifica&ccedil;&otilde;es dos par&acirc;metros de seguran&ccedil;a',
 'info_mois_courant' => 'No m&ecirc;s corrente:',
@@ -500,6 +524,8 @@ Obrigado por participar
 'info_retablir_lien' => 'reabilitar este link',
 'info_retirer_mot' => 'Retirar esta palavra-chave',
 'info_retirer_mots' => 'Retirar todas as palavras-chave',
+'info_rubriques_nb' => '@nb@ se&ccedil;&otilde;es',
+'info_rubriques_un' => '1 se&ccedil;&atilde;o',
 'info_sans_titre_2' => 'sem t&iacute;tulo',
 'info_selectionner_fichier' => 'Voc&ecirc; pode escolher um arquivo do diret&oacute;rio @upload@',
 'info_selectionner_fichier_2' => 'Selecionar um arquivo:',
@@ -508,7 +534,9 @@ Obrigado por participar
 'info_site_attente' => 'Website aguardando valida&ccedil;&atilde;o',
 'info_site_reference' => 'Site referenciado online',
 'info_site_refuse' => 'Website recusado',
+'info_sites_nb' => '@nb@ sites',
 'info_sites_referencer' => 'Referenciar um site',
+'info_sites_un' => '1 site',
 'info_supprimer_vignette' => 'excluir o &iacute;cone',
 'info_symbole_bleu' => 'O &iacute;cone <b>azul</b> indica um <b>lembrete</b>: ou seja, uma mensagem para seu uso pessoal.',
 'info_symbole_jaune' => 'O &iacute;cone <b>amarelo</b> indica um  <b>an&uacute;ncio para todos os redatores</b>: modific&aacute;vel por todos os administradores, e vis&iacute;vel por todos os redatores.',
@@ -539,7 +567,6 @@ Obrigado por participar
 'lien_afficher_icones_seuls' => 'Exibir apenas os &iacute;cones',
 'lien_afficher_texte_icones' => 'Exibir &iacute;cones e texto',
 'lien_afficher_texte_seul' => 'Exibir apenas o texto',
-'lien_icones_interface' => 'Os &iacute;cones da interface s&atilde;o de <a href=\'http://jimmac.musichall.cz/\'>Jakub \'Jimmac\' Steiner</a>.',
 'lien_liberer' => 'liberar',
 'lien_liberer_tous' => 'liberar estas mat&eacute;rias',
 'lien_nouvea_pense_bete' => 'NOVO LEMBRETE',
@@ -581,6 +608,7 @@ Se voc&ecirc; n&atilde;o quiser que a sua senha possa ser interceptada na rede,
 'login_retour_site' => 'Voltar ao site p&uacute;blico',
 'login_retoursitepublic' => 'voltar&nbsp;ao&nbsp;site&nbsp;p&uacute;blico',
 'login_sans_cookiie' => 'Identifica&ccedil;&atilde;o sem cookie',
+'login_securise' => 'Login seguro',
 'login_sinscrire' => 'cadastrar-se',
 'login_test_navigateur' => 'testar navegador/reconex&atilde;o',
 'login_verifiez_navigateur' => '(Verifique sempre se o seu navegador n&atilde;o est&aacute; memorizando a sua senha...)',
@@ -719,34 +747,34 @@ Tente se',
 
 // Z
 'zbug_balise_b_aval' => ': tag B colocada ap&oacute;s BOUCLE',
-'zbug_balise_inexistante' => 'erro @from@: a tag #@balise@ n&atilde;o existe',
+'zbug_balise_inexistante' => 'Tag @balise@ mal declarada para @from@',
 'zbug_balise_sans_argument' => 'Falta um arqumento na tag @balise@',
 'zbug_boucle' => 'la&ccedil;o',
-'zbug_boucle_recursive_undef' => 'la&ccedil;o recursivo n&atilde;o definido',
+'zbug_boucle_recursive_undef' => 'La&ccedil;o recursivo n&atilde;o definido: @nom@',
 'zbug_calcul' => 'c&aacute;lculo',
 'zbug_champ_hors_boucle' => 'Campo @champ@ fora do la&ccedil;o',
-'zbug_champ_hors_motif' => 'Campo @champ@ fora de um la&ccedil;o de motivo @motif@',
+'zbug_champ_hors_motif' => 'Campo @champ@ fora de um contexto @motif@',
 'zbug_code' => 'c&oacute;digo',
-'zbug_critere_inconnu' => 'crit&eacute;rio @critere@ desconhecido',
-'zbug_distant_interdit' => 'externa interditada',
-'zbug_doublon_table_sans_cle_primaire' => 'duplica&ccedil;&atilde;o em tabela sem chave prim&aacute;ria at&ocirc;mica',
-'zbug_doublon_table_sans_index' => 'doublons em uma tabela sem index',
-'zbug_erreur_boucle_double' => 'BOUCLE@id@: dupla defini&ccedil;&atilde;o',
-'zbug_erreur_boucle_fermant' => 'BOUCLE@id@: falta a tag de fechamento',
-'zbug_erreur_boucle_syntaxe' => 'Sintaxe do la&ccedil;o est&aacute; incorreta',
+'zbug_critere_inconnu' => 'Crit&eacute;rio @critere@ desconhecido',
+'zbug_distant_interdit' => 'Externa interdita',
+'zbug_doublon_table_sans_cle_primaire' => 'Duplica&ccedil;&atilde;o em tabela sem chave prim&aacute;ria at&ocirc;mica',
+'zbug_doublon_table_sans_index' => 'Doublons em uma tabela sem index',
+'zbug_erreur_boucle_double' => 'Dupla defini&ccedil;&atilde;o do la&ccedil;o @id@',
+'zbug_erreur_boucle_fermant' => 'La&ccedil;o @id@ n&atilde;o fechado',
+'zbug_erreur_boucle_syntaxe' => 'Sintaxe do la&ccedil;o @id@ est&aacute; incorreta',
 'zbug_erreur_compilation' => 'Erro de compila&ccedil;&atilde;o',
-'zbug_erreur_execution_page' => 'erro de execu&ccedil;&atilde;o da p&aacute;gina',
-'zbug_erreur_filtre' => 'Erro: filtro <b>&laquo; @filtre@ &raquo;</b> n&atilde;o definido',
-'zbug_erreur_meme_parent' => '{meme_parent} aplica-se exclusivamente aos la&ccedil;os (FORUMS) ou (RUBRIQUES)',
+'zbug_erreur_execution_page' => 'Erro de execu&ccedil;&atilde;o',
+'zbug_erreur_filtre' => 'Filtro @filtre@ n&atilde;o definido',
+'zbug_erreur_meme_parent' => 'O crit&eacute;rio {meme_parent} aplica-se exclusivamente aos la&ccedil;os (FORUMS) ou (RUBRIQUES)',
 'zbug_erreur_squelette' => 'Erro(s) no gabarito',
 'zbug_hors_compilation' => 'Fora de Compila&ccedil;&atilde;o',
 'zbug_info_erreur_squelette' => 'Erro no site',
-'zbug_inversion_ordre_inexistant' => 'invers&atilde;o de uma ordem inexistente',
-'zbug_pagination_sans_critere' => '#PAGINATION sem crit&eacute;rio {pagination} ou usada dentro de uma boucle recursiva',
-'zbug_parametres_inclus_incorrects' => 'Par&acirc;metros de inclus&atilde;o incorretos',
+'zbug_inversion_ordre_inexistant' => 'Invers&atilde;o de uma ordem inexistente',
+'zbug_pagination_sans_critere' => 'Tag #PAGINATION sem crit&eacute;rio {pagination} ou usada dentro de uma boucle recursiva',
+'zbug_parametres_inclus_incorrects' => 'Par&acirc;metro de inclus&atilde;o incorreto: @param@',
 'zbug_profile' => 'Tempo de processamento: @time@',
 'zbug_resultat' => 'resultado',
-'zbug_serveur_indefini' => 'sevidor SQL n&atilde;o definido',
+'zbug_serveur_indefini' => 'Sevidor SQL n&atilde;o definido',
 'zbug_statistiques' => 'Estat&iacute;sticas das requisi&ccedil;&otilde;es SQL classificadas por dura&ccedil;&atilde;o',
 'zbug_table_inconnue' => 'Tabela SQL &laquo;@table@&raquo; desconhecida',
 'zxml_connus_attributs' => 'atributos conhecidos',
