@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2009                                                *
+ *  Copyright (c) 2001-2010                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -194,6 +194,11 @@ array('sql_alter',"TABLE spip_groupes_mots DROP syndic"),
 function maj_13135 () {
 	include_spip('inc/rubriques');
 	calculer_prochain_postdate();
+
+	// supprimer les eventuels vieux cache plugin qui n'utilisaient pas _chemin
+	@spip_unlink(_CACHE_PLUGINS_OPT);
+	@spip_unlink(_CACHE_PLUGINS_FCT);
+	@spip_unlink(_CACHE_PLUGINS_VERIF);
 }
 
 $GLOBALS['maj'][13135] = array(array('maj_13135'));
@@ -207,10 +212,27 @@ $GLOBALS['maj'][13833] = array(
 array('sql_alter',"TABLE spip_documents_liens ADD INDEX objet(id_objet,objet)"))
 ;
 
-// Types de fichiers m4a/m4b/m4p/m4u/m4v/dv
-$GLOBALS['maj'][14272] = array(array('upgrade_types_documents'));
+// Fin upgrade commun branche 2.0
 
+include_spip('inc/autoriser');
+$GLOBALS['maj'][13904] = array(
+array('sql_alter',"TABLE spip_auteurs ADD webmestre varchar(3)  DEFAULT 'non' NOT NULL"),
+array('sql_update','spip_auteurs',array('webmestre'=>"'oui'"),sql_in("id_auteur",defined('_ID_WEBMESTRES')?explode(':',_ID_WEBMESTRES):(autoriser('configurer')?array($GLOBALS['visiteur_session']['id_auteur']):array(0)))) // le webmestre est celui qui fait l'upgrade si rien de defini
+)
+;
+
+// sites plantes en mode "'su" au lieu de "sus"
+$GLOBALS['maj'][13929] = array(
+	array('sql_update',"spip_syndic",array('syndication'=>"'sus'"),"syndication LIKE '\\'%'")
+);
+
+// Types de fichiers m4a/m4b/m4p/m4u/m4v/dv
 // Types de fichiers Open XML (cro$oft)
 $GLOBALS['maj'][14558] = array(array('upgrade_types_documents'));
 
+// refaire les upgrade dont les numeros sont inferieurs a ceux de la branche 2.0
+// etre sur qu'ils sont bien unipotents(?)...
+$GLOBALS['maj'][14559] = $GLOBALS['maj'][13904]+$GLOBALS['maj'][13929]+$GLOBALS['maj'][14558];
+
+
 ?>
