@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2009                                                *
+ *  Copyright (c) 2001-2010                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -11,6 +11,8 @@
 \***************************************************************************/
 
 // Distinguer une inclusion d'un appel initial
+// (cette distinction est obsolete a present, on la garde provisoirement
+// par souci de compatiilite).
 
 if (isset($GLOBALS['_INC_PUBLIC'])) {
 
@@ -23,17 +25,16 @@ if (isset($GLOBALS['_INC_PUBLIC'])) {
 	// Faut-il initialiser SPIP ? (oui dans le cas general)
 	if (!defined('_DIR_RESTREINT_ABS'))
 		if (defined('_DIR_RESTREINT')
-		AND @file_exists(_DIR_RESTREINT.'inc_version.php')) {
-			include_once _DIR_RESTREINT.'inc_version.php';
+		AND @file_exists( _ROOT_RESTREINT . 'inc_version.php')) {
+			include_once  _ROOT_RESTREINT . 'inc_version.php';
 		}
 		else
 			die('inc_version absent ?');
 
 
 	// $fond defini dans le fichier d'appel ?
-	// note : securise anti-injection par inc/utils.php
 
-	else if (isset($fond)) { }
+	else if (isset($fond) AND !_request('fond')) { }
 
 	// fond demande dans l'url par page=xxxx ?
 	else if (isset($_GET[_SPIP_PAGE])) {
@@ -70,13 +71,13 @@ if (isset($GLOBALS['_INC_PUBLIC'])) {
 		$fond = '';
 	}
 
-	$tableau_des_erreurs = 	$tableau_des_temps = array();
+	$tableau_des_temps = array();
 
 	// Particularites de certains squelettes
 	if ($fond == 'login')
 		$forcer_lang = true;
 
-	if ($forcer_lang AND ($forcer_lang!=='non') AND !_request('action')) {
+	if (isset($forcer_lang) AND $forcer_lang AND ($forcer_lang!=='non') AND !_request('action')) {
 		include_spip('inc/lang');
 		verifier_lang_url();
 	}
@@ -85,17 +86,19 @@ if (isset($GLOBALS['_INC_PUBLIC'])) {
 
 	// Charger l'aiguilleur des traitements derogatoires
 	// (action en base SQL, formulaires CVT, AJax)
-	include_spip('public/aiguiller');
-	if (
-		// cas des appels actions ?action=xxx
-		traiter_appels_actions()
-	OR
-		// cas des hits ajax sur les inclusions ajax
-		traiter_appels_inclusions_ajax()
-	 OR 
-	 	// cas des formulaires charger/verifier/traiter
-	  traiter_formulaires_dynamiques())
-	  exit; // le hit est fini !
+	if (_request('action') OR _request('var_ajax') OR _request('formulaire_action')){
+		include_spip('public/aiguiller');
+		if (
+			// cas des appels actions ?action=xxx
+			traiter_appels_actions()
+		OR
+			// cas des hits ajax sur les inclusions ajax
+			traiter_appels_inclusions_ajax()
+		 OR
+			// cas des formulaires charger/verifier/traiter
+			traiter_formulaires_dynamiques())
+			exit; // le hit est fini !
+	}
 
 	// si signature de petition, l'enregistrer avant d'afficher la page
 	// afin que celle-ci contienne la signature
@@ -142,28 +145,36 @@ if (isset($GLOBALS['_INC_PUBLIC'])) {
 			$pos = strlen($page['texte']);
 		$page['texte'] = substr_replace($page['texte'], $x, $pos, 0);
 	}
-	// est-on admin ?
-	if ($affiche_boutons_admin = (
-	  (isset($_COOKIE['spip_admin'])
-	  OR
-		(isset($GLOBALS['visiteur_session']['id_auteur']) AND include_spip('inc/autoriser') AND autoriser('debug'))
-		OR
-		(defined('_DEBUG_ANONYME') AND _DEBUG_ANONYME)
-	)
-	AND !$flag_preserver
-	AND ($html OR ($var_mode == 'debug') OR count($tableau_des_erreurs))
-	))
+
+	// Tester si on est admin et il y a des choses supplementaires a dire
+	// type tableau pour y mettre des choses au besoin.
+	$debug = ((_request('var_mode') == 'debug') OR $tableau_des_temps) ? array(1) : array();
+
+	$affiche_boutons_admin = ($html AND ((
+		isset($_COOKIE['spip_admin'])
+		AND !$flag_preserver
+				   ) OR $debug));
+
+	if ($affiche_boutons_admin)
 		include_spip('balise/formulaire_admin');
 
+
+
+ 	// decomptage des visites, on peut forcer a oui ou non avec le header X-Spip-Visites
+ 	// par defaut on ne compte que les pages en html (ce qui exclue les js,css et flux rss)
+ 	$spip_compter_visites = $html?'oui':'non';
+ 	if (isset($page['entetes']['X-Spip-Visites'])){
+		$spip_compter_visites = in_array($page['entetes']['X-Spip-Visites'],array('oui','non'))?$page['entetes']['X-Spip-Visites']:$spip_compter_visites;
+		unset($page['entetes']['X-Spip-Visites']);
+ 	}
+
 	// Execution de la page calculee
 
-	// decomptage des visites, on peut forcer a oui ou non avec le header X-Spip-Visites
-	// par defaut on ne compte que les pages en html (ce qui exclue les js,css et flux rss)
-	$spip_compter_visites = $html?'oui':'non';
-	if (isset($page['entetes']['X-Spip-Visites'])){
-		$spip_compter_visites = in_array($page['entetes']['X-Spip-Visites'],array('oui','non'))?$page['entetes']['X-Spip-Visites']:$spip_compter_visites;
-		unset($page['entetes']['X-Spip-Visites']);
-	}
+
+	// traitements sur les entetes avant envoi
+	// peut servir pour le plugin de stats
+	$page['entetes'] = pipeline('affichage_entetes_final', $page['entetes']);
+
 
 	// 1. Cas d'une page contenant uniquement du HTML :
 	if ($page['process_ins'] == 'html') {
@@ -177,6 +188,12 @@ if (isset($GLOBALS['_INC_PUBLIC'])) {
 	else {
 		// sinon, inclure_balise_dynamique nous enverra peut-etre
 		// quelques en-tetes de plus (voire qq envoyes directement)
+
+		// restaurer l'etat des notes
+		if (isset($page['notes']) AND $page['notes']){
+			$notes = charger_fonction("notes","inc");
+			$notes($page['notes'],'restaurer_etat');
+		}
 		ob_start(); 
 		xml_hack($page, true);
 		$res = eval('?' . '>' . $page['texte']);
@@ -187,62 +204,63 @@ if (isset($GLOBALS['_INC_PUBLIC'])) {
 		envoyer_entetes($page['entetes']);
 		// en cas d'erreur lors du eval,
 		// la memoriser dans le tableau des erreurs
-		// On ne revient pas ici si le nb d'erreurs > 4
-		if ($res === false AND $affiche_boutons_admin) {
-			include_spip('public/debug');
-			erreur_squelette(_T('zbug_erreur_execution_page'));
-		}
 
+		if ($res === false) {
+			$msg = array('zbug_erreur_execution_page');
+			erreur_squelette($msg);
+		}
 	}
 
-	// Passer la main au debuggueur le cas echeant
-
-	if ($var_mode == 'debug') {
-		include_spip('public/debug');
-		$var_mode_affiche = _request('var_mode_affiche');
-		$var_mode_objet = _request('var_mode_objet');
-		debug_dumpfile($var_mode_affiche== 'validation' ? $page['texte'] :"",
-			       $var_mode_objet,$var_mode_affiche);
-	} 
-
-	if (count($tableau_des_erreurs) AND $affiche_boutons_admin)
-		$page['texte'] = affiche_erreurs_page($tableau_des_erreurs)
-			. $page['texte'];
-
 	//
-	// Post-traitements et affichage final
+	// Post-traitements
 	//
 	page_base_href($page['texte']);
 
-	// (c'est ici qu'on fait var_recherche, tidy, boutons d'admin,
+	// (c'est ici qu'on fait var_recherche, validation, boutons d'admin,
 	// cf. public/assembler.php)
 	echo pipeline('affichage_final', $page['texte']);
+	// l'affichage de la page a pu lever des erreurs (inclusion manquante)
+	// il faut tester a nouveau
+	$debug = ((_request('var_mode') == 'debug') OR $tableau_des_temps) ? array(1) : array();
 
-	if (count($tableau_des_temps) AND $affiche_boutons_admin) {
-		include_spip('public/debug');
-		echo chrono_requete($tableau_des_temps);
+	// Appel au debusqueur en cas d'erreurs ou de demande de trace
+	// at last
+	if ($debug) {
+		// en cas d'erreur, retester l'affichage
+		if ($html AND ($affiche_boutons_admin OR $debug)) {
+			$var_mode_affiche = _request('var_mode_affiche');
+			$GLOBALS['debug_objets'][$var_mode_affiche][$var_mode_objet . 'tout'] = ($var_mode_affiche== 'validation' ? $page['texte'] :"");
+			echo erreur_squelette(false);
+		}
+	} else {
+
+		if (isset($GLOBALS['meta']['date_prochain_postdate'])
+		AND $GLOBALS['meta']['date_prochain_postdate'] <= time()) {
+			include_spip('inc/rubriques');
+			calculer_prochain_postdate(true);
+		}
+
+		// Effectuer une tache de fond ?
+		// si #SPIP_CRON est present, on ne le tente que pour les navigateurs
+		// en mode texte (par exemple), et seulement sur les pages web
+		if (defined('_DIRECT_CRON_FORCE')
+			OR (
+			!defined('_DIRECT_CRON_INHIBE')
+			AND $html
+			AND !strstr($page['texte'], '<!-- SPIP-CRON -->')
+			AND !preg_match(',msie|mozilla|opera|konqueror,i', $_SERVER['HTTP_USER_AGENT']))
+			)
+			cron();
+
+		// sauver le cache chemin si necessaire
+		save_path_cache();
 	}
 
-	// Gestion des statistiques du site public
+ 	// Gestion des statistiques du site public
 	if (($GLOBALS['meta']["activer_statistiques"] != "non")
-	AND $spip_compter_visites!='non') {
-		$stats = charger_fonction('stats', 'public');
+	AND $spip_compter_visites!='non'
+	AND $stats = charger_fonction('stats', 'public', true))
 		$stats();
-	}
-
-	if (isset($GLOBALS['meta']['date_prochain_postdate'])
-	AND $GLOBALS['meta']['date_prochain_postdate'] <= time()) {
-		include_spip('inc/rubriques');
-		calculer_prochain_postdate(true);
-	}
-
-	// Effectuer une tache de fond ?
-	// si #SPIP_CRON est present, on ne le tente que pour les navigateurs
-	// en mode texte (par exemple), et seulement sur les pages web
-	if ($html
-	AND !strstr($page['texte'], '<!-- SPIP-CRON -->')
-	AND !preg_match(',msie|mozilla|opera|konqueror,i', $_SERVER['HTTP_USER_AGENT']))
-		cron();
 }
 
 ?>
