@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2009                                                *
+ *  Copyright (c) 2001-2010                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -25,14 +25,11 @@ function assembler($fond, $connect='') {
 	global $flag_preserver,$lastmodified, $use_cache, $contexte;
 
 	$contexte = calculer_contexte();
-
-	$page = $fond .
-		preg_replace(',\.[a-zA-Z0-9]*$,', '', 
-		preg_replace('/[?].*$/', '', $GLOBALS['REQUEST_URI']));
-
+	$page = array('contexte_implicite'=>calculer_contexte_implicite());
+	$page['contexte_implicite']['cache'] = $fond . preg_replace(',\.[a-zA-Z0-9]*$,', '', preg_replace('/[?].*$/', '', $GLOBALS['REQUEST_URI']));
 	// Cette fonction est utilisee deux fois
 	$cacher = charger_fonction('cacher', 'public');
-	// Les quatre derniers parametres sont modifes par la fonction:
+	// Les quatre derniers parametres sont modifies par la fonction:
 	// emplacement, validite, et, s'il est valide, contenu & age
 	$res = $cacher($GLOBALS['contexte'], $use_cache, $chemin_cache, $page, $lastmodified);
 	// Si un resultat est retourne, c'est un message d'impossibilite
@@ -73,10 +70,18 @@ function assembler($fond, $connect='') {
 		// Informer les boutons d'admin du contexte
 		// (fourni par $renommer ci-dessous lors de la mise en cache)
 			$contexte = $page['contexte'];
+
+			// vider les globales url propres qui ne doivent plus etre utilisees en cas
+			// d'inversion url => objet
+			unset($_SERVER['REDIRECT_url_propre']);
+			unset($_ENV['url_propre']);
 		}
 		// ATTENTION, gestion des URLs transformee par le htaccess
 		// $renommer = 'urls_propres_dist';
-		// renvoie array($contexte, $fond, $url_redirect)
+		// renvoie array($contexte, $type, $url_redirect, $nfond)
+		// $nfond n'est retourne que si l'url est definie apres le ?
+		// et risque d'etre effacee par un form en get
+		// elle est utilisee par form_hidden exclusivement
 		// Compat ascendante si le retour est null:
 		// 1. $contexte est global car cette fonction le modifie.
 		// 2. $fond est passe par reference, pour la meme raison
@@ -85,7 +90,7 @@ function assembler($fond, $connect='') {
 			$renommer = generer_url_entite();
 			if ($renommer) {
 				$url = nettoyer_uri();
-				$a = $renommer($url, $fond);
+				$a = $renommer($url, $fond, $contexte);
 				if (is_array($a)) {
 					list($ncontexte, $type, $url_redirect, $nfond) = $a;
 					if (strlen($url_redirect)
@@ -103,27 +108,29 @@ function assembler($fond, $connect='') {
 						$fond = ($type === 'syndic') ? 'site' : $type;
 					if (isset($ncontexte))
 						$contexte = $ncontexte;
+					if (defined('_DEFINIR_CONTEXTE_TYPE') AND _DEFINIR_CONTEXTE_TYPE)
+						$contexte['type'] = ($type === 'syndic') ? 'site' : $type;
 				}
 			}
 			// compatibilite <= 1.9.2
 			elseif (function_exists('recuperer_parametres_url'))
 				recuperer_parametres_url($fond, nettoyer_uri());
 
+			// vider les globales url propres qui ne doivent plus etre utilisees en cas
+			// d'inversion url => objet
+			unset($_SERVER['REDIRECT_url_propre']);
+			unset($_ENV['url_propre']);
 
 			// squelette par defaut
 			if (!strlen($fond))
 				$fond = 'sommaire';
 
-			// preparer le contexte
-			$parametrer = charger_fonction('parametrer', 'public');
-			$page = $parametrer($fond, $GLOBALS['contexte'], $chemin_cache, $connect);
-
-			// Stocker le cache sur le disque
-			if ($chemin_cache)
-				$cacher(NULL, $use_cache, $chemin_cache, $page, $lastmodified);
+			// produire la page : peut mettre a jour $lastmodified
+			$produire_page = charger_fonction('produire_page','public');
+			$page = $produire_page($fond, $GLOBALS['contexte'], $use_cache, $chemin_cache, NULL, $page, $lastmodified, $connect);
 		}
 
-		if ($chemin_cache) $page['cache'] = $chemin_cache;
+		if ($page AND $chemin_cache) $page['cache'] = $chemin_cache;
 
 		auto_content_type($page);
 
@@ -137,7 +144,18 @@ function assembler($fond, $connect='') {
 				AND $GLOBALS['var_mode'] != 'debug'
 				AND !isset($page['entetes']['Location']) // cette page realise une redirection, donc pas d'erreur
 				) {
-					$page = message_erreur_404();
+					// passer le type d'objet recherche au contexte de la page d'erreur
+					$contexte['type'] = (isset($type)?$type:$fond);
+				  $page = message_page_indisponible($page, $contexte);
+					// cacher la page d'erreur car celle ci est contextuelle
+					if ($chemin_cache
+					AND is_array($page)
+					AND count($page)
+					AND $page['entetes']['X-Spip-Cache'] > 0){
+						$cacher = charger_fonction('cacher', 'public');
+						$lastinclude = time();
+						$cacher($contexte_cache, $use_cache, $chemin_cache, $page, $lastinclude);
+					}
 				}
 				// pas de cache client en mode 'observation'
 				if ($GLOBALS['var_mode']) {
@@ -182,8 +200,28 @@ function calculer_contexte() {
 	return $contexte;
 }
 
+/**
+ * Calculer le contexte implicite, qui n'apparait pas dans le ENV d'un cache
+ * mais est utilise pour distinguer deux caches differents
+ *
+ * @staticvar string $notes
+ * @return array
+ */
+function calculer_contexte_implicite(){
+	static $notes = null;
+	if (is_null($notes))
+		$notes = charger_fonction('notes','inc');
+	$contexte_implicite = array(
+		'squelettes' => $GLOBALS['dossier_squelettes'], // devrait etre 'chemin' => $GLOBALS['path_sig'], ?
+		'host' => $_SERVER['HTTP_HOST'],
+		'marqueur' => (isset($GLOBALS['marqueur']) ?  $GLOBALS['marqueur'] : ''),
+		'notes' => $notes('','contexter_cache'),
+	);
+	return $contexte_implicite;
+}
+
 //
-// 2 fonctions pour compatibilite arriere. Sont probablement superflues
+// fonction pour compatibilite arriere, probablement superflue
 //
 
 // http://doc.spip.org/@auto_content_type
@@ -192,7 +230,7 @@ function auto_content_type($page)
 	global $flag_preserver;
 	if (!isset($flag_preserver))
 	  {
-		$flag_preserver = preg_match("/header\s*\(\s*.content\-type:/isx",$page['texte']) || (isset($page['entetes']['Content-Type']));
+	    $flag_preserver = ($page && preg_match("/header\s*\(\s*.content\-type:/isx",$page['texte']) || (isset($page['entetes']['Content-Type'])));
 	  }
 }
 
@@ -203,39 +241,89 @@ function inclure_page($fond, $contexte, $connect='') {
 
 	// enlever le fond de contexte inclus car sinon il prend la main
 	// dans les sous inclusions -> boucle infinie d'inclusion identique
+	// (cette precaution n'est probablement plus utile)
 	unset($contexte['fond']);
-	// mais le donner pour le calcul du cache
-	$page = $fond; 
+	$page = array('contexte_implicite'=>calculer_contexte_implicite());
+	$page['contexte_implicite']['cache'] = $fond;
 	$cacher = charger_fonction('cacher', 'public');
-	// Les quatre derniers parametres sont modifes par la fonction:
+	// Les quatre derniers parametres sont modifies par la fonction:
 	// emplacement, validite, et, s'il est valide, contenu & age
 	$res = $cacher($contexte, $use_cache, $chemin_cache, $page, $lastinclude);
+	// $res = message d'erreur : on sort de la
 	if ($res) {return array('texte' => $res);}
 
-	// Si use_cache vaut 0, la page a ete tiree du cache et se trouve dans $page
-	if (!$use_cache) {
-		$lastmodified = max($lastmodified, $lastinclude);
-	} else {
-		$parametrer = charger_fonction('parametrer', 'public');
-		$page = $parametrer($fond, $contexte, $chemin_cache, $connect);
-		$lastmodified = time();
-		// et on l'enregistre sur le disque
-		if ($chemin_cache
-		AND $page['entetes']['X-Spip-Cache'] > 0)
-			$cacher($contexte, $use_cache, $chemin_cache, $page,
-				$lastmodified);
+	// Si use_cache ne vaut pas 0, la page doit etre calculee
+	// produire la page : peut mettre a jour $lastinclude
+	// le contexte_cache envoye a cacher() a ete conserve et est passe a produire
+	if ($use_cache) {
+		$produire_page = charger_fonction('produire_page','public');
+		$page = $produire_page($fond, $contexte, $use_cache, $chemin_cache, $contexte, $page, $lastinclude, $connect);
 	}
+	// dans tous les cas, mettre a jour $lastmodified
+	$lastmodified = max($lastmodified, $lastinclude);
 
 	return $page;
 }
 
-# Attention, un appel explicite a cette fonction suppose certains include
-# $echo = faut-il faire echo ou return
+/**
+ * Produire la page et la mettre en cache
+ * lorsque c'est necessaire
+ *
+ * @param string $fond
+ * @param array $contexte
+ * @param int $use_cache
+ * @param string $chemin_cache
+ * @param array $contexte_cache
+ * @param array $page
+ * @param int $lastinclude
+ * @param string $connect
+ * @return array
+ */
+function public_produire_page_dist($fond, $contexte, $use_cache, $chemin_cache, $contexte_cache, &$page, &$lastinclude, $connect=''){
+	#var_dump($page);
+	$parametrer = charger_fonction('parametrer', 'public');
+	$page = $parametrer($fond, $contexte, $chemin_cache, $connect);
+	// et on l'enregistre sur le disque
+	if ($chemin_cache
+	AND $use_cache>-1
+	AND is_array($page)
+	AND count($page)
+	AND $page['entetes']['X-Spip-Cache'] > 0){
+		$cacher = charger_fonction('cacher', 'public');
+		$lastinclude = time();
+		$cacher($contexte_cache, $use_cache, $chemin_cache, $page, $lastinclude);
+	}
+	return $page;
+}
+
+
+// Fonction inseree par le compilateur dans le code compile.
+// Elle recoit un contexte pour inclure un squelette, 
+// et les valeurs du contexte de compil prepare par memoriser_contexte_compil
+// elle-meme appelee par calculer_balise_dynamique dans references.php:
+// 0: sourcefile
+// 1: codefile
+// 2: id_boucle
+// 3: ligne
+// 4: langue
+
+function inserer_balise_dynamique($contexte_exec, $contexte_compil)
+{
+	if (!is_array($contexte_exec))
+		echo $contexte_exec; // message d'erreur etc
+	else {
+		if ($contexte_compil[4] AND empty($contexte_exec[2]['lang']))
+			$contexte_exec[2]['lang'] = $contexte_compil[4];
+		inclure_balise_dynamique($contexte_exec, true, $contexte_compil);
+	}
+}
+
+// Attention, un appel explicite a cette fonction suppose certains include
+// $echo = faut-il faire echo ou return
 
 // http://doc.spip.org/@inclure_balise_dynamique
-function inclure_balise_dynamique($texte, $echo=true, $ligne=0) {
-	global $contexte_inclus; # provisoire : c'est pour le debuggueur
-
+function inclure_balise_dynamique($texte, $echo=true, $contexte_compil=array())
+{
 	if (is_array($texte)) {
 
 		list($fond, $delainc, $contexte_inclus) = $texte;
@@ -244,15 +332,10 @@ function inclure_balise_dynamique($texte, $echo=true, $ligne=0) {
 		$d = isset($GLOBALS['delais']) ? $GLOBALS['delais'] : NULL;
 		$GLOBALS['delais'] = $delainc;
 
-		// les balises dynamiques passent toujours leur $fond
-		// si un 'fond' est present dans le contexte il vient d'autre part (de la bdd par exemple:p)
-		// et c'est le crash assure
-		$contexte_inclus['fond'] = $fond;
-		$page = recuperer_fond($fond,$contexte_inclus,array('trim'=>false, 'raw' => true));
+		$page = recuperer_fond($fond,$contexte_inclus,array('trim'=>false, 'raw' => true, 'compil' => $contexte_compil));
 
 		$texte = $page['texte'];
 
-		// attention $contexte_inclus a pu changer pendant l'eval ci dessus
 		$GLOBALS['delais'] = $d;
 		// Faire remonter les entetes
 		if (is_array($page['entetes'])) {
@@ -279,9 +362,11 @@ function inclure_balise_dynamique($texte, $echo=true, $ligne=0) {
 		}
 	}
 
-	if ($GLOBALS['var_mode'] == 'debug')
+	if ($GLOBALS['var_mode'] == 'debug') {
+		// compatibilite : avant on donnait le numero de ligne ou rien.
+		$ligne =  intval(isset($contexte_compil[3]) ? $contexte_compil[3] : $contexte_compil);
 		$GLOBALS['debug_objets']['resultat'][$ligne] = $texte;
-
+	}
 	if ($echo)
 		echo $texte;
 	else
@@ -292,12 +377,11 @@ function inclure_balise_dynamique($texte, $echo=true, $ligne=0) {
 // Traiter var_recherche ou le referrer pour surligner les mots
 // http://doc.spip.org/@f_surligne
 function f_surligne ($texte) {
-	if ($GLOBALS['html']
-	AND (isset($_SERVER['HTTP_REFERER']) OR isset($_GET['var_recherche']))) {
-		include_spip('inc/surligne');
-		$texte = surligner_mots($texte);
-	}
-	return $texte;
+	if (!$GLOBALS['html']) return $texte;
+	$rech = _request('var_recherche');
+	if (!$rech AND !isset($_SERVER['HTTP_REFERER'])) return $texte;
+	include_spip('inc/surligne');
+	return surligner_mots($texte, $rech);
 }
 
 // Valider/indenter a la demande.
@@ -355,60 +439,41 @@ function f_admin ($texte) {
 	return $texte;
 }
 
-// Ajoute ce qu'il faut pour les clients MSIE et leurs debilites notoires
-// * gestion du PNG transparent
-// * images background (TODO)
-// Cf. aussi inc/presentation, fonction fin_page();
-// http://doc.spip.org/@f_msie
-function f_msie ($texte) {
-	if (!$GLOBALS['html']) return $texte;
-	if ($GLOBALS['flag_preserver']) return $texte;
-	
-	// test si MSIE et sinon quitte
-	if (
-		strpos(strtolower($_SERVER['HTTP_USER_AGENT']), 'msie')
-		AND preg_match('/MSIE /i', $_SERVER['HTTP_USER_AGENT'])
-		AND $msiefix = charger_fonction('msiefix', 'inc')
-	)
-		return $msiefix($texte);
-	else
-		return $texte;
-}
 
-
-// http://doc.spip.org/@message_erreur_404
-function message_erreur_404 ($erreur= "") {
+// http://doc.spip.org/@message_page_indisponible
+function message_page_indisponible ($page, $contexte) {
 	static $deja = false;
 	if ($deja) return "erreur";
-	$deja = true;
-	if (!$erreur) {
-		if (isset($GLOBALS['id_article']))
-		$erreur = 'public:aucun_article';
-		else if (isset($GLOBALS['id_rubrique']))
-		$erreur = 'public:aucune_rubrique';
-		else if (isset($GLOBALS['id_breve']))
-		$erreur = 'public:aucune_breve';
-		else if (isset($GLOBALS['id_auteur']))
-		$erreur = 'public:aucun_auteur';
-		else if (isset($GLOBALS['id_syndic']))
-		$erreur = 'public:aucun_site';
-	}
-	$contexte_inclus = array(
-		'erreur' => _T($erreur),
-		'lang' => $GLOBALS['spip_lang']
+	$codes = array(
+		'404' => '404 Not Found',
+		'503' => '503 Service Unavailable',
 	);
-	$page = inclure_page('404', $contexte_inclus);
-	$page['status'] = 404;
+
+	$contexte['status'] = ($page !== false) ? '404' : '503';
+	$contexte['code'] = $codes[$contexte['status']];
+	$contexte['fond'] = '404'; // gere les 2 erreurs
+	$contexte['erreur'] = _T($erreur);
+	if (!isset($contexte['lang']))
+		$contexte['lang'] = $GLOBALS['spip_lang'];
+
+	$deja = true;
+	// passer aux plugins qui peuvent decider d'une page d'erreur plus pertinent
+	// ex restriction d'acces => 401
+	$contexte = pipeline('page_indisponible',$contexte);
+
+	// produire la page d'erreur
+	$page = inclure_page($contexte['fond'], $contexte);
+	if (!$page)
+		$page = inclure_page('404', $contexte);
+	$page['status'] = $contexte['status'];
 	return $page;
 }
 
-
 // temporairement ici : a mettre dans le futur inc/modeles
 // creer_contexte_de_modele('left', 'autostart=true', ...) renvoie un array()
 // http://doc.spip.org/@creer_contexte_de_modele
 function creer_contexte_de_modele($args) {
 	$contexte = array();
-	$params = array();
 	foreach ($args as $var=>$val) {
 		if (is_int($var)){ // argument pas formate
 			if (in_array($val, array('left', 'right', 'center'))) {
@@ -451,8 +516,7 @@ function inclure_modele($type, $id, $params, $lien, $connect='') {
 		}
 
 		if (preg_match(',^[a-z0-9_]+$,', $soustype)) {
-			$fond = $type.'_'.$soustype;
-			if (!find_in_path('modeles/'. $fond.'.html')) {
+			if (!trouve_modele($fond = ($type.'_'.$soustype))) {
 				$fond = '';
 				$class = $soustype;
 			}
@@ -460,14 +524,13 @@ function inclure_modele($type, $id, $params, $lien, $connect='') {
 			$params = array_diff($params,array($soustype));
 		}
 	}
-	// Si ca marche pas en precisant le sous-type, prendre le type
-	if (!$fond AND !find_in_path('modeles/'. ($fond = $type).'.html'))
-		return false;
 
+	// Si ca marche pas en precisant le sous-type, prendre le type
+	if (!$fond AND !trouve_modele($fond = $type))
+		return false;
+	$fond = 'modeles/'.$fond;
 	// Creer le contexte
 	$contexte = array( 
-		'lang' => $GLOBALS['spip_lang'], 
-		'fond' => 'modeles/'.$fond,
 		'dir_racine' => _DIR_RACINE # eviter de mixer un cache racine et un cache ecrire (meme si pour l'instant les modeles ne sont pas caches, le resultat etant different il faut que le contexte en tienne compte 
 	); 
 	// Le numero du modele est mis dans l'environnement
@@ -496,26 +559,10 @@ function inclure_modele($type, $id, $params, $lien, $connect='') {
 	$contexte['args'] = $arg_list; // on passe la liste des arguments du modeles dans une variable args
 	$contexte = array_merge($contexte,$arg_list);
 
-	// On cree un marqueur de notes unique lie a ce modele
-	// et on enregistre l'etat courant des globales de notes...
-	$enregistre_marqueur_notes = $GLOBALS['marqueur_notes'];
-	$enregistre_les_notes = $GLOBALS['les_notes'];
-	$enregistre_compt_note = $GLOBALS['compt_note'];
-	$GLOBALS['marqueur_notes'] = substr(md5(serialize($contexte)),0,8);
-	$GLOBALS['les_notes'] = '';
-	$GLOBALS['compt_note'] = 0;
 
 	// Appliquer le modele avec le contexte
-	$retour = recuperer_fond($fond, $contexte);
+	$retour = recuperer_fond($fond, $contexte, array(), $connect);
 
-	// On restitue les globales de notes telles qu'elles etaient avant l'appel
-	// du modele. Si le modele n'a pas affiche ses notes, tant pis (elles *doivent*
-	// etre dans le cache du modele, autrement elles ne seraient pas prises en
-	// compte a chaque calcul d'un texte contenant un modele, mais seulement
-	// quand le modele serait calcule, et on aurait des resultats incoherents)
-	$GLOBALS['les_notes'] = $enregistre_les_notes;
-	$GLOBALS['marqueur_notes'] = $enregistre_marqueur_notes;
-	$GLOBALS['compt_note'] = $enregistre_compt_note;
 
 	// Regarder si le modele tient compte des liens (il *doit* alors indiquer
 	// spip_lien_ok dans les classes de son conteneur de premier niveau ;
@@ -541,13 +588,17 @@ function inclure_modele($type, $id, $params, $lien, $connect='') {
 // http://doc.spip.org/@evaluer_fond
 function evaluer_fond ($fond, $contexte=array(), $connect=null) {
 
-	if (isset($contexte['fond'])
-	AND $fond === '')
-		$fond = $contexte['fond'];
-
 	$page = inclure_page($fond, $contexte, $connect);
 
-	if ($GLOBALS['flag_ob'] AND ($page['process_ins'] != 'html')) {
+	if (!$page) return $page;
+
+	if ($page['process_ins'] != 'html') {
+		// restaurer l'etat des notes
+		if (isset($page['notes']) AND $page['notes']){
+			$notes = charger_fonction("notes","inc");
+			$notes($page['notes'],'restaurer_etat');
+		}
+
 		ob_start();
 		xml_hack($page, true);
 		eval('?' . '>' . $page['texte']);
@@ -592,9 +643,10 @@ function page_base_href(&$texte){
 			AND !_request('action'));
 
 	if (_SET_HTML_BASE
-	AND $GLOBALS['html']
-	AND $GLOBALS['profondeur_url']>0){
-		list($head, $body) = explode('</head>', $texte, 1);
+	AND isset($GLOBALS['html']) AND $GLOBALS['html']
+	AND $GLOBALS['profondeur_url']>0
+	AND ($poshead = strpos($texte,'</head>'))!==FALSE){
+		$head = substr($texte,0,$poshead);
 		$insert = false;
 		if (strpos($head, '<base')===false) 
 			$insert = true;
@@ -613,7 +665,7 @@ function page_base_href(&$texte){
 			$base = url_absolue('./');
 			if (($pos = strpos($head, '<head>')) !== false)
 				$head = substr_replace($head, "\n<base href=\"$base\" />", $pos+6, 0);
-			$texte = $head . (isset($body) ? '</head>'.$body : '');
+			$texte = $head . substr($texte,$poshead);
 			// gerer les ancres
 			$base = $_SERVER['REQUEST_URI'];
 			if (strpos($texte,"href='#")!==false)
