@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2009                                                *
+ *  Copyright (c) 2001-2010                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -166,8 +166,8 @@ function boucle_DOCUMENTS_dist($id_boucle, &$boucles) {
 	array_unshift($boucle->where,array("'($id_table.taille > 0 OR $id_table.distant=\\'oui\\')'"));
 
 	// Supprimer les vignettes
-	if (!$boucle->modificateur['criteres']['mode']
-	AND !$boucle->modificateur['criteres']['tout']) {
+	if (!isset($boucle->modificateur['criteres']['mode'])
+	AND !isset($boucle->modificateur['criteres']['tout'])) {
 		array_unshift($boucle->where,array("'!='", "'$id_table.mode'", "'\\'vignette\\''"));
 	}
 
@@ -177,8 +177,8 @@ function boucle_DOCUMENTS_dist($id_boucle, &$boucles) {
 	// S'il y a un critere de lien {id_article} par exemple, on zappe
 	// ces complications (et tant pis si la boucle n'a pas prevu de
 	// verification du statut de l'article)
-	if (!$boucle->modificateur['tout']
-	AND !$boucle->modificateur['criteres']['id_objet']
+	if ((!isset($boucle->modificateur['tout']) OR !$boucle->modificateur['tout'])
+	AND (!isset($boucle->modificateur['criteres']['id_objet']) OR !$boucle->modificateur['criteres']['id_objet'])
 	) {
 		# Espace avant LEFT JOIN indispensable pour insertion de AS
 		# a refaire plus proprement
@@ -196,7 +196,7 @@ function boucle_DOCUMENTS_dist($id_boucle, &$boucles) {
 				ON (l.id_objet=ff.id_forum AND l.objet=\'forum\')
 		";
 		$boucle->group[] = "$id_table.id_document";
-		
+
 		if ($GLOBALS['var_preview']) {
 			array_unshift($boucle->where,"'(aa.statut IN (\'publie\',\'prop\') OR bb.statut  IN (\'publie\',\'prop\') OR rr.statut IN (\'publie\',\'prive\') OR ff.statut IN (\'publie\',\'prop\'))'");
 		} else {
@@ -257,7 +257,7 @@ function boucle_HIERARCHIE_dist($id_boucle, &$boucles) {
 	$boucle->where[]= array("'IN'", "'$id_table'", '"($hierarchie)"');
 
         $order = "FIELD($id_table, \$hierarchie)";
-	if ($boucle->default_order[0] != " DESC")
+	if (!isset($boucle->default_order[0]) OR $boucle->default_order[0] != " DESC")
 		$boucle->default_order[] = "\"$order\"";
 	else
 		$boucle->default_order[0] = "\"$order DESC\"";
@@ -295,7 +295,7 @@ function boucle_SYNDIC_ARTICLES_dist($id_boucle, &$boucles) {
 	$mstatut = $id_table .'.statut';
 
 	// Restreindre aux elements publies, sauf critere contraire
-	if ($boucle->modificateur['criteres']['statut']) {}
+	if (isset($boucle->modificateur['criteres']['statut']) AND $boucle->modificateur['criteres']['statut']) {}
 	else if ($GLOBALS['var_preview'])
 		array_unshift($boucle->where,array("'IN'", "'$mstatut'", "'(\\'publie\\',\\'prop\\')'"));
 	else {
