@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2009                                                *
+ *  Copyright (c) 2001-2010                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -20,7 +20,8 @@ if (!defined("_ECRIRE_INC_VERSION")) return;
 // http://doc.spip.org/@generer_nom_fichier_cache
 function generer_nom_fichier_cache($contexte, $page) {
 
-	$cache = $page . '-';
+	$cache = $page['contexte_implicite']['cache'] . '-';
+
 	foreach ($contexte as $var=>$val) {
 		$val = is_array($val) ? var_export($val,true) : strval($val);
 		$cache .= str_replace('-', '_', $val) . '-' ;
@@ -38,11 +39,9 @@ function generer_nom_fichier_cache($contexte, $page) {
 	// donc, par exemple, de gerer differents dossiers de squelettes
 	// en parallele, ou de la "personnalisation" via un marqueur (dont la
 	// composition est totalement libre...)
-	$md_cache = md5($page . ' '
+	$md_cache = md5(
+		var_export($page['contexte_implicite'],true) . ' '
 		. var_export($contexte,true)
-		. $_SERVER['HTTP_HOST'] . ' '
-		. $GLOBALS['dossier_squelettes'] . ' '
-		. (isset($GLOBALS['marqueur']) ?  $GLOBALS['marqueur'] : '')
 	);
 
 	$cache .= '-'.substr($md_cache, 1, 32-strlen($cache));
@@ -50,10 +49,7 @@ function generer_nom_fichier_cache($contexte, $page) {
 	// Sous-repertoires 0...9a..f ; ne pas prendre la base _DIR_CACHE
 	$rep = _DIR_CACHE;
 
-	if(!@file_exists($rep)) {
-		$rep = preg_replace(','._DIR_TMP.',', '', $rep);
-		$rep = sous_repertoire(_DIR_TMP, $rep, false,true);
-	}
+	$rep = sous_repertoire($rep, '', false,true);
 	$subdir = sous_repertoire($rep, substr($md_cache, 0, 1), true,true);
 	return $subdir.$cache;
 }
@@ -76,8 +72,10 @@ function gzip_page($page) {
 // (passage par reference pour alleger)
 // http://doc.spip.org/@gunzip_page
 function gunzip_page(&$page) {
-	if ($page['gz'])
+	if ($page['gz']) {
 		$page['texte'] = gzuncompress($page['texte']);
+		$page['gz'] = false; // ne pas gzuncompress deux fois une meme page
+	}
 }
 
 /**
@@ -97,15 +95,17 @@ function gunzip_page(&$page) {
 function cache_valide(&$page, $date) {
 
 	if (isset($GLOBALS['var_nocache']) AND $GLOBALS['var_nocache']) return -1;
-	if (defined('_NO_CACHE')) return (_NO_CACHE==0 AND !$page)?1:_NO_CACHE;
-	if (!$page) return 1;
+	if (defined('_NO_CACHE')) return (_NO_CACHE==0 AND !isset($page['texte']))?1:_NO_CACHE;
+	if (!$page OR !isset($page['texte']) OR !isset($page['entetes']['X-Spip-Cache'])) return 1;
 
 	// #CACHE{n,statique} => on n'invalide pas avec derniere_modif
 	// cf. ecrire/public/balises.php, balise_CACHE_dist()
 	if (!isset($page['entetes']['X-Spip-Statique']) OR $page['entetes']['X-Spip-Statique'] !== 'oui') {
 
 		// Cache invalide par la meta 'derniere_modif'
-		if ($GLOBALS['derniere_modif_invalide']
+		// sauf pour les bots, qui utilisent toujours le cache
+		if (!_IS_BOT
+		AND $GLOBALS['derniere_modif_invalide']
 		AND $date < $GLOBALS['meta']['derniere_modif'])
 			return 1;
 
@@ -132,22 +132,52 @@ function cache_valide(&$page, $date) {
 		return 0;
 }
 
+function cache_sessionne($chemin_cache, $session, $creer=false) {
+	$fs = substr(md5($chemin_cache),0,8);
+	$a = substr($fs,0,1);
+	$b = sous_repertoire(_DIR_CACHE, $a);
+	// si la session n'est pas anonyme, creer un sous dossier
+	// car spip est susceptible de generer auant de caches que de visiteur identifie
+	if ($session){
+		if ($creer)
+			sous_repertoire($b, $fs);
+		return $a.'/'.$fs.'/_'.$session;
+	}
+	// sinon un simple fichier suffixe par _anonyme
+	else {
+		return $a.'/'.$fs.'_anonyme';
+	}
+}
 
 // Creer le fichier cache
 # Passage par reference de $page par souci d'economie
 // http://doc.spip.org/@creer_cache
 function creer_cache(&$page, &$chemin_cache) {
 
+	// Ne rien faire si on est en preview, debug, ou si une erreur
+	// grave s'est presentee (compilation du squelette, MySQL, etc)
+	// le cas var_nocache ne devrait jamais arriver ici (securite)
+	// le cas spip_interdire_cache correspond a une ereur SQL grave non anticipable
+	if ((isset($GLOBALS['var_nocache']) AND $GLOBALS['var_nocache'])
+		OR defined('spip_interdire_cache'))
+		return;
+
 	// Si la page c1234 a un invalideur de session 'zz', sauver dans
-	// 'tmp/cache/a/c1234-zz.gz'
+	// 'tmp/cache/MD5(chemin_cache)/_zz'
 	// en prenant soin de supprimer un eventuel cache non-sessionne
 	// si l'ajout de #SESSION dans le squelette est recent
 	if (isset($page['invalideurs'])
 	AND isset($page['invalideurs']['session'])) {
 		supprimer_fichier(_DIR_CACHE . $chemin_cache);
-		$chemin_cache .= '-'.$page['invalideurs']['session'];
+		$chemin_cache = cache_sessionne($chemin_cache,$page['invalideurs']['session'], true);
+		
 	}
 
+	// ajouter la date de production dans le cache lui meme
+	// (qui contient deja sa duree de validite)
+	$page['lastmodified'] = time();
+
+
 	// l'enregistrer, compresse ou non...
 	$ok = ecrire_fichier(_DIR_CACHE . $chemin_cache,
 		serialize(gzip_page($page)));
@@ -163,7 +193,7 @@ function creer_cache(&$page, &$chemin_cache) {
 
 
 // purger un petit cache (tidy ou recherche) qui ne doit pas contenir de
-// vieux fichiers
+// vieux fichiers ; (cette fonction ne sert que dans des plugins obsoletes)
 // http://doc.spip.org/@nettoyer_petit_cache
 function nettoyer_petit_cache($prefix, $duree = 300) {
 	// determiner le repertoire a purger : 'tmp/CACHE/rech/'
@@ -199,9 +229,11 @@ function public_cacher_dist($contexte, &$use_cache, &$chemin_cache, &$page, &$la
 
 	// Toute la suite correspond au premier appel
 
+	$contexte_implicite = $page['contexte_implicite'];
+
 	// Cas ignorant le cache car completement dynamique
 	if ($_SERVER['REQUEST_METHOD'] == 'POST'
-	OR (substr($page,0,8)=='modeles/') 
+	OR (substr($contexte_implicite['cache'],0,8)=='modeles/') 
 	OR (_request('connect'))
 // Mode auteur authentifie appelant de ecrire/ : il ne faut rien lire du cache
 // et n'y ecrire que la compilation des squelettes (pas les pages produites)
@@ -215,20 +247,16 @@ function public_cacher_dist($contexte, &$use_cache, &$chemin_cache, &$page, &$la
 	}
 
 	// Controler l'existence d'un cache nous correspondant, dans les
-	// quatre versions possibles : gzip ou non, session ou non
+	// deux versions possibles : session ou non
 	$chemin_cache = generer_nom_fichier_cache($contexte, $page);
-
-	if (@file_exists(_DIR_CACHE . ($f = $g = $chemin_cache))
-	OR (@file_exists(_DIR_CACHE . ($f = $chemin_cache.'-'.spip_session())))
-	) {
-		$lastmodified = @filemtime(_DIR_CACHE . $f);
-	} else
-		$lastmodified = 0;
+	$lastmodified = 0;
+	if (!lire_fichier(_DIR_CACHE . ($f = $chemin_cache), $page))
+		$fs = lire_fichier(_DIR_CACHE . ($f = cache_sessionne($f, spip_session())), $page);
 
 	// HEAD : cas sans jamais de calcul pour raisons de performance
 	if ($_SERVER['REQUEST_METHOD'] == 'HEAD') {
 		$use_cache = 0;
-		$page = array();
+		$page = array('contexte_implicite'=>$contexte_implicite);
 		return;
 	}
 
@@ -248,9 +276,13 @@ function public_cacher_dist($contexte, &$use_cache, &$chemin_cache, &$page, &$la
 		|| isset($_COOKIE['spip_admin'])
 		|| @file_exists(_ACCESS_FILE_NAME))
 	) {
-		supprimer_fichier(_DIR_CACHE . $f);
-		if (in_array($GLOBALS['var_mode'], array('calcul', 'recalcul')))
-			array_map('supprimer_fichier', preg_files(_DIR_CACHE . $g));
+		$page = array('contexte_implicite'=>$contexte_implicite); // ignorer le cache deja lu
+		supprimer_fichier(_DIR_CACHE . $f); // pas necessaire ?
+		if (in_array($GLOBALS['var_mode'], array('calcul', 'recalcul'))
+		AND $fs) {
+			include_spip('inc/invalideur');
+			purger_repertoire(dirname(_DIR_CACHE.$f));
+		}
 	}
 
 	// $delais par defaut (pour toutes les pages sans #CACHE{})
@@ -259,24 +291,26 @@ function public_cacher_dist($contexte, &$use_cache, &$chemin_cache, &$page, &$la
 		$GLOBALS['delais'] = _DUREE_CACHE_DEFAUT;
 	}
 
-	// Lire le fichier cache et determiner sa validite
-	if ($lastmodified
-	AND lire_fichier(_DIR_CACHE . $f, $page)) {
-		$page = @unserialize($page);
-		$use_cache = cache_valide($page, $lastmodified);
+	// decoder le cache et determiner sa validite
+	if ($page AND
+		$page = @unserialize($page)) {
+		$use_cache = cache_valide($page, $page['lastmodified']);
+		// le contexte implicite n'est pas stocke dans le cache, mais il y a equivalence
+		// par le nom du cache. On le reinjecte donc ici pour utilisation eventuelle au calcul
+		$page['contexte_implicite'] = $contexte_implicite;
 		if (!$use_cache) {
 			// $page est un cache utilisable
 			gunzip_page($page);
 			return;
 		}
 	} else {
-		$page = array();
+		$page = array('contexte_implicite'=>$contexte_implicite);
 		$use_cache = cache_valide($page,0); // fichier cache absent : provoque le calcul
 	}
 
 	// Si pas valide mais pas de connexion a la base, le garder quand meme
 	if (!spip_connect()) {
-		if ($lastmodified)
+		if (isset($page['texte']))
 			$use_cache = 0;
 		else {
 			spip_log("Erreur base de donnees, impossible utiliser $chemin_cache");
