@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2009                                                *
+ *  Copyright (c) 2001-2010                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -14,6 +14,12 @@
 // Definition des {criteres} d'une boucle
 //
 
+// Une Regexp reperant une chaine produite par le compilateur,
+// souvent utilisee pour faire de la concatenation lors de la compilation
+// plutot qu'a l'execution, i.e. pour remplacer 'x'.'y' par 'xy'
+
+define('_CODE_QUOTE', ",^(\n//[^\n]*\n)? *'(.*)' *$,");
+
 if (!defined("_ECRIRE_INC_VERSION")) return;
 
 // {racine}
@@ -28,7 +34,7 @@ function critere_racine_dist($idb, &$boucles, $crit) {
 		'id_parent';
 
 	if ($not)
-		erreur_squelette(_T('zbug_info_erreur_squelette'), $crit->op);
+		return (array('zbug_critere_inconnu', array('critere' => $not . $crit->op)));
 
 	$boucle->where[]= array("'='", "'$boucle->id_table." . "$id_parent'", 0);
 }
@@ -37,14 +43,12 @@ function critere_racine_dist($idb, &$boucles, $crit) {
 // http://www.spip.net/@exclus
 // http://doc.spip.org/@critere_exclus_dist
 function critere_exclus_dist($idb, &$boucles, $crit) {
-	$param = $crit->op;
 	$not = $crit->not;
 	$boucle = &$boucles[$idb];
 	$id = $boucle->primary;
 
 	if ($not OR !$id)
-		erreur_squelette(_T('zbug_info_erreur_squelette'), $param);
-
+		return (array('zbug_critere_inconnu', array('critere' => $not . $crit->op)));
 	$arg = kwote(calculer_argument_precedent($idb, $id, $boucles));
 	$boucle->where[]= array("'!='", "'$boucle->id_table." . "$id'", $arg);
 }
@@ -58,8 +62,7 @@ function critere_doublons_dist($idb, &$boucles, $crit) {
 	$primary = $boucle->primary;
 
 	if (!$primary OR strpos($primary,',')) {
-		erreur_squelette(_T('zbug_doublon_sur_table_sans_cle_primaire'), "BOUCLE$idb");
-		return;
+		return (array('zbug_doublon_sur_table_sans_cle_primaire'));
 	}
 
 	$not = ($crit->not ? '' : 'NOT');
@@ -123,7 +126,7 @@ function critere_debut_dist($idb, &$boucles, $crit) {
 		  '"]) . ",' .
 		  $deux .
 		  '"' ;
-	} else calculer_critere_DEFAUT($idb, $boucles, $crit);
+	} else calculer_critere_DEFAUT_dist($idb, $boucles, $crit);
 }
 
 // {pagination}
@@ -134,23 +137,47 @@ function critere_debut_dist($idb, &$boucles, $crit) {
 // http://doc.spip.org/@critere_pagination_dist
 function critere_pagination_dist($idb, &$boucles, $crit) {
 
+	$boucle = &$boucles[$idb];
 	// definition de la taille de la page
-	$pas = !isset($crit->param[0][0]) ? "''" : calculer_liste(array($crit->param[0][0]), array(), $boucles, $boucles[$idb]->id_parent);
-	if (!preg_match("/^'([^']*)'$/", $pas, $r)) {
+	$pas = !isset($crit->param[0][0]) ? "''" : calculer_liste(array($crit->param[0][0]), array(), $boucles, $boucle->id_parent);
+
+	if (!preg_match(_CODE_QUOTE, $pas, $r)) {
 		$pas = "((\$a = intval($pas)) ? \$a : 10)";
 	} else {
-		$r = intval($r[1]);
+		$r = intval($r[2]);
 		$pas = strval($r ? $r : 10);
 	}
-	$debut = !isset($crit->param[0][1]) ? "'$idb'" : calculer_liste(array($crit->param[0][1]), array(), $boucles, $boucles[$idb]->id_parent);
+	$type = !isset($crit->param[0][1]) ? "'$idb'" : calculer_liste(array($crit->param[0][1]), array(), $boucles, $boucle->id_parent);
+	$debut = ($type[0]!=="'") ? "'debut'.$type" 
+	  : ("'debut" .substr($type,1));
+
+	$boucle->modificateur['debut_nom'] = $type;
+	$partie =
+		 // tester si le numero de page demande est de la forme '@yyy'
+		 'isset($Pile[0]['.$debut.']) ? $Pile[0]['.$debut.'] : _request('.$debut.");\n"
+		."\tif(substr(\$debut_boucle,0,1)=='@'){\n"
+		."\t\t".'$debut_boucle = $Pile[0]['. $debut.'] = quete_debut_pagination(\''.$boucle->primary.'\',$Pile[0][\'@'.$boucle->primary.'\'] = substr($debut_boucle,1),'.intval($pas).',$result,'._q($boucle->sql_serveur).');'."\n"
+		."\t\t".'if (!sql_seek($result,0,'._q($boucle->sql_serveur).")){\n"
+		."\t\t\t".'@sql_free($result,'._q($boucle->sql_serveur).");\n"
+		."\t\t\t".'$result = calculer_select($select, $from, $type, $where, $join, $groupby, $orderby, $limit, $having, $table, $id, $connect);'."\n"
+		."\t\t}\n"
+		."\t}\n"
+		."\t".'$debut_boucle = intval($debut_boucle)';
+
 
-	$boucle = &$boucles[$idb];
-	$boucle->mode_partie = 'p+';
-	$boucle->partie = 'intval(isset($Pile[0][\'debut\'.'.$debut.']) ? $Pile[0][\'debut\'.'.$debut.'] : _request(\'debut\'.'.$debut.'))';
-	$boucle->modificateur['debut_nom'] = $debut;
 	$boucle->total_parties = $pas;
+	calculer_parties($boucles, $idb, $partie, 'p+');
+	// ajouter la cle primaire dans le select pour pouvoir gerer la pagination referencee par @id
+	// sauf si pas de primaire, ou si primaire composee
+	// dans ce cas, on ne sait pas gerer une pagination indirecte
+	$t = $boucle->id_table . '.' . $boucle->primary;
+	if ($boucle->primary
+		AND !preg_match('/[,\s]/',$boucle->primary)
+		AND !in_array($t, $boucle->select))
+	  $boucle->select[]= $t;
 }
 
+
 // {recherche} ou {recherche susan}
 // http://www.spip.net/@recherche
 // http://doc.spip.org/@critere_recherche_dist
@@ -307,8 +334,7 @@ function critere_fusion_dist($idb,&$boucles, $crit) {
 		if (!in_array($t, $boucles[$idb]->select))
 		    $boucles[$idb]->select[] = $t;
 	} else 
-		erreur_squelette(_T('zbug_info_erreur_squelette'),
-			"{groupby ?} BOUCLE$idb");
+		return (array('zbug_critere_inconnu', array('critere' => $crit->op . ' ?')));
 }
 
 // c'est la commande SQL "COLLATE"
@@ -323,8 +349,7 @@ function critere_collecte_dist($idb,&$boucles, $crit) {
     if ($n && (strpos($boucle->order[$n-1],'COLLATE')===false))
     	$boucle->order[$n-1] .= " . " . $boucle->modificateur['collate'];
 	} else
-		erreur_squelette(_T('zbug_info_erreur_squelette'),
-			"{collecte ?} BOUCLE$idb");
+		return (array('zbug_critere_inconnu', array('critere' => $crit->op . " $n")));
 }
 
 // http://doc.spip.org/@calculer_critere_arg_dynamique
@@ -343,12 +368,11 @@ function calculer_critere_arg_dynamique($idb, &$boucles, $crit, $suffix='')
 	$arg = calculer_liste($crit, array(), $boucles, $boucle->id_parent);
 	return	"((\$x = preg_replace(\"/\\W/\",'', $arg)) ? $alt : '')";
 }
-
 // Tri : {par xxxx}
 // http://www.spip.net/@par
 // http://doc.spip.org/@critere_par_dist
 function critere_par_dist($idb, &$boucles, $crit) {
-	critere_parinverse($idb, $boucles, $crit) ;
+	return critere_parinverse($idb, $boucles, $crit) ;
 }
 
 // http://doc.spip.org/@critere_parinverse
@@ -389,9 +413,9 @@ function critere_parinverse($idb, &$boucles, $crit, $sens='') {
 		  $boucle->select[] = $texte . " AS $as";
 		  $order = "'$as'";
 	      } else {
-	      if (!preg_match(",^" . CHAMP_SQL_PLUS_FONC . '$,is', $par, $match)) 
-		erreur_squelette(_T('zbug_info_erreur_squelette'), "{par $par} BOUCLE$idb");
-	      else {
+		if (!preg_match(",^" . CHAMP_SQL_PLUS_FONC . '$,is', $par, $match)) {
+			return (array('zbug_critere_inconnu', array('critere' => $crit->op . " $par")));
+		} else {
 		if (count($match)>2) { $par = substr($match[2],1,-1); $fct = $match[1]; }
 	// par hasard
 		if ($par == 'hasard') {
@@ -403,6 +427,8 @@ function critere_parinverse($idb, &$boucles, $crit, $sens='') {
 		else if (isset($exceptions_des_jointures[$par])) {
 			list($table, $champ) =  $exceptions_des_jointures[$par];
 			$order = critere_par_joint($table, $champ, $boucle, $idb);
+			if (!$order)
+				return (array('zbug_critere_inconnu', array('critere' => $crit->op . " $par")));
 		}
 		else if ($par == 'date'
 		AND isset($GLOBALS['table_date'][$boucle->type_requete])) {
@@ -418,8 +444,7 @@ function critere_parinverse($idb, &$boucles, $crit, $sens='') {
 				$t = array_search(@$t[0], $boucle->from);
 			}
 			if (!$t) {
-				erreur_squelette(_T('zbug_info_erreur_squelette'),  "{par $par } BOUCLE$idb");
-				$order = '';
+				return (array('zbug_critere_inconnu', array('critere' => $crit->op . " $par")));
 			} else 	$order = "'" . $t . '.' . $r[2] . "'";
 		} else {
 			$desc = $boucle->show;
@@ -455,8 +480,7 @@ function critere_par_joint($table, $champ, &$boucle, $idb)
 {
 	$t = array_search($table, $boucle->from);
 	if (!$t) $t = trouver_jointure_champ($champ, $boucle);
-	if (!$t) erreur_squelette(_T('zbug_info_erreur_squelette'),  "{par ?} BOUCLE$idb");
-	return "'" . $t . '.' . $champ . "'";
+	return !$t ? '' : ("'" . $t . '.' . $champ . "'");
 }
 
 // {inverse}
@@ -496,8 +520,7 @@ function critere_agenda_dist($idb, &$boucles, $crit)
 	$params = $crit->param;
 
 	if (count($params) < 1)
-	      erreur_squelette(_T('zbug_info_erreur_squelette'),
-			       "{agenda ?} BOUCLE$idb");
+		return (array('zbug_critere_inconnu', array('critere' => $crit->op . " ?")));
 
 	$parent = $boucles[$idb]->id_parent;
 
@@ -572,18 +595,79 @@ function calculer_critere_parties($idb, &$boucles, $crit) {
 	$a1 = $crit->param[0];
 	$a2 = $crit->param[1];
 	$op = $crit->op;
+
 	list($a11,$a12) = calculer_critere_parties_aux($idb, $boucles, $a1);
 	list($a21,$a22) = calculer_critere_parties_aux($idb, $boucles, $a2);
 	if (($op== ',')&&(is_numeric($a11) && (is_numeric($a21))))
 	    $boucle->limit = $a11 .',' . $a21;
 	else {
-		$boucle->partie = ($a11 != 'n') ? $a11 : $a12;
 		$boucle->total_parties =  ($a21 != 'n') ? $a21 : $a22;
-		$boucle->mode_partie = (($op == '/') ? '/' :
+		$partie = ($a11 != 'n') ? $a11 : $a12;
+		$mode = (($op == '/') ? '/' :
 			(($a11=='n') ? '-' : '+').(($a21=='n') ? '-' : '+'));
+		calculer_parties($boucles, $idb, $partie,  $mode);
 	}
 }
 
+//
+// Code specifique aux criteres {pagination}, {1,n} {n/m} etc
+//
+
+function calculer_parties(&$boucles, $id_boucle, $debut, $mode) {
+
+	$total_parties = $boucles[$id_boucle]->total_parties;
+	preg_match(",([+-/p])([+-/])?,", $mode, $regs);
+	list(,$op1,$op2) = $regs;
+	$nombre_boucle = "\$Numrows['$id_boucle']['total']";
+	// {1/3}
+	if ($op1 == '/') {
+		$pmoins1 = is_numeric($debut) ? ($debut-1) : "($debut-1)";
+		$totpos = is_numeric($total_parties) ? ($total_parties) :
+		  "($total_parties ? $total_parties : 1)";
+		$fin = "ceil(($nombre_boucle * $debut )/$totpos) - 1";
+		$debut = !$pmoins1 ? 0 : "ceil(($nombre_boucle * $pmoins1)/$totpos);";
+	} else {
+		// cas {n-1,x}
+		if ($op1 == '-') $debut = "$nombre_boucle - $debut;";
+
+		// cas {x,n-1}
+		if ($op2 == '-') {
+			$fin = '$debut_boucle + '.$nombre_boucle.' - '
+			. (is_numeric($total_parties) ? ($total_parties+1) :
+			   ($total_parties . ' - 1'));
+		} else {
+			// {x,1} ou {pagination}
+			$fin = '$debut_boucle'
+			. (is_numeric($total_parties) ?
+			     (($total_parties==1) ? "" :(' + ' . ($total_parties-1))):
+			     ('+' . $total_parties . ' - 1'));
+		}
+		
+		// {pagination}, gerer le debut_xx=-1 pour tout voir
+		if ($op1 == 'p') {
+			$debut .= ";\n	\$debut_boucle = ((\$tout=(\$debut_boucle == -1))?0:(\$debut_boucle))";
+			$fin = "(\$tout ? \$Numrows['$id_boucle']['total'] : $fin)";
+		}
+	}
+
+	// Notes :
+	// $debut_boucle et $fin_boucle sont les indices SQL du premier
+	// et du dernier demandes dans la boucle : 0 pour le premier,
+	// n-1 pour le dernier ; donc total_boucle = 1 + debut - fin
+	// Utiliser min pour rabattre $fin_boucle sur total_boucle.
+
+	$boucles[$id_boucle]->mode_partie = "\n\t"
+	. '$debut_boucle = ' . $debut .   ";\n	"
+	. '$fin_boucle = min(' . $fin . ", \$Numrows['$id_boucle']['total'] - 1);\n	"
+	. '$Numrows[\''.$id_boucle. "']['grand_total'] = \$Numrows['$id_boucle']['total'];\n	"
+	. '$Numrows[\''.$id_boucle.'\']["total"] = max(0,$fin_boucle - $debut_boucle + 1);'
+	. "\n\tif (\$debut_boucle>0 AND \$debut_boucle < \$Numrows['$id_boucle']['grand_total'] AND sql_seek(\$result,\$debut_boucle,"._q($boucles[$id_boucle]->sql_serveur).",'continue'))\n\t\t\$Numrows['$id_boucle']['compteur_boucle'] = \$debut_boucle;\n\t";
+
+	$boucles[$id_boucle]->partie = "
+		if (\$Numrows['$id_boucle']['compteur_boucle'] <= \$debut_boucle) continue;
+		if (\$Numrows['$id_boucle']['compteur_boucle']-1 > \$fin_boucle) break;";
+}
+
 // http://doc.spip.org/@calculer_critere_parties_aux
 function calculer_critere_parties_aux($idb, &$boucles, $param) {
 	if ($param[0]->type != 'texte')
@@ -604,32 +688,40 @@ function calculer_critere_parties_aux($idb, &$boucles, $param) {
 }
 
 //
-// La fonction d'aiguillage sur le nom du critere
-//
+// La fonction d'aiguillage sur le nom du critere dans leur liste
+// Si l'une au moins des fonctions associees retourne une erreur 
+// (i.e. un tableau), on propage l'information
+// Sinon, ne retourne rien (affectation directe dans l'arbre)
 
 // http://doc.spip.org/@calculer_criteres
-function calculer_criteres ($idb, &$boucles) {
-
-	foreach($boucles[$idb]->criteres as $crit) {
+function calculer_criteres ($idb, &$boucles)
+{
+	$msg = '';
+	$boucle = $boucles[$idb];
+	$table = strtoupper($boucle->id_table);
+	$defaut = charger_fonction('DEFAUT', 'calculer_critere');
+	// s'il y avait une erreur de syntaxe, propager cette info
+	if (!is_array($boucle->criteres)) return array(); 
+	foreach($boucle->criteres as $crit) {
 		$critere = $crit->op;
 		// critere personnalise ?
-		if (
-		  (!function_exists($f="critere_".strtoupper($boucles[$idb]->id_table)."_".$critere))
+		if ((!function_exists($f="critere_".$table."_".$critere))
 		AND (!function_exists($f=$f."_dist"))
 		AND (!function_exists($f="critere_".$critere))
 		AND (!function_exists($f=$f."_dist"))	) {
-		  // fonction critere standard ?
-		  // double cas particulier repere a l'analyse lexicale
-		  if (($critere == ",") OR ($critere == '/'))
-		    $f = 'calculer_critere_parties';
-		  else	$f = 'calculer_critere_DEFAUT';
+			// fonction critere standard 
+			$f = $defaut;
 		}
-		// Applique le critere
+		// compile le critere
 		$res = $f($idb, $boucles, $crit);
 
-		// Gestion d'erreur
-		if (is_array($res)) erreur_squelette($res);
+		// Gestion centralisee des erreurs pour pouvoir propager
+		if (is_array($res)) {
+			$msg = $res;
+			erreur_squelette($msg, $boucle);
+		}
 	}
+	return $msg;
 }
 
 // Madeleine de Proust, revision MIT-1958 sqq, revision CERN-1989
@@ -637,7 +729,7 @@ function calculer_criteres ($idb, &$boucles) {
 // http://doc.spip.org/@kwote
 function kwote($lisp)
 {
-	if (preg_match(",^(\n//[^\n]*\n)? *'(.*)' *$,", $lisp, $r))
+	if (preg_match(_CODE_QUOTE, $lisp, $r))
 		return $r[1] . "\"" . sql_quote(str_replace(array("\\'","\\\\"),array("'","\\"),$r[2])) . "\"" ;
 	else
 		return "sql_quote($lisp)"; 
@@ -648,8 +740,12 @@ function kwote($lisp)
 // http://doc.spip.org/@critere_IN_dist
 function critere_IN_dist ($idb, &$boucles, $crit)
 {
+	$r = calculer_critere_infixe($idb, $boucles, $crit);
+	if (!$r) {
+		return (array('zbug_critere_inconnu', array('critere' => $crit->op . " ?")));
+	}
+	list($arg, $op, $val, $col, $where_complement) = $r;
 
-	list($arg, $op, $val, $col, $where_complement)= calculer_critere_infixe($idb, $boucles, $crit);
 	$in = critere_IN_cas($idb, $boucles, $crit->not ? 'NOT' : ($crit->exclus? 'exclus' :  ''), $arg, $op, $val, $col);
 //	inserer la condition; exemple: {id_mot ?IN (66, 62, 64)}
 	$where = $in;
@@ -674,7 +770,10 @@ function critere_IN_dist ($idb, &$boucles, $crit)
 // http://doc.spip.org/@critere_IN_cas
 function critere_IN_cas ($idb, &$boucles, $crit2, $arg, $op, $val, $col)
 {
-	static $cpt = 0;
+	static $num = array();
+	$descr = $boucles[$idb]->descr;
+	$cpt = &$num[$descr['nom']][$descr['gram']][$idb];
+
 	$var = '$in' . $cpt++;
 	$x= "\n\t$var = array();";
 	foreach ($val as $k => $v) {
@@ -706,13 +805,25 @@ function critere_IN_cas ($idb, &$boucles, $crit2, $arg, $op, $val, $col)
 	return "sql_in('$arg',sql_quote($var)".($crit2=='NOT'?",'NOT'":"").")";
 }
 
-
 # Criteres de comparaison
 
 // http://doc.spip.org/@calculer_critere_DEFAUT
-function calculer_critere_DEFAUT($idb, &$boucles, $crit)
+function calculer_critere_DEFAUT_dist($idb, &$boucles, $crit)
 {
-	list($arg, $op, $val, $col, $where_complement)= calculer_critere_infixe($idb, $boucles, $crit);
+	// double cas particulier {0,1} et {1/2} repere a l'analyse lexicale
+	if (($crit->op == ",") OR ($crit->op == '/'))
+		return calculer_critere_parties($idb, $boucles, $crit);
+
+	$r = calculer_critere_infixe($idb, $boucles, $crit);
+
+	if (!$r) {
+		return (array('zbug_critere_inconnu', array('critere' => $crit->op )));
+	} else calculer_critere_DEFAUT_args($idb, $boucles, $crit, $r);
+}
+
+function calculer_critere_DEFAUT_args($idb, &$boucles, $crit, $args)
+{
+	list($arg, $op, $val, $col, $where_complement) = $args;
 
 	$where = array("'$op'", "'$arg'", $val[0]);
 
@@ -730,12 +841,12 @@ function calculer_critere_DEFAUT($idb, &$boucles, $crit)
 	// traiter a part la date, elle est mise d'office par SPIP,
 	if ($crit->cond) {
 		$pred = calculer_argument_precedent($idb, $col, $boucles);
-    if ($col == "date" OR $col == "date_redac") {
-      if($pred == "\$Pile[0]['".$col."']") {
-        $pred = "(\$Pile[0]['{$col}_default']?'':$pred)";
-      }
-    }
-
+		if ($col == "date" OR $col == "date_redac") {
+			if($pred == "\$Pile[0]['".$col."']") {
+			  $pred = "(\$Pile[0]['{$col}_default']?'':$pred)";
+			}
+		}
+		
 		if ($op == '=' AND !$crit->not)
 		  $where = array("'?'", "(is_array($pred))", 
 				 critere_IN_cas ($idb, $boucles, 'COND', $arg, $op, array($pred), $col), 
@@ -764,9 +875,10 @@ function calculer_critere_infixe($idb, &$boucles, $crit) {
 
 	list($fct, $col, $op, $val, $args_sql) =
 	  calculer_critere_infixe_ops($idb, $boucles, $crit);
+
 	$col_alias = $col;
 	$where_complement =false;
-//var_dump(array($fct, $col, $op, $val, $args_sql));
+
 	// Cas particulier : id_enfant => utiliser la colonne id_objet
 	if ($col == 'id_enfant')
 	  $col = $boucle->primary;
@@ -781,8 +893,9 @@ function calculer_critere_infixe($idb, &$boucles, $crit) {
 	else if (($col == 'id_secteur')&&($type == 'breves')) {
 		$col = 'id_rubrique';
 	}
-	else if (($col == 'id_secteur')&& ($type == 'forums')) {
-		$table = critere_secteur_forum($idb, $boucles, $val, $crit);
+	// et possibilite de gerer un critere secteur sur des tables de plugins (ie forums)
+	else if (($col == 'id_secteur') AND ($critere_secteur = charger_fonction("critere_secteur_$type","public",true))) {
+		$table = $critere_secteur($idb, $boucles, $val, $crit);
 	}
 	
 	// cas id_article=xx qui se mappe en id_objet=xx AND objet=article
@@ -794,40 +907,20 @@ function calculer_critere_infixe($idb, &$boucles, $crit) {
 	}
 	// Cas particulier : expressions de date
 	else if ($date = tester_param_date($boucle->type_requete, $col)) {
-		list($col, $table) =
-		calculer_critere_infixe_date($idb, $boucles, $date);
+		$col = calculer_critere_infixe_date($idb, $boucles, $date);
+		$table = '';
 	}
 	else if (preg_match('/^(.*)\.(.*)$/', $col, $r)) {
 		  list(,$table, $col) = $r;
 		  $col_alias = $col;
 		  $table = calculer_critere_externe_init($boucle, array($table), $col, $desc, ($crit->cond OR $op !='='), true);
+		  if (!$table) return '';
 	}
-	else {
-		if (@!array_key_exists($col, $desc['field'])) {
-	  	$calculer_critere_externe = 'calculer_critere_externe_init';
-			// gestion par les plugins des jointures tordues pas automatiques mais necessaires
-			if (isset($exceptions_des_jointures[$table][$col])){
-				if (count($exceptions_des_jointures[$table][$col])==3)
-					list($t, $col, $calculer_critere_externe) = $exceptions_des_jointures[$table][$col];
-				else
-					list($t, $col) = $exceptions_des_jointures[$table][$col];
-			}
-			else if (isset($exceptions_des_jointures[$col]))
-				list($t, $col) = $exceptions_des_jointures[$col];
-			else $t =''; // jointure non declaree. La trouver.
-			$table = $calculer_critere_externe($boucle, $boucle->jointures, $col, $desc, ($crit->cond OR $op !='='), $t);
-			list($nom, $desc) = trouver_champ_exterieur($col, $boucle->jointures, $boucle);
-			if (count(trouver_champs_decomposes($col,$desc))>1){
-				$col_alias = $col; // id_article devient juste le nom d'origine
-				$e = decompose_champ_id_objet($col);
-				$col = array_shift($e);
-				$where_complement = primary_doublee($e, $table);
-			}
-		}
+	elseif (@!array_key_exists($col, $desc['field'])) {
+		$r = calculer_critere_infixe_externe($boucle, $crit, $op, $desc, $col, $col_alias, $table);
+		if (!$r) return '';
+		list($col, $col_alias, $table, $where_complement) = $r;
 	}
-	// Si la colonne SQL est numerique ou le critere est une date relative
-	// forcer une conversion pour eviter un erreur au niveau SQL
-
 	// Si la colonne SQL est numerique ou le critere est une date relative
 	// virer les guillemets eventuels qui sont refuses par certains SQL
 	// Ne pas utiliser intval, PHP tronquant les Bigint de SQL
@@ -878,6 +971,46 @@ function calculer_critere_infixe($idb, &$boucles, $crit) {
 	return array($arg, $op, $val, $col_alias, $where_complement);
 }
 
+function calculer_critere_infixe_externe(&$boucle, $crit, $op, $desc, $col, $col_alias, $table)
+{
+	global $exceptions_des_jointures;
+	$where = '';
+
+	$calculer_critere_externe = 'calculer_critere_externe_init';
+	// gestion par les plugins des jointures tordues 
+	// pas automatiques mais necessaires
+	if (is_array($exceptions_des_jointures[$table])) {
+		$t = $exceptions_des_jointures[$table];
+		$index = isset($t[$col])
+		?  $t[$col] : (isset($t['']) ? $t[''] : array());
+		
+		if (count($index)==3)
+			list($t, $col, $calculer_critere_externe) = $index;
+		elseif (count($index)==2)
+			list($t, $col) = $t[$col];
+		else 	{
+			list($calculer_critere_externe) = $index;
+			$t = $table;
+		}
+	} else if (isset($exceptions_des_jointures[$col]))
+		list($t, $col) = $exceptions_des_jointures[$col];
+	else $t =''; // jointure non declaree. La trouver.
+
+	$table = $calculer_critere_externe($boucle, $boucle->jointures, $col, $desc, ($crit->cond OR $op !='='), $t);
+
+	if (!$table) return '';
+
+	list($nom, $desc) = trouver_champ_exterieur($col, $boucle->jointures, $boucle);
+	if (count(trouver_champs_decomposes($col,$desc))>1){
+		$col_alias = $col; // id_article devient juste le nom d'origine
+		$e = decompose_champ_id_objet($col);
+		$col = array_shift($e);
+		$where = primary_doublee($e, $table);
+	}
+
+	return array($col, $col_alias, $table, $where);
+}
+
 // Ne pas appliquer sql_quote lors de la compilation,
 // car on ne connait pas le serveur SQL, donc s'il faut \' ou ''
 
@@ -920,11 +1053,11 @@ function critere_secteur_forum($idb, &$boucles, $val, $crit)
 function calculer_critere_externe_init(&$boucle, $joints, $col, $desc, $eg, $checkarrivee = false)
 {
 	$cle = trouver_champ_exterieur($col, $joints, $boucle, $checkarrivee);
-	if ($cle) {
-		$t = array_search($cle[0], $boucle->from);
-		// transformer eventuellement id_xx en (id_objet,objet)
-		$cols = trouver_champs_decomposes($col,$cle[1]); 
-		if ($t) {
+	if (!$cle) return '';
+	$t = array_search($cle[0], $boucle->from);
+	// transformer eventuellement id_xx en (id_objet,objet)
+	$cols = trouver_champs_decomposes($col,$cle[1]); 
+	if ($t) {
 			$joindre = false;
 			foreach($cols as $col){
 			  $c = '/\b' . $t  . ".$col" . '\b/';
@@ -936,16 +1069,9 @@ function calculer_critere_externe_init(&$boucle, $joints, $col, $desc, $eg, $che
 			  }
 			}
 		  if (!$joindre) return $t;
-		}
-		$cle = calculer_jointure($boucle, array($boucle->id_table, $desc), $cle, $cols, $eg);
-		if ($cle) return $cle;
 	}
+	return calculer_jointure($boucle, array($boucle->id_table, $desc), $cle, $cols, $eg);
 
-	erreur_squelette(_T('zbug_info_erreur_squelette'),
-			_T('zbug_boucle') .
-			" $idb " .
-			_T('zbug_critere_inconnu', 
-			    array('critere' => $col)));
 }
 
 // http://doc.spip.org/@trouver_champ
@@ -988,44 +1114,43 @@ function calculer_critere_infixe_ops($idb, &$boucles, $crit)
 	// un critere conditionnel sur date est traite a part
 	// car la date est mise d'office par SPIP, 
 	      $val = calculer_argument_precedent($idb, $val, $boucles);
-        if ($crit->cond AND ($col == "date" OR $col == "date_redac")) {
+	      if ($crit->cond AND ($col == "date" OR $col == "date_redac")) {
 		      if($val == "\$Pile[0]['".$col."']") {
-            $val = "(\$Pile[0]['{$col}_default']?'':$val)";
-          }
-		    }
+			$val = "(\$Pile[0]['{$col}_default']?'':$val)";
+		      }
+	      }
 	      $val = array(kwote($val));
 	    }
 	  } else {
 	    // comparaison explicite
 	    // le phraseur impose que le premier param soit du texte
-	    $params = $crit->param;
-	    $op = $crit->op;
-	    if ($op == '==') $op = 'REGEXP';
-	    $col = array_shift($params);
-	    $col = $col[0]->texte;
+		$params = $crit->param;
+		$op = $crit->op;
+		if ($op == '==') $op = 'REGEXP';
+		$col = array_shift($params);
+		$col = $col[0]->texte;
 
-	    $val = array();
-	    $desc = array('id_mere' => $idb);
-	    $parent = $boucles[$idb]->id_parent;
+		$val = array();
+		$desc = array('id_mere' => $idb);
+		$parent = $boucles[$idb]->id_parent;
 
-			// Dans le cas {x=='#DATE'} etc, defaire le travail du phraseur, 
-			// celui ne sachant pas ce qu'est un critere infixe
-			// et a fortiori son 2e operande qu'entoure " ou '
-			if (count($params)==1
-					AND count($params[0]==3)
-					AND $params[0][0]->type == 'texte' 
-					AND @$params[0][2]->type == 'texte' 
-					AND ($p=$params[0][0]->texte) == $params[0][2]->texte
-					AND (($p == "'") OR ($p == '"'))
-					AND $params[0][1]->type == 'champ' ) {
-				$val[]= "$p\\$p#" . $params[0][1]->nom_champ . "\\$p$p";
+		// Dans le cas {x=='#DATE'} etc, defaire le travail du phraseur,
+		// celui ne sachant pas ce qu'est un critere infixe
+		// et a fortiori son 2e operande qu'entoure " ou '
+		if (count($params)==1
+		AND count($params[0]==3)
+		AND $params[0][0]->type == 'texte' 
+		AND @$params[0][2]->type == 'texte' 
+		AND ($p=$params[0][0]->texte) == $params[0][2]->texte
+		AND (($p == "'") OR ($p == '"'))
+		AND $params[0][1]->type == 'champ' ) {
+			$val[]= "$p\\$p#" . $params[0][1]->nom_champ . "\\$p$p";
+		} else 
+			foreach ((($op != 'IN') ? $params : calculer_vieux_in($params)) as $p) {
+				$a = calculer_liste($p, $desc, $boucles, $parent);
+				if ($op == 'IN') $val[]= $a;
+				else $val[]=kwote($a);
 			}
-			else 
-				foreach ((($op != 'IN') ? $params : calculer_vieux_in($params)) as $p) {
-					$a = calculer_liste($p, $desc, $boucles, $parent);
-					if ($op == 'IN') $val[]= $a;
-					else $val[]=kwote($a);
-				}
 	}
 
 	$fct = $args_sql = '';
@@ -1040,7 +1165,7 @@ function calculer_critere_infixe_ops($idb, &$boucles, $crit)
 	  }
 	  $args_sql .= $a[2];;
 	}
-//var_dump(array($fct,$col,$op,$val,$args_sql));
+
 	return array($fct, $col, $op, $val, $args_sql);
 }
 
@@ -1083,9 +1208,9 @@ function calculer_critere_infixe_date($idb, &$boucles, $regs)
 {
 	global $table_date; 
 	$boucle = $boucles[$idb];
-	list(,$col, $rel, $suite) = $regs;
+	$col = $regs[1];
 	$date_orig = $pred = isset($table_date[$boucle->type_requete])?$table_date[$boucle->type_requete]:'date';
-	if ($suite) {
+	if (isset($regs[3]) AND $suite=$regs[3]) {
 	# Recherche de l'existence du champ date_xxxx,
 	# si oui choisir ce champ, sinon choisir xxxx
 		$t = $boucle->show;
@@ -1094,62 +1219,56 @@ function calculer_critere_infixe_date($idb, &$boucles, $regs)
 		else
 			$date_orig = substr($suite, 1);
 		$pred = $date_orig;
-	} else if ($rel) $pred = 'date';
+	} 
+	else 
+	  if (isset($regs[2]) AND $rel=$regs[2]) $pred = 'date';
 
 	$date_compare = "\"' . normaliser_date(" .
 	      calculer_argument_precedent($idb, $pred, $boucles) .
 	      ") . '\"";
 	$date_orig = $boucle->id_table . '.' . $date_orig;
 
-	if ($col == 'date') {
+	switch ($col) {
+		case 'date':
 			$col = $date_orig;
-			$col_table = '';
-		}
-	else if ($col == 'jour') {
+			break;
+		case 'jour':
 			$col = "DAYOFMONTH($date_orig)";
-			$col_table = '';
-		}
-	else if ($col == 'mois') {
+			break;
+		case 'mois':
 			$col = "MONTH($date_orig)";
-			$col_table = '';
-		}
-	else if ($col == 'annee') {
+			break;
+		case 'annee':
 			$col = "YEAR($date_orig)";
-			$col_table = '';
-		}
-	else if ($col == 'heure') {
+			break;
+		case 'heure':
 			$col = "DATE_FORMAT($date_orig, '%H:%i')";
-			$col_table = '';
-		}
-	else if ($col == 'age') {
-			$col = calculer_param_date("now()", $date_orig);
-			$col_table = '';
-		}
-	else if ($col == 'age_relatif') {
+			break;
+		case 'age':
+			$col = calculer_param_date("NOW()", $date_orig);
+			break;
+		case 'age_relatif':
 			$col = calculer_param_date($date_compare, $date_orig);
-			$col_table = '';
-		}
-	else if ($col == 'jour_relatif') {
+			break;
+		case 'jour_relatif':
 			$col = "LEAST(TO_DAYS(" .$date_compare . ")-TO_DAYS(" .
 			$date_orig . "), DAYOFMONTH(" . $date_compare .
 			")-DAYOFMONTH(" . $date_orig . ")+30.4368*(MONTH(" .
 			$date_compare . ")-MONTH(" . $date_orig .
 			"))+365.2422*(YEAR(" . $date_compare . ")-YEAR(" .
 			$date_orig . ")))";
-			$col_table = '';
-		}
-	else if ($col == 'mois_relatif') {
+			break;
+		case 'mois_relatif':
 			$col = "MONTH(" . $date_compare . ")-MONTH(" .
 			$date_orig . ")+12*(YEAR(" . $date_compare .
 			")-YEAR(" . $date_orig . "))";
-			$col_table = '';
-		}
-	else if ($col == 'annee_relatif') {
+			break;
+		case 'annee_relatif':
 			$col = "YEAR(" . $date_compare . ")-YEAR(" .
 			$date_orig . ")";
-			$col_table = '';
-		}
-	return array($col, $col_table);
+			break;
+	}
+	return $col;
 }
 
 // http://doc.spip.org/@calculer_param_date
