@@ -11,7 +11,7 @@
 <?php
 	$myDir = opendir('.');
 	while($file = readdir($myDir)) {
-		if (ereg("\.(png|gif)$", $file))
+		if (preg_match(",\.(png|gif)$,i", $file))
 			echo "		<tr><td>$file</td><td><img src='$file' alt='$file' /></td></tr>\n";
 	}
 ?>
