@@ -3,7 +3,7 @@
 /***************************************************************************\
  *  SPIP, Systeme de publication pour l'internet                           *
  *                                                                         *
- *  Copyright (c) 2001-2009                                                *
+ *  Copyright (c) 2001-2010                                                *
  *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
  *                                                                         *
  *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
@@ -15,13 +15,24 @@
 // il faut aller le chercher a la main
 function informer_auteur($bof)
 {
-  	include_spip('inc/json');
+	include_spip('inc/json');
 	include_spip('formulaires/login');
-	$row = informer_login(_request('var_login'));
-	if (is_array($row))
+	include_spip('inc/auth');
+	$row = auth_informer_login(_request('var_login'));
+	if ($row AND is_array($row))
 		unset($row['id_auteur']);
-	else $row = array();
+	else {
+		// piocher les infos sur un autre login
+		$n = sql_countsel('spip_auteurs',"login<>''");
+		$n = (abs(crc32(_request('var_login')))%$n);
+		$row = auth_informer_login(sql_getfetsel('login','spip_auteurs',"login<>''",'','',"$n,1"));
+		if ($row AND is_array($row)){
+			unset($row['id_auteur']);
+			$row['login'] = _request('var_login');
+		}
+	}
+
 	return json_export($row);
 }
 
-?>
+?>
\ No newline at end of file
